@@ -37,35 +37,34 @@ static int initFlags = 0;
 static void
 print_title()
 {
-    std::cout
-        << "Jami Core " << libjami::version()
-        << ", by Savoir-faire Linux Inc. Copyright (C) 2004-2025" << std::endl
-        << "https://jami.net/" << std::endl
+    std::cout << "Jami Core " << libjami::version() << ", by Savoir-faire Linux Inc. Copyright (C) 2004-2025"
+              << std::endl
+              << "https://jami.net/" << std::endl
 #ifdef ENABLE_VIDEO
-        << "[Video support enabled]" << std::endl
+              << "[Video support enabled]" << std::endl
 #endif
 #ifdef ENABLE_PLUGIN
-        << "[Plugins support enabled]" << std::endl
+              << "[Plugins support enabled]" << std::endl
 #endif
-        << std::endl;
+              << std::endl;
 }
 
 static void
 print_usage()
 {
-    std::cout << std::endl <<
-    "-c, --console \t- Log in console (instead of syslog)" << std::endl <<
-    "-d, --debug \t- Debug mode (more verbose)" << std::endl <<
-    "-p, --persistent \t- Stay alive after client quits" << std::endl <<
-    "--auto-answer \t- Force automatic answer to incoming calls" << std::endl <<
-    "-h, --help \t- Print help" << std::endl;
+    std::cout << std::endl
+              << "-c, --console \t- Log in console (instead of syslog)" << std::endl
+              << "-d, --debug \t- Debug mode (more verbose)" << std::endl
+              << "-p, --persistent \t- Stay alive after client quits" << std::endl
+              << "--auto-answer \t- Force automatic answer to incoming calls" << std::endl
+              << "-h, --help \t- Print help" << std::endl;
 }
 
 // Parse command line arguments, setting debug options or printing a help
 // message accordingly.
 // returns true if we should quit (i.e. help was printed), false otherwise
 static bool
-parse_args(int argc, char *argv[], bool& persistent)
+parse_args(int argc, char* argv[], bool& persistent)
 {
     int consoleFlag = false;
     int debugFlag = false;
@@ -95,29 +94,29 @@ parse_args(int argc, char *argv[], bool& persistent)
             break;
 
         switch (c) {
-            case 'd':
-                debugFlag = true;
-                break;
+        case 'd':
+            debugFlag = true;
+            break;
 
-            case 'c':
-                consoleFlag = true;
-                break;
+        case 'c':
+            consoleFlag = true;
+            break;
 
-            case 'p':
-                persistent = true;
-                break;
+        case 'p':
+            persistent = true;
+            break;
 
-            case 'h':
-            case '?':
-                helpFlag = true;
-                break;
+        case 'h':
+        case '?':
+            helpFlag = true;
+            break;
 
-            case 'v':
-                versionFlag = true;
-                break;
+        case 'v':
+            versionFlag = true;
+            break;
 
-            default:
-                break;
+        default:
+            break;
         }
     }
 
@@ -153,7 +152,7 @@ osxTests()
     registerSignalHandlers(std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>>());
 
     if (!libjami::start())
-            return -1;
+        return -1;
 
     while (true) {
         std::this_thread::sleep_for(std::chrono::seconds(1));
@@ -176,8 +175,7 @@ interrupt()
 static void
 signal_handler(int code)
 {
-    std::cerr << "Caught signal " << strsignal(code)
-              << ", terminating..." << std::endl;
+    std::cerr << "Caught signal " << strsignal(code) << ", terminating..." << std::endl;
 
     // Unset signal handlers
     signal(SIGHUP, SIG_DFL);
@@ -188,7 +186,7 @@ signal_handler(int code)
 }
 
 int
-main(int argc, char *argv [])
+main(int argc, char* argv[])
 {
     // Set the program's directory path as the resource directory path.
     std::filesystem::path programPath(argv[0]);
