@@ -1,18 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3, or (at your option)
- *  any later version.
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #include "account_config.h"
 #include "account_const.h"
@@ -22,6 +22,7 @@
 #include "config/account_config_utils.h"
 
 #include <fmt/compile.h>
+#include <fmt/ranges.h>
 
 namespace jami {
 
@@ -31,18 +32,17 @@ constexpr const char* VIDEO_ENABLED_KEY = "videoEnabled";
 constexpr const char* DISPLAY_NAME_KEY = "displayName";
 constexpr const char* ALIAS_KEY = "alias";
 constexpr const char* TYPE_KEY = "type";
-constexpr const char* AUTHENTICATION_USERNAME_KEY = "authenticationUsername";
 constexpr const char* USERNAME_KEY = "username";
-constexpr const char* PASSWORD_KEY = "password";
 constexpr const char* HOSTNAME_KEY = "hostname";
 constexpr const char* ACCOUNT_ENABLE_KEY = "enable";
 constexpr const char* ACCOUNT_AUTOANSWER_KEY = "autoAnswer";
+constexpr const char* DENY_SECOND_CALL_KEY = "denySecondCall";
 constexpr const char* ACCOUNT_READRECEIPT_KEY = "sendReadReceipt";
+constexpr const char* ACCOUNT_COMPOSING_KEY = "sendComposing";
 constexpr const char* ACCOUNT_ISRENDEZVOUS_KEY = "rendezVous";
 constexpr const char* ACCOUNT_ACTIVE_CALL_LIMIT_KEY = "activeCallLimit";
 constexpr const char* MAILBOX_KEY = "mailbox";
 constexpr const char* USER_AGENT_KEY = "useragent";
-constexpr const char* HAS_CUSTOM_USER_AGENT_KEY = "hasCustomUserAgent";
 constexpr const char* UPNP_ENABLED_KEY = "upnpEnabled";
 constexpr const char* ACTIVE_CODEC_KEY = "activeCodecs";
 constexpr const char* DEFAULT_MODERATORS_KEY = "defaultModerators";
@@ -51,6 +51,7 @@ constexpr const char* ALL_MODERATORS_ENABLED_KEY = "allModeratorsEnabled";
 constexpr const char* PROXY_PUSH_TOKEN_KEY = "proxyPushToken";
 constexpr const char* PROXY_PUSH_PLATFORM_KEY = "proxyPushPlatform";
 constexpr const char* PROXY_PUSH_TOPIC_KEY = "proxyPushiOSTopic";
+constexpr const char* UI_CUSTOMIZATION = "uiCustomization";
 
 using yaml_utils::parseValueOptional;
 
@@ -63,10 +64,11 @@ AccountConfig::serializeDiff(YAML::Emitter& out, const AccountConfig& DEFAULT_CO
     SERIALIZE_CONFIG(HOSTNAME_KEY, hostname);
     SERIALIZE_CONFIG(USERNAME_KEY, username);
     SERIALIZE_CONFIG(MAILBOX_KEY, mailbox);
-    out << YAML::Key << ACTIVE_CODEC_KEY << YAML::Value
-        << fmt::format(FMT_COMPILE("{}"), fmt::join(activeCodecs, "/"sv));
+    out << YAML::Key << ACTIVE_CODEC_KEY << YAML::Value << fmt::format(FMT_COMPILE("{}"), fmt::join(activeCodecs, "/"));
     SERIALIZE_CONFIG(ACCOUNT_AUTOANSWER_KEY, autoAnswerEnabled);
+    SERIALIZE_CONFIG(DENY_SECOND_CALL_KEY, denySecondCallEnabled);
     SERIALIZE_CONFIG(ACCOUNT_READRECEIPT_KEY, sendReadReceipt);
+    SERIALIZE_CONFIG(ACCOUNT_COMPOSING_KEY, sendComposing);
     SERIALIZE_CONFIG(ACCOUNT_ISRENDEZVOUS_KEY, isRendezVous);
     SERIALIZE_CONFIG(ACCOUNT_ACTIVE_CALL_LIMIT_KEY, activeCallLimit);
     SERIALIZE_CONFIG(RINGTONE_ENABLED_KEY, ringtoneEnabled);
@@ -74,13 +76,15 @@ AccountConfig::serializeDiff(YAML::Emitter& out, const AccountConfig& DEFAULT_CO
     SERIALIZE_CONFIG(USER_AGENT_KEY, customUserAgent);
     SERIALIZE_CONFIG(DISPLAY_NAME_KEY, displayName);
     SERIALIZE_CONFIG(UPNP_ENABLED_KEY, upnpEnabled);
-    SERIALIZE_CONFIG(DEFAULT_MODERATORS_KEY, defaultModerators);
+    out << YAML::Key << DEFAULT_MODERATORS_KEY << YAML::Value
+        << fmt::format(FMT_COMPILE("{}"), fmt::join(defaultModerators, "/"));
     SERIALIZE_CONFIG(LOCAL_MODERATORS_ENABLED_KEY, localModeratorsEnabled);
     SERIALIZE_CONFIG(ALL_MODERATORS_ENABLED_KEY, allModeratorsEnabled);
     SERIALIZE_CONFIG(PROXY_PUSH_TOKEN_KEY, deviceKey);
     SERIALIZE_CONFIG(PROXY_PUSH_PLATFORM_KEY, platform);
     SERIALIZE_CONFIG(PROXY_PUSH_TOPIC_KEY, notificationTopic);
     SERIALIZE_CONFIG(VIDEO_ENABLED_KEY, videoEnabled);
+    SERIALIZE_CONFIG(UI_CUSTOMIZATION, uiCustomization);
 }
 
 void
@@ -91,7 +95,9 @@ AccountConfig::unserialize(const YAML::Node& node)
     parseValueOptional(node, ACCOUNT_ENABLE_KEY, enabled);
     parseValueOptional(node, HOSTNAME_KEY, hostname);
     parseValueOptional(node, ACCOUNT_AUTOANSWER_KEY, autoAnswerEnabled);
+    parseValueOptional(node, DENY_SECOND_CALL_KEY, denySecondCallEnabled);
     parseValueOptional(node, ACCOUNT_READRECEIPT_KEY, sendReadReceipt);
+    parseValueOptional(node, ACCOUNT_COMPOSING_KEY, sendComposing);
     parseValueOptional(node, ACCOUNT_ISRENDEZVOUS_KEY, isRendezVous);
     parseValueOptional(node, ACCOUNT_ACTIVE_CALL_LIMIT_KEY, activeCallLimit);
     parseValueOptional(node, MAILBOX_KEY, mailbox);
@@ -117,6 +123,7 @@ AccountConfig::unserialize(const YAML::Node& node)
     parseValueOptional(node, PROXY_PUSH_TOKEN_KEY, deviceKey);
     parseValueOptional(node, PROXY_PUSH_PLATFORM_KEY, platform);
     parseValueOptional(node, PROXY_PUSH_TOPIC_KEY, notificationTopic);
+    parseValueOptional(node, UI_CUSTOMIZATION, uiCustomization);
 }
 
 std::map<std::string, std::string>
@@ -131,7 +138,9 @@ AccountConfig::toMap() const
             {Conf::CONFIG_ACCOUNT_MAILBOX, mailbox},
             {Conf::CONFIG_ACCOUNT_USERAGENT, customUserAgent},
             {Conf::CONFIG_ACCOUNT_AUTOANSWER, autoAnswerEnabled ? TRUE_STR : FALSE_STR},
+            {Conf::CONFIG_ACCOUNT_DENY_SECOND_CALL, denySecondCallEnabled ? TRUE_STR : FALSE_STR},
             {Conf::CONFIG_ACCOUNT_SENDREADRECEIPT, sendReadReceipt ? TRUE_STR : FALSE_STR},
+            {Conf::CONFIG_ACCOUNT_SENDCOMPOSING, sendComposing ? TRUE_STR : FALSE_STR},
             {Conf::CONFIG_ACCOUNT_ISRENDEZVOUS, isRendezVous ? TRUE_STR : FALSE_STR},
             {libjami::Account::ConfProperties::ACTIVE_CALL_LIMIT, std::to_string(activeCallLimit)},
             {Conf::CONFIG_RINGTONE_ENABLED, ringtoneEnabled ? TRUE_STR : FALSE_STR},
@@ -140,7 +149,8 @@ AccountConfig::toMap() const
             {Conf::CONFIG_UPNP_ENABLED, upnpEnabled ? TRUE_STR : FALSE_STR},
             {Conf::CONFIG_DEFAULT_MODERATORS, string_join(defaultModerators)},
             {Conf::CONFIG_LOCAL_MODERATORS_ENABLED, localModeratorsEnabled ? TRUE_STR : FALSE_STR},
-            {Conf::CONFIG_ALL_MODERATORS_ENABLED, allModeratorsEnabled ? TRUE_STR : FALSE_STR}};
+            {Conf::CONFIG_ALL_MODERATORS_ENABLED, allModeratorsEnabled ? TRUE_STR : FALSE_STR},
+            {Conf::CONFIG_ACCOUNT_UICUSTOMIZATION, uiCustomization}};
 }
 
 void
@@ -153,7 +163,9 @@ AccountConfig::fromMap(const std::map<std::string, std::string>& details)
     parseString(details, Conf::CONFIG_ACCOUNT_HOSTNAME, hostname);
     parseString(details, Conf::CONFIG_ACCOUNT_MAILBOX, mailbox);
     parseBool(details, Conf::CONFIG_ACCOUNT_AUTOANSWER, autoAnswerEnabled);
+    parseBool(details, Conf::CONFIG_ACCOUNT_DENY_SECOND_CALL, denySecondCallEnabled);
     parseBool(details, Conf::CONFIG_ACCOUNT_SENDREADRECEIPT, sendReadReceipt);
+    parseBool(details, Conf::CONFIG_ACCOUNT_SENDCOMPOSING, sendComposing);
     parseBool(details, Conf::CONFIG_ACCOUNT_ISRENDEZVOUS, isRendezVous);
     parseInt(details, libjami::Account::ConfProperties::ACTIVE_CALL_LIMIT, activeCallLimit);
     parseBool(details, Conf::CONFIG_RINGTONE_ENABLED, ringtoneEnabled);
@@ -169,17 +181,19 @@ AccountConfig::fromMap(const std::map<std::string, std::string>& details)
     parseString(details, libjami::Account::ConfProperties::PROXY_PUSH_TOKEN, deviceKey);
     parseString(details, PROXY_PUSH_PLATFORM_KEY, platform);
     parseString(details, PROXY_PUSH_TOPIC_KEY, notificationTopic);
+
+    parseString(details, Conf::CONFIG_ACCOUNT_UICUSTOMIZATION, uiCustomization);
 }
 
 void
 parsePath(const std::map<std::string, std::string>& details,
           const char* key,
           std::string& s,
-          const std::string& base)
+          const std::filesystem::path& base)
 {
     auto it = details.find(key);
     if (it != details.end())
-        s = fileutils::getFullPath(base, it->second);
+        s = fileutils::getFullPath(base, it->second).string();
 }
 
 } // namespace jami
