@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "call.h"
@@ -32,14 +27,15 @@
 #include "jami/call_const.h"
 #include "client/ring_signal.h"
 #include "connectivity/sip_utils.h"
-#include "connectivity/ip_utils.h"
 #include "map_utils.h"
 #include "call_factory.h"
 #include "string_utils.h"
 #include "enumclass_utils.h"
 
 #include "errno.h"
+#include "json_utils.h"
 
+#include <dhtnet/ip_utils.h>
 #include <opendht/thread_pool.h>
 
 #include <stdexcept>
@@ -86,9 +82,7 @@ Call::Call(const std::shared_ptr<Account>& account,
     , type_(type)
     , account_(account)
 {
-    addStateListener([this](Call::CallState call_state,
-                            Call::ConnectionState cnx_state,
-                            UNUSED int code) {
+    addStateListener([this](Call::CallState call_state, Call::ConnectionState cnx_state, int code) {
         checkPendingIM();
         runOnMainThread([callWkPtr = weak()] {
             if (auto call = callWkPtr.lock())
@@ -104,9 +98,8 @@ Call::Call(const std::shared_ptr<Account>& account,
                 [callWkPtr = weak()] {
                     if (auto callShPtr = callWkPtr.lock()) {
                         if (callShPtr->getConnectionState() == Call::ConnectionState::RINGING) {
-                            JAMI_DBG(
-                                "Call %s is still ringing after timeout, setting state to BUSY",
-                                callShPtr->getCallId().c_str());
+                            JAMI_DBG("Call %s is still ringing after timeout, setting state to BUSY",
+                                     callShPtr->getCallId().c_str());
                             callShPtr->hangup(PJSIP_SC_BUSY_HERE);
                             Manager::instance().callFailure(*callShPtr);
                         }
@@ -116,15 +109,16 @@ Call::Call(const std::shared_ptr<Account>& account,
         }
 
         if (!isSubcall()) {
+            if (code == static_cast<int>(std::errc::no_such_device_or_address)) {
+                reason_ = "no_device";
+            }
             if (cnx_state == ConnectionState::CONNECTED && duration_start_ == time_point::min())
                 duration_start_ = clock::now();
             else if (cnx_state == ConnectionState::DISCONNECTED && call_state == CallState::OVER) {
                 if (auto jamiAccount = std::dynamic_pointer_cast<JamiAccount>(getAccount().lock())) {
-                    // TODO: This will be removed when 1:1 swarm will have a conference.
-                    // For now, only commit for 1:1 calls
                     if (toUsername().find('/') == std::string::npos && getCallType() == CallType::OUTGOING) {
-                        jamiAccount->convModule()->addCallHistoryMessage(getPeerNumber(),
-                                                                         getCallDuration().count());
+                        if (auto cm = jamiAccount->convModule(true))
+                            cm->addCallHistoryMessage(getPeerNumber(), getCallDuration().count(), reason_);
                     }
                     monitor();
                 }
@@ -153,6 +147,8 @@ Call::removeCall()
         Recordable::stopRecording();
     if (auto account = account_.lock())
         account->detach(this_);
+    parent_.reset();
+    subcalls_.clear();
 }
 
 std::string
@@ -167,14 +163,14 @@ Call::getAccountId() const
 Call::ConnectionState
 Call::getConnectionState() const
 {
-    std::lock_guard<std::recursive_mutex> lock(callMutex_);
+    std::lock_guard lock(callMutex_);
     return connectionState_;
 }
 
 Call::CallState
 Call::getState() const
 {
-    std::lock_guard<std::recursive_mutex> lock(callMutex_);
+    std::lock_guard lock(callMutex_);
     return callState_;
 }
 
@@ -272,15 +268,9 @@ Call::setState(CallState call_state, ConnectionState cnx_state, signed code)
 
     if (old_client_state != new_client_state) {
         if (not parent_) {
-            JAMI_DBG("[call:%s] emit client call state change %s, code %d",
-                     id_.c_str(),
-                     new_client_state.c_str(),
-                     code);
+            JAMI_DBG("[call:%s] emit client call state change %s, code %d", id_.c_str(), new_client_state.c_str(), code);
             lock.unlock();
-            emitSignal<libjami::CallSignal::StateChange>(getAccountId(),
-                                                         id_,
-                                                         new_client_state,
-                                                         code);
+            emitSignal<libjami::CallSignal::StateChange>(getAccountId(), id_, new_client_state, code);
         }
     }
 
@@ -290,14 +280,14 @@ Call::setState(CallState call_state, ConnectionState cnx_state, signed code)
 bool
 Call::setState(CallState call_state, signed code)
 {
-    std::lock_guard<std::recursive_mutex> lock(callMutex_);
+    std::lock_guard lock(callMutex_);
     return setState(call_state, connectionState_, code);
 }
 
 bool
 Call::setState(ConnectionState cnx_state, signed code)
 {
-    std::lock_guard<std::recursive_mutex> lock(callMutex_);
+    std::lock_guard lock(callMutex_);
     return setState(callState_, cnx_state, code);
 }
 
@@ -377,10 +367,9 @@ Call::getDetails() const
         {libjami::Call::Details::CONF_ID, conference ? conference->getConfId() : ""},
         {libjami::Call::Details::TIMESTAMP_START, std::to_string(timestamp_start_)},
         {libjami::Call::Details::ACCOUNTID, getAccountId()},
-        {libjami::Call::Details::AUDIO_MUTED,
-         std::string(bool_to_str(isCaptureDeviceMuted(MediaType::MEDIA_AUDIO)))},
-        {libjami::Call::Details::VIDEO_MUTED,
-         std::string(bool_to_str(isCaptureDeviceMuted(MediaType::MEDIA_VIDEO)))},
+        {libjami::Call::Details::TO_USERNAME, toUsername()},
+        {libjami::Call::Details::AUDIO_MUTED, std::string(bool_to_str(isCaptureDeviceMuted(MediaType::MEDIA_AUDIO)))},
+        {libjami::Call::Details::VIDEO_MUTED, std::string(bool_to_str(isCaptureDeviceMuted(MediaType::MEDIA_VIDEO)))},
         {libjami::Call::Details::AUDIO_ONLY, std::string(bool_to_str(not hasVideo()))},
     };
 }
@@ -402,7 +391,7 @@ Call::onTextMessage(std::map<std::string, std::string>&& messages)
     }
 
     {
-        std::lock_guard<std::recursive_mutex> lk {callMutex_};
+        std::lock_guard lk {callMutex_};
         if (parent_) {
             pendingInMessages_.emplace_back(std::move(messages), "");
             return;
@@ -429,13 +418,13 @@ Call::peerHungup()
 void
 Call::addSubCall(Call& subcall)
 {
-    std::lock_guard<std::recursive_mutex> lk {callMutex_};
+    std::lock_guard lk {callMutex_};
 
     // Add subCall only if call is not connected or terminated
     // Because we only want to addSubCall if the peer didn't answer
     // So till it's <= RINGING
-    if (connectionState_ == ConnectionState::CONNECTED
-        || connectionState_ == ConnectionState::DISCONNECTED || callState_ == CallState::OVER) {
+    if (connectionState_ == ConnectionState::CONNECTED || connectionState_ == ConnectionState::DISCONNECTED
+        || callState_ == CallState::OVER) {
         subcall.removeCall();
         return;
     }
@@ -451,19 +440,18 @@ Call::addSubCall(Call& subcall)
     for (const auto& msg : pendingOutMessages_)
         subcall.sendTextMessage(msg.first, msg.second);
 
-    subcall.addStateListener(
-        [sub = subcall.weak(), parent = weak()](Call::CallState new_state,
-                                                Call::ConnectionState new_cstate,
-                                                int /* code */) {
-            runOnMainThread([sub, parent, new_state, new_cstate]() {
-                if (auto p = parent.lock()) {
-                    if (auto s = sub.lock()) {
-                        p->subcallStateChanged(*s, new_state, new_cstate);
-                    }
+    subcall.addStateListener([sub = subcall.weak(), parent = weak()](Call::CallState new_state,
+                                                                     Call::ConnectionState new_cstate,
+                                                                     int /* code */) {
+        runOnMainThread([sub, parent, new_state, new_cstate]() {
+            if (auto p = parent.lock()) {
+                if (auto s = sub.lock()) {
+                    p->subcallStateChanged(*s, new_state, new_cstate);
                 }
-            });
-            return true;
+            }
         });
+        return true;
+    });
 }
 
 /// Called by a subcall when its states change (multidevice)
@@ -479,7 +467,7 @@ Call::subcallStateChanged(Call& subcall, Call::CallState new_state, Call::Connec
         // This is normal to keep parent_ != nullptr on the subcall, as it's the way to flag it
         // as an subcall and not a master call.
         // XXX: having a way to unsubscribe the state listener could be better than such test
-        std::lock_guard<std::recursive_mutex> lk {callMutex_};
+        std::lock_guard lk {callMutex_};
         auto sit = subcalls_.find(getPtr(subcall));
         if (sit == subcalls_.end())
             return;
@@ -487,9 +475,7 @@ Call::subcallStateChanged(Call& subcall, Call::CallState new_state, Call::Connec
 
     // We found a responding device: hangup all other subcalls and merge
     if (new_state == CallState::ACTIVE and new_cstate == ConnectionState::CONNECTED) {
-        JAMI_DBG("[call:%s] subcall %s answered by peer",
-                 getCallId().c_str(),
-                 subcall.getCallId().c_str());
+        JAMI_DBG("[call:%s] subcall %s answered by peer", getCallId().c_str(), subcall.getCallId().c_str());
 
         hangupCallsIf(safePopSubcalls(), 0, [&](const Call* call) { return call != &subcall; });
         merge(subcall);
@@ -500,10 +486,8 @@ Call::subcallStateChanged(Call& subcall, Call::CallState new_state, Call::Connec
     // Hangup the call if any device hangup or send busy
     if ((new_state == CallState::ACTIVE or new_state == CallState::PEER_BUSY)
         and new_cstate == ConnectionState::DISCONNECTED) {
-        JAMI_WARN("[call:%s] subcall %s hangup by peer",
-                  getCallId().c_str(),
-                  subcall.getCallId().c_str());
-
+        JAMI_WARN("[call:%s] subcall %s hangup by peer", getCallId().c_str(), subcall.getCallId().c_str());
+        reason_ = new_state == CallState::ACTIVE ? "declined" : "busy";
         hangupCalls(safePopSubcalls(), 0);
         Manager::instance().peerHungupCall(*this);
         removeCall();
@@ -515,10 +499,8 @@ Call::subcallStateChanged(Call& subcall, Call::CallState new_state, Call::Connec
         if (new_state == CallState::BUSY || new_state == CallState::PEER_BUSY)
             JAMI_WARN("[call:%s] subcall %s busy", getCallId().c_str(), subcall.getCallId().c_str());
         else
-            JAMI_WARN("[call:%s] subcall %s failed",
-                      getCallId().c_str(),
-                      subcall.getCallId().c_str());
-        std::lock_guard<std::recursive_mutex> lk {callMutex_};
+            JAMI_WARN("[call:%s] subcall %s failed", getCallId().c_str(), subcall.getCallId().c_str());
+        std::lock_guard lk {callMutex_};
         subcalls_.erase(getPtr(subcall));
 
         // Parent call fails if last subcall is busy or failed
@@ -534,9 +516,7 @@ Call::subcallStateChanged(Call& subcall, Call::CallState new_state, Call::Connec
             } else {
                 // XXX: first idea was to use std::errc::host_unreachable, but it's not available on
                 // some platforms like mingw.
-                setState(CallState::MERROR,
-                         ConnectionState::DISCONNECTED,
-                         static_cast<int>(std::errc::io_error));
+                setState(CallState::MERROR, ConnectionState::DISCONNECTED, static_cast<int>(std::errc::io_error));
             }
             removeCall();
         } else {
@@ -583,17 +563,14 @@ Call::merge(Call& subcall)
 void
 Call::checkPendingIM()
 {
-    std::lock_guard<std::recursive_mutex> lk {callMutex_};
+    std::lock_guard lk {callMutex_};
 
     auto state = getStateStr();
     // Let parent call handles IM after the merge
     if (not parent_) {
         if (state == libjami::Call::StateEvent::CURRENT) {
             for (const auto& msg : pendingInMessages_)
-                Manager::instance().incomingMessage(getAccountId(),
-                                                    getCallId(),
-                                                    getPeerNumber(),
-                                                    msg.first);
+                Manager::instance().incomingMessage(getAccountId(), getCallId(), getPeerNumber(), msg.first);
             pendingInMessages_.clear();
 
             std::weak_ptr<Call> callWkPtr = shared_from_this();
@@ -625,7 +602,7 @@ Call::checkAudio()
 Call::SubcallSet
 Call::safePopSubcalls()
 {
-    std::lock_guard<std::recursive_mutex> lk {callMutex_};
+    std::lock_guard lk {callMutex_};
     // std::exchange is C++14
     auto old_value = std::move(subcalls_);
     subcalls_.clear();
@@ -637,10 +614,7 @@ Call::setConferenceInfo(const std::string& msg)
 {
     ConfInfo newInfo;
     Json::Value json;
-    std::string err;
-    Json::CharReaderBuilder rbuilder;
-    auto reader = std::unique_ptr<Json::CharReader>(rbuilder.newCharReader());
-    if (reader->parse(msg.data(), msg.data() + msg.size(), &json, &err)) {
+    if (json::parse(msg, json)) {
         if (json.isObject()) {
             // new confInfo
             if (json.isMember("p")) {
@@ -673,7 +647,7 @@ Call::setConferenceInfo(const std::string& msg)
     }
 
     {
-        std::lock_guard<std::mutex> lk(confInfoMutex_);
+        std::lock_guard lk(confInfoMutex_);
         if (not isConferenceParticipant()) {
             // confID_ empty -> participant set confInfo with the received one
             confInfo_ = std::move(newInfo);
@@ -683,8 +657,7 @@ Call::setConferenceInfo(const std::string& msg)
             createSinks(confInfo_);
 #endif
             // Inform client that layout has changed
-            jami::emitSignal<libjami::CallSignal::OnConferenceInfosUpdated>(
-                id_, confInfo_.toVectorMapStringString());
+            jami::emitSignal<libjami::CallSignal::OnConferenceInfosUpdated>(id_, confInfo_.toVectorMapStringString());
         } else if (auto conf = conf_.lock()) {
             conf->mergeConfInfo(newInfo, getPeerNumber());
         }
@@ -695,10 +668,7 @@ void
 Call::sendConfOrder(const Json::Value& root)
 {
     std::map<std::string, std::string> messages;
-    Json::StreamWriterBuilder wbuilder;
-    wbuilder["commentStyle"] = "None";
-    wbuilder["indentation"] = "";
-    messages["application/confOrder+json"] = Json::writeString(wbuilder, root);
+    messages["application/confOrder+json"] = json::toString(root);
 
     auto w = getAccount();
     auto account = w.lock();
@@ -710,9 +680,6 @@ void
 Call::sendConfInfo(const std::string& json)
 {
     std::map<std::string, std::string> messages;
-    Json::StreamWriterBuilder wbuilder;
-    wbuilder["commentStyle"] = "None";
-    wbuilder["indentation"] = "";
     messages["application/confInfo+json"] = json;
 
     auto w = getAccount();
