@@ -1,26 +1,19 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #ifdef HAVE_CONFIG_H
@@ -89,30 +82,14 @@ public:
      *
      * \note modify validStateTransition/getStateStr if this enum changes
      */
-    enum class ConnectionState : unsigned {
-        DISCONNECTED,
-        TRYING,
-        PROGRESSING,
-        RINGING,
-        CONNECTED,
-        COUNT__
-    };
+    enum class ConnectionState : unsigned { DISCONNECTED, TRYING, PROGRESSING, RINGING, CONNECTED, COUNT__ };
 
     /**
      * The Call State.
      *
      * \note modify validStateTransition/getStateStr if this enum changes
      */
-    enum class CallState : unsigned {
-        INACTIVE,
-        ACTIVE,
-        HOLD,
-        BUSY,
-        PEER_BUSY,
-        MERROR,
-        OVER,
-        COUNT__
-    };
+    enum class CallState : unsigned { INACTIVE, ACTIVE, HOLD, BUSY, PEER_BUSY, MERROR, OVER, COUNT__ };
 
     enum class LinkType { GENERIC, SIP };
 
@@ -273,9 +250,7 @@ public:
      * to determine wether an answer will be sent to the peer.
      * @param isRemote      True if the media list is from the remote peer
      */
-    virtual void answerMediaChangeRequest(const std::vector<libjami::MediaMap>& mediaList,
-                                          bool isRemote = false)
-        = 0;
+    virtual void answerMediaChangeRequest(const std::vector<libjami::MediaMap>& mediaList, bool isRemote = false) = 0;
     /**
      * Hang up the call
      * @param reason
@@ -362,8 +337,7 @@ public:
     {
         return duration_start_ == time_point::min()
                    ? std::chrono::milliseconds::zero()
-                   : std::chrono::duration_cast<std::chrono::milliseconds>(clock::now()
-                                                                           - duration_start_);
+                   : std::chrono::duration_cast<std::chrono::milliseconds>(clock::now() - duration_start_);
     }
 
     // media management
@@ -411,20 +385,12 @@ public:
      * @param A list of mimetype/payload pairs
      * @param The sender of this message (could be another participant of a conference)
      */
-    virtual void sendTextMessage(const std::map<std::string, std::string>& messages,
-                                 const std::string& from)
-        = 0;
+    virtual void sendTextMessage(const std::map<std::string, std::string>& messages, const std::string& from) = 0;
 
     void onTextMessage(std::map<std::string, std::string>&& messages);
 
-    virtual std::shared_ptr<SystemCodecInfo> getAudioCodec() const
-    {
-        return {};
-    }
-    virtual std::shared_ptr<SystemCodecInfo> getVideoCodec() const
-    {
-        return {};
-    }
+    virtual std::shared_ptr<SystemCodecInfo> getAudioCodec() const { return {}; }
+    virtual std::shared_ptr<SystemCodecInfo> getVideoCodec() const { return {}; }
 
     virtual void restartMediaSender() = 0;
 
@@ -434,7 +400,7 @@ public:
 
     /**
      * A Call can be in a conference. If this is the case, the other side
-     * will send conference informations describing the rendered image
+     * will send conference information describing the rendered image
      * @msg     A JSON object describing the conference
      */
     void setConferenceInfo(const std::string& msg);
@@ -454,10 +420,7 @@ public:
 
     virtual void monitor() const = 0;
 
-    int conferenceProtocolVersion() const
-    {
-        return peerConfProtocol_;
-    }
+    int conferenceProtocolVersion() const { return peerConfProtocol_; }
 
 protected:
     using clock = std::chrono::steady_clock;
@@ -526,6 +489,8 @@ protected:
     /** Inactive/Active/Hold/Busy/Error */
     CallState callState_ {CallState::INACTIVE};
 
+    std::string reason_ {};
+
     /** Direct IP-to-IP or classic call */
     bool isIPToIP_ {false};
 
