@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Guillaume Carmel-Archambault <guillaume.carmel-archambault@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "videomanager_interface.h"
@@ -113,9 +108,7 @@ AudioFrame::setFormat(const jami::AudioFormat& format)
 jami::AudioFormat
 AudioFrame::getFormat() const
 {
-    return {(unsigned) frame_->sample_rate,
-            (unsigned) frame_->ch_layout.nb_channels,
-            (AVSampleFormat) frame_->format};
+    return {(unsigned) frame_->sample_rate, (unsigned) frame_->ch_layout.nb_channels, (AVSampleFormat) frame_->format};
 }
 
 size_t
@@ -142,14 +135,15 @@ AudioFrame::mix(const AudioFrame& frame)
 {
     auto& f = *pointer();
     auto& fIn = *frame.pointer();
-    if (f.ch_layout.nb_channels != fIn.ch_layout.nb_channels || f.format != fIn.format || f.sample_rate != fIn.sample_rate) {
-        throw std::invalid_argument("Can't mix frames with different formats");
+    if (f.ch_layout.nb_channels != fIn.ch_layout.nb_channels || f.format != fIn.format
+        || f.sample_rate != fIn.sample_rate) {
+        throw std::invalid_argument("Unable to mix frames with different formats");
     }
     if (f.nb_samples == 0) {
         reserve(fIn.nb_samples);
         jami::libav_utils::fillWithSilence(&f);
     } else if (f.nb_samples != fIn.nb_samples) {
-        throw std::invalid_argument("Can't mix frames with different length");
+        throw std::invalid_argument("Unable to mix frames with different length");
     }
     AVSampleFormat fmt = (AVSampleFormat) f.format;
     bool isPlanar = av_sample_fmt_is_planar(fmt);
@@ -174,8 +168,7 @@ AudioFrame::mix(const AudioFrame& frame)
             }
         }
     } else {
-        throw std::invalid_argument(std::string("Unsupported format for mixing: ")
-                                    + av_get_sample_fmt_name(fmt));
+        throw std::invalid_argument(std::string("Unsupported format for mixing: ") + av_get_sample_fmt_name(fmt));
     }
 }
 
@@ -204,8 +197,7 @@ AudioFrame::calcRMS() const
         }
     } else {
         // Should not happen
-        JAMI_ERR() << "Unsupported format for getting volume level: "
-                   << av_get_sample_fmt_name(fmt);
+        JAMI_ERR() << "Unsupported format for getting volume level: " << av_get_sample_fmt_name(fmt);
         return 0.0;
     }
     // divide by the number of multi-byte samples
@@ -239,10 +231,7 @@ VideoFrame::copyFrom(const VideoFrame& o)
 size_t
 VideoFrame::size() const noexcept
 {
-    return av_image_get_buffer_size((AVPixelFormat) frame_->format,
-                                    frame_->width,
-                                    frame_->height,
-                                    1);
+    return av_image_get_buffer_size((AVPixelFormat) frame_->format, frame_->width, frame_->height, 1);
 }
 
 int
@@ -278,8 +267,7 @@ VideoFrame::reserve(int format, int width, int height)
 
     if (allocated_) {
         // nothing to do if same properties
-        if (width == libav_frame->width and height == libav_frame->height
-            and format == libav_frame->format)
+        if (width == libav_frame->width and height == libav_frame->height and format == libav_frame->format)
             av_frame_unref(libav_frame);
     }
 
@@ -307,11 +295,8 @@ VideoFrame::setFromMemory(uint8_t* ptr, int format, int width, int height) noexc
 }
 
 void
-VideoFrame::setFromMemory(uint8_t* ptr,
-                          int format,
-                          int width,
-                          int height,
-                          const std::function<void(uint8_t*)>& cb) noexcept
+VideoFrame::setFromMemory(
+    uint8_t* ptr, int format, int width, int height, const std::function<void(uint8_t*)>& cb) noexcept
 {
     setFromMemory(ptr, format, width, height);
     if (cb) {
@@ -344,8 +329,7 @@ VideoFrame::getOrientation() const
 {
     int32_t* matrix {nullptr};
     if (auto p = packet()) {
-        matrix = reinterpret_cast<int32_t*>(
-            av_packet_get_side_data(p, AV_PKT_DATA_DISPLAYMATRIX, nullptr));
+        matrix = reinterpret_cast<int32_t*>(av_packet_get_side_data(p, AV_PKT_DATA_DISPLAYMATRIX, nullptr));
     } else if (auto p = pointer()) {
         if (AVFrameSideData* side_data = av_frame_get_side_data(p, AV_FRAME_DATA_DISPLAYMATRIX)) {
             matrix = reinterpret_cast<int32_t*>(side_data->data);
@@ -361,18 +345,19 @@ VideoFrame::getOrientation() const
 VideoFrame*
 getNewFrame(std::string_view id)
 {
-    if (auto input = jami::Manager::instance().getVideoManager().getVideoInput(id))
-        return &input->getNewFrame();
-    JAMI_WARN("getNewFrame: can't find input %.*s", (int) id.size(), id.data());
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        if (auto input = vm->getVideoInput(id))
+            return &input->getNewFrame();
+    JAMI_WARNING("getNewFrame: Unable to find input {}", id);
     return nullptr;
 }
 
 void
 publishFrame(std::string_view id)
 {
-    if (auto input = jami::Manager::instance().getVideoManager().getVideoInput(id))
-        return input->publishFrame();
-    JAMI_WARN("publishFrame: can't find input %.*s", (int) id.size(), id.data());
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        if (auto input = vm->getVideoInput(id))
+            input->publishFrame();
 }
 
 void
@@ -384,96 +369,113 @@ registerVideoHandlers(const std::map<std::string, std::shared_ptr<CallbackWrappe
 std::vector<std::string>
 getDeviceList()
 {
-    return jami::Manager::instance().getVideoManager().videoDeviceMonitor.getDeviceList();
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        return vm->videoDeviceMonitor.getDeviceList();
+    return {};
 }
 
 VideoCapabilities
 getCapabilities(const std::string& deviceId)
 {
-    return jami::Manager::instance().getVideoManager().videoDeviceMonitor.getCapabilities(deviceId);
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        return vm->videoDeviceMonitor.getCapabilities(deviceId);
+    return {};
 }
 
 std::string
 getDefaultDevice()
 {
-    return jami::Manager::instance().getVideoManager().videoDeviceMonitor.getDefaultDevice();
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        return vm->videoDeviceMonitor.getDefaultDevice();
+    return {};
 }
 
 void
 setDefaultDevice(const std::string& deviceId)
 {
     JAMI_DBG("Setting default device to %s", deviceId.c_str());
-    if (jami::Manager::instance().getVideoManager().videoDeviceMonitor.setDefaultDevice(deviceId))
-        jami::Manager::instance().saveConfig();
+    if (auto vm = jami::Manager::instance().getVideoManager()) {
+        if (vm->videoDeviceMonitor.setDefaultDevice(deviceId))
+            jami::Manager::instance().saveConfig();
+    }
 }
 
 void
 setDeviceOrientation(const std::string& deviceId, int angle)
 {
-    jami::Manager::instance().getVideoManager().setDeviceOrientation(deviceId, angle);
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        vm->setDeviceOrientation(deviceId, angle);
 }
 
 std::map<std::string, std::string>
 getDeviceParams(const std::string& deviceId)
 {
-    auto params = jami::Manager::instance().getVideoManager().videoDeviceMonitor.getDeviceParams(
-        deviceId);
-    std::ostringstream rate;
-    rate << params.framerate;
-    return {{"format", params.format},
-            {"width", std::to_string(params.width)},
-            {"height", std::to_string(params.height)},
-            {"rate", rate.str()}};
+    if (auto vm = jami::Manager::instance().getVideoManager()) {
+        auto params = vm->videoDeviceMonitor.getDeviceParams(deviceId);
+        return {{"format", params.format},
+                {"width", std::to_string(params.width)},
+                {"height", std::to_string(params.height)},
+                {"rate", params.framerate.to_string()}};
+    }
+    return {};
 }
 
 std::map<std::string, std::string>
 getSettings(const std::string& deviceId)
 {
-    return jami::Manager::instance()
-        .getVideoManager()
-        .videoDeviceMonitor.getSettings(deviceId)
-        .to_map();
+    if (auto vm = jami::Manager::instance().getVideoManager()) {
+        return vm->videoDeviceMonitor.getSettings(deviceId).to_map();
+    }
+    return {};
 }
 
 void
 applySettings(const std::string& deviceId, const std::map<std::string, std::string>& settings)
 {
-    jami::Manager::instance().getVideoManager().videoDeviceMonitor.applySettings(deviceId, settings);
-    jami::Manager::instance().saveConfig();
+    if (auto vm = jami::Manager::instance().getVideoManager()) {
+        vm->videoDeviceMonitor.applySettings(deviceId, settings);
+        jami::Manager::instance().saveConfig();
+    }
 }
 
 std::string
 openVideoInput(const std::string& path)
 {
-    auto& vm = jami::Manager::instance().getVideoManager();
-
-    auto id = path.empty() ? vm.videoDeviceMonitor.getMRLForDefaultDevice() : path;
-    auto& input = vm.clientVideoInputs[id];
-    if (not input) {
-        input = jami::getVideoInput(id);
+    if (auto vm = jami::Manager::instance().getVideoManager()) {
+        auto id = path.empty() ? vm->videoDeviceMonitor.getMRLForDefaultDevice() : path;
+        auto& input = vm->clientVideoInputs[id];
+        if (not input) {
+            input = jami::getVideoInput(id);
+        }
+        return id;
     }
-    return id;
+    return {};
 }
 
 bool
 closeVideoInput(const std::string& id)
 {
-    return jami::Manager::instance().getVideoManager().clientVideoInputs.erase(id) > 0;
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        return vm->clientVideoInputs.erase(id) > 0;
+    return false;
 }
 #endif
 
 void
 startAudioDevice()
 {
-    auto newPreview = jami::getAudioInput(jami::RingBufferPool::DEFAULT_ID);
-    jami::Manager::instance().getVideoManager().audioPreview = newPreview;
-    newPreview->switchInput("");
+    if (auto newPreview = jami::getAudioInput(jami::RingBufferPool::DEFAULT_ID)) {
+        if (auto vm = jami::Manager::instance().getVideoManager())
+            vm->audioPreview = newPreview;
+        newPreview->switchInput("");
+    }
 }
 
 void
 stopAudioDevice()
 {
-    jami::Manager::instance().getVideoManager().audioPreview.reset();
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        vm->audioPreview.reset();
 }
 
 std::string
@@ -493,7 +495,7 @@ startLocalMediaRecorder(const std::string& videoInputId, const std::string& file
         return "";
     }
 
-    auto ret = recordManager.getRecorderByPath(path)->startRecording();
+    auto ret = recordManager.getRecorderByPath(path)->start();
     if (!ret) {
         recordManager.removeRecorderByPath(filepath);
         return "";
@@ -507,7 +509,7 @@ stopLocalRecorder(const std::string& filepath)
 {
     jami::LocalRecorder* rec = jami::LocalRecorderManager::instance().getRecorderByPath(filepath);
     if (!rec) {
-        JAMI_WARN("Can't stop non existing local recorder.");
+        JAMI_WARN("Unable to stop non existing local recorder.");
         return;
     }
 
@@ -568,12 +570,6 @@ createMediaPlayer(const std::string& path)
     return jami::createMediaPlayer(path);
 }
 
-bool
-pausePlayer(const std::string& id, bool pause)
-{
-    return jami::pausePlayer(id, pause);
-}
-
 bool
 closeMediaPlayer(const std::string& id)
 {
@@ -581,13 +577,19 @@ closeMediaPlayer(const std::string& id)
 }
 
 bool
-mutePlayerAudio(const std::string& id, bool mute)
+pausePlayer(const std::string& id, const bool& pause)
+{
+    return jami::pausePlayer(id, pause);
+}
+
+bool
+mutePlayerAudio(const std::string& id, const bool& mute)
 {
     return jami::mutePlayerAudio(id, mute);
 }
 
 bool
-playerSeekToTime(const std::string& id, int time)
+playerSeekToTime(const std::string& id, const int& time)
 {
     return jami::playerSeekToTime(id, time);
 }
@@ -598,10 +600,22 @@ getPlayerPosition(const std::string& id)
     return jami::getPlayerPosition(id);
 }
 
+int64_t
+getPlayerDuration(const std::string& id)
+{
+    return jami::getPlayerDuration(id);
+}
+
+void
+setAutoRestart(const std::string& id, const bool& restart)
+{
+    jami::setAutoRestart(id, restart);
+}
+
 bool
 getDecodingAccelerated()
 {
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     return jami::Manager::instance().videoPreferences.getDecodingAccelerated();
 #else
     return false;
@@ -611,7 +625,7 @@ getDecodingAccelerated()
 void
 setDecodingAccelerated(bool state)
 {
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     JAMI_DBG("%s hardware acceleration", (state ? "Enabling" : "Disabling"));
     if (jami::Manager::instance().videoPreferences.setDecodingAccelerated(state))
         jami::Manager::instance().saveConfig();
@@ -621,7 +635,7 @@ setDecodingAccelerated(bool state)
 bool
 getEncodingAccelerated()
 {
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     return jami::Manager::instance().videoPreferences.getEncodingAccelerated();
 #else
     return false;
@@ -631,7 +645,7 @@ getEncodingAccelerated()
 void
 setEncodingAccelerated(bool state)
 {
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     JAMI_DBG("%s hardware acceleration", (state ? "Enabling" : "Disabling"));
     if (jami::Manager::instance().videoPreferences.setEncodingAccelerated(state))
         jami::Manager::instance().saveConfig();
@@ -649,18 +663,21 @@ setEncodingAccelerated(bool state)
     }
 }
 
-#if defined(__ANDROID__) || defined(RING_UWP) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
+#if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
 void
-addVideoDevice(const std::string& node,
-               const std::vector<std::map<std::string, std::string>>& devInfo)
+addVideoDevice(const std::string& node, const std::vector<std::map<std::string, std::string>>& devInfo)
 {
-    jami::Manager::instance().getVideoManager().videoDeviceMonitor.addDevice(node, devInfo);
+    if (auto videoManager = jami::Manager::instance().getVideoManager()) {
+        videoManager->videoDeviceMonitor.addDevice(node, devInfo);
+    }
 }
 
 void
 removeVideoDevice(const std::string& node)
 {
-    jami::Manager::instance().getVideoManager().videoDeviceMonitor.removeDevice(node);
+    if (auto videoManager = jami::Manager::instance().getVideoManager()) {
+        videoManager->videoDeviceMonitor.removeDevice(node);
+    }
 }
 #endif
 
@@ -669,26 +686,31 @@ removeVideoDevice(const std::string& node)
 namespace jami {
 
 #ifdef ENABLE_VIDEO
-video::VideoDeviceMonitor&
+video::VideoDeviceMonitor*
 getVideoDeviceMonitor()
 {
-    return Manager::instance().getVideoManager().videoDeviceMonitor;
+    if (auto vm = jami::Manager::instance().getVideoManager())
+        return &vm->videoDeviceMonitor;
+    return {};
 }
 
 std::shared_ptr<video::VideoInput>
-getVideoInput(const std::string& id, video::VideoInputMode inputMode)
+getVideoInput(const std::string& resource, video::VideoInputMode inputMode, const std::string& sink)
 {
-    auto& vmgr = Manager::instance().getVideoManager();
-    std::lock_guard<std::mutex> lk(vmgr.videoMutex);
-    auto it = vmgr.videoInputs.find(id);
-    if (it != vmgr.videoInputs.end()) {
+    auto sinkId = sink.empty() ? resource : sink;
+    auto vmgr = Manager::instance().getVideoManager();
+    if (!vmgr)
+        return {};
+    std::lock_guard<std::mutex> lk(vmgr->videoMutex);
+    auto it = vmgr->videoInputs.find(sinkId);
+    if (it != vmgr->videoInputs.end()) {
         if (auto input = it->second.lock()) {
             return input;
         }
     }
 
-    auto input = std::make_shared<video::VideoInput>(inputMode, id);
-    vmgr.videoInputs[id] = input;
+    auto input = std::make_shared<video::VideoInput>(inputMode, resource, sinkId);
+    vmgr->videoInputs[sinkId] = input;
     return input;
 }
 
@@ -700,45 +722,49 @@ VideoManager::setDeviceOrientation(const std::string& deviceId, int angle)
 #endif
 
 std::shared_ptr<AudioInput>
-getAudioInput(const std::string& id)
+getAudioInput(const std::string& device)
 {
-    auto& vmgr = Manager::instance().getVideoManager();
-    std::lock_guard<std::mutex> lk(vmgr.audioMutex);
+    auto vmgr = Manager::instance().getVideoManager();
+    if (!vmgr)
+        return {};
+    std::lock_guard<std::mutex> lk(vmgr->audioMutex);
 
     // erase expired audio inputs
-    for (auto it = vmgr.audioInputs.cbegin(); it != vmgr.audioInputs.cend();) {
+    for (auto it = vmgr->audioInputs.cbegin(); it != vmgr->audioInputs.cend();) {
         if (it->second.expired())
-            it = vmgr.audioInputs.erase(it);
+            it = vmgr->audioInputs.erase(it);
         else
             ++it;
     }
 
-    auto it = vmgr.audioInputs.find(id);
-    if (it != vmgr.audioInputs.end()) {
+    auto it = vmgr->audioInputs.find(device);
+    if (it != vmgr->audioInputs.end()) {
         if (auto input = it->second.lock()) {
             return input;
         }
     }
 
-    auto input = std::make_shared<AudioInput>(id);
-    vmgr.audioInputs[id] = input;
+    auto input = std::make_shared<AudioInput>(device);
+    vmgr->audioInputs[device] = input;
     return input;
 }
 
 bool
 VideoManager::hasRunningPlayers()
 {
-    auto& vmgr = Manager::instance().getVideoManager();
-    return !vmgr.mediaPlayers.empty();
+    if (auto vmgr = Manager::instance().getVideoManager())
+        return !vmgr->mediaPlayers.empty();
+    return false;
 }
 
 std::shared_ptr<MediaPlayer>
 getMediaPlayer(const std::string& id)
 {
-    auto& vmgr = Manager::instance().getVideoManager();
-    auto it = vmgr.mediaPlayers.find(id);
-    if (it != vmgr.mediaPlayers.end()) {
-        return it->second;
+    if (auto vmgr = Manager::instance().getVideoManager()) {
+        auto it = vmgr->mediaPlayers.find(id);
+        if (it != vmgr->mediaPlayers.end()) {
+            return it->second;
+        }
     }
     return {};
 }
@@ -746,13 +772,14 @@ getMediaPlayer(const std::string& id)
 std::string
 createMediaPlayer(const std::string& path)
 {
-    auto player = std::make_shared<MediaPlayer>(path);
-    if (!player->isInputValid()) {
-        return "";
+    if (auto vmgr = Manager::instance().getVideoManager()) {
+        auto& player = vmgr->mediaPlayers[path];
+        if (!player) {
+            player = std::make_shared<MediaPlayer>(path);
+        }
+        return path;
     }
-    auto playerId = player.get()->getId();
-    Manager::instance().getVideoManager().mediaPlayers[playerId] = player;
-    return playerId;
+    return {};
 }
 
 bool
@@ -768,7 +795,9 @@ pausePlayer(const std::string& id, bool pause)
 bool
 closeMediaPlayer(const std::string& id)
 {
-    return Manager::instance().getVideoManager().mediaPlayers.erase(id) > 0;
+    if (auto vm = Manager::instance().getVideoManager())
+        return vm->mediaPlayers.erase(id) > 0;
+    return false;
 }
 
 bool
@@ -797,4 +826,19 @@ getPlayerPosition(const std::string& id)
     return -1;
 }
 
+int64_t
+getPlayerDuration(const std::string& id)
+{
+    if (auto player = getMediaPlayer(id))
+        return player->getPlayerDuration();
+    return -1;
+}
+
+void
+setAutoRestart(const std::string& id, bool restart)
+{
+    if (auto player = getMediaPlayer(id))
+        player->setAutoRestart(restart);
+}
+
 } // namespace jami
