@@ -1,26 +1,19 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Alexandre Lision <alexandre.lision@savoirfairelinux.com>
- *  Author: Vittorio Giovara <vittorio.giovara@savoirfairelinux.com>
- *  Author: Emmanuel Lepage <emmanuel.lepage@savoirfairelinux.com>
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #include "enumclass_utils.h"
@@ -80,33 +73,33 @@ public:
      *
      */
     enum class CertificateCheck {
-        HAS_PRIVATE_KEY, /** This certificate has a build in private key                          */
-        EXPIRED,         /** This certificate is past its expiration date                         */
-        STRONG_SIGNING,  /** This certificate has been signed with a brute-force-able method      */
-        NOT_SELF_SIGNED, /** This certificate has been self signed                                */
-        KEY_MATCH,       /** The public and private keys provided don't match                     */
-        PRIVATE_KEY_STORAGE_PERMISSION, /** The file hosting the private key isn't correctly secured */
-        PUBLIC_KEY_STORAGE_PERMISSION, /** The file hosting the public key isn't correctly secured */
+        HAS_PRIVATE_KEY,                   /** This certificate has a build in private key                          */
+        EXPIRED,                           /** This certificate is past its expiration date                         */
+        STRONG_SIGNING,                    /** This certificate has been signed with a brute-force-able method      */
+        NOT_SELF_SIGNED,                   /** This certificate has been self signed                                */
+        KEY_MATCH,                         /** The public and private keys provided don't match                     */
+        PRIVATE_KEY_STORAGE_PERMISSION,    /** The file hosting the private key isn't correctly secured */
+        PUBLIC_KEY_STORAGE_PERMISSION,     /** The file hosting the public key isn't correctly secured */
         PRIVATE_KEY_DIRECTORY_PERMISSIONS, /** The folder storing the private key isn't correctly
                                               secured           */
         PUBLIC_KEY_DIRECTORY_PERMISSIONS,  /** The folder storing the public key isn't correctly
                                               secured            */
-        PRIVATE_KEY_STORAGE_LOCATION, /** Some operating systems have extra policies for certificate
-                                         storage   */
-        PUBLIC_KEY_STORAGE_LOCATION,  /** Some operating systems have extra policies for certificate
-                                         storage   */
-        PRIVATE_KEY_SELINUX_ATTRIBUTES, /** Some operating systems require keys to have extra
-                                           attributes         */
-        PUBLIC_KEY_SELINUX_ATTRIBUTES,  /** Some operating systems require keys to have extra
-                                           attributes         */
-        EXIST,           /** The certificate file doesn't exist or is not accessible              */
-        VALID,           /** The file is not a certificate                                        */
-        VALID_AUTHORITY, /** The claimed authority did not sign the certificate                   */
-        KNOWN_AUTHORITY, /** Some operating systems provide a list of trusted authorities, use it */
-        NOT_REVOKED,     /** The certificate has been revoked by the authority                    */
-        AUTHORITY_MISMATCH, /** The certificate and authority mismatch */
-        UNEXPECTED_OWNER,   /** The certificate has an expected owner   */
-        NOT_ACTIVATED, /** The certificate has not been activated yet                           */
+        PRIVATE_KEY_STORAGE_LOCATION,      /** Some operating systems have extra policies for certificate
+                                              storage   */
+        PUBLIC_KEY_STORAGE_LOCATION,       /** Some operating systems have extra policies for certificate
+                                              storage   */
+        PRIVATE_KEY_SELINUX_ATTRIBUTES,    /** Some operating systems require keys to have extra
+                                              attributes         */
+        PUBLIC_KEY_SELINUX_ATTRIBUTES,     /** Some operating systems require keys to have extra
+                                              attributes         */
+        EXIST,                             /** The certificate file doesn't exist or is not accessible              */
+        VALID,                             /** The file is not a certificate                                        */
+        VALID_AUTHORITY,                   /** The claimed authority did not sign the certificate                   */
+        KNOWN_AUTHORITY,                   /** Some operating systems provide a list of trusted authorities, use it */
+        NOT_REVOKED,                       /** The certificate has been revoked by the authority                    */
+        AUTHORITY_MISMATCH,                /** The certificate and authority mismatch */
+        UNEXPECTED_OWNER,                  /** The certificate has an expected owner   */
+        NOT_ACTIVATED,                     /** The certificate has not been activated yet                           */
         COUNT__,
     };
 
@@ -114,15 +107,17 @@ public:
      * @enum CertificateDetails Informative fields about a certificate
      */
     enum class CertificateDetails {
-        EXPIRATION_DATE, /** The certificate expiration date                                      */
-        ACTIVATION_DATE, /** The certificate activation date                                      */
+        EXPIRATION_DATE,              /** The certificate expiration date                                      */
+        ACTIVATION_DATE,              /** The certificate activation date                                      */
         REQUIRE_PRIVATE_KEY_PASSWORD, /** Does the private key require a password */
         PUBLIC_SIGNATURE,
         VERSION_NUMBER,
         SERIAL_NUMBER,
         ISSUER,
         SUBJECT_KEY_ALGORITHM,
+        SUBJECT_KEY,
         CN,
+        UID,
         N,
         O,
         SIGNATURE_ALGORITHM,
@@ -130,6 +125,10 @@ public:
         SHA1_FINGERPRINT,
         PUBLIC_KEY_ID,
         ISSUER_DN,
+        ISSUER_CN,
+        ISSUER_UID,
+        ISSUER_N,
+        ISSUER_O,
         NEXT_EXPECTED_UPDATE_DATE,
         OUTGOING_SERVER, /** The hostname/outgoing server used for this certificate               */
         IS_CA,
@@ -189,7 +188,8 @@ public:
                  const std::string& privatekeyPasswd = "",
                  const std::string& caList = "");
 
-    TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::vector<std::vector<uint8_t>>& certificate_chain_raw);
+    TlsValidator(const dhtnet::tls::CertificateStore& certStore,
+                 const std::vector<std::vector<uint8_t>>& certificate_chain_raw);
 
     TlsValidator(const dhtnet::tls::CertificateStore& certStore, const std::vector<uint8_t>& certificate_raw);
 
@@ -233,7 +233,9 @@ public:
     CheckResult getSerialNumber();
     CheckResult getIssuer();
     CheckResult getSubjectKeyAlgorithm();
+    CheckResult getSubjectKey();
     CheckResult getCN();
+    CheckResult getUID();
     CheckResult getN();
     CheckResult getO();
     CheckResult getSignatureAlgorithm();
@@ -241,6 +243,10 @@ public:
     CheckResult getSha1Fingerprint();
     CheckResult getPublicKeyId();
     CheckResult getIssuerDN();
+    CheckResult getIssuerCN();
+    CheckResult getIssuerUID();
+    CheckResult getIssuerN();
+    CheckResult getIssuerO();
     CheckResult outgoingServer();
     CheckResult isCA();
 
@@ -279,7 +285,7 @@ private:
 
     static const Matrix1D<CertificateCheck, CheckValuesType> enforcedCheckType;
 
-    const dhtnet::tls::CertificateStore&  certStore_;
+    const dhtnet::tls::CertificateStore& certStore_;
     std::string certificatePath_;
     std::string privateKeyPath_;
     std::string caListPath_ {};
