@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
  *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -45,22 +45,34 @@ namespace fileutils {
 
 using namespace std::literals;
 
-std::filesystem::path get_home_dir();
 std::filesystem::path get_config_dir(const char* pkg);
 std::filesystem::path get_data_dir(const char* pkg);
 std::filesystem::path get_cache_dir(const char* pkg);
 
-std::filesystem::path get_config_dir();
-std::filesystem::path get_data_dir();
-std::filesystem::path get_cache_dir();
+const std::filesystem::path& get_home_dir();
+const std::filesystem::path& get_config_dir();
+const std::filesystem::path& get_data_dir();
+const std::filesystem::path& get_cache_dir();
 
 /**
- * Check directory existence and create it with given mode if it doesn't.
- * @param path to check, relative or absolute
- * @param dir last directory creation mode
- * @param parents default mode for all created directories except the last
+ * Set the program's resource directory path. This is used for clients that may be installed in
+ * different locations and are deployed with ringtones and other resources in an application
+ * relative directory.
+ * @param resource_dir_path The path to the ringtone directory.
+ */
+LIBJAMI_PUBLIC void set_resource_dir_path(const std::filesystem::path& resourceDirPath);
+
+/**
+ * Get the resource directory path that was set with set_resource_dir_path.
+ * @return The resource directory path.
+ */
+const std::filesystem::path& get_resource_dir_path();
+
+/**
+ * Expand the given path.
+ * @param path The path to be expanded.
+ * @return The expanded path as a string.
  */
-LIBJAMI_PUBLIC void set_program_dir(char* program_path); // public because bin/main.cpp uses it
 std::string expand_path(const std::string& path);
 
 bool isPathRelative(const std::filesystem::path& path);
@@ -74,8 +86,7 @@ std::string getCleanPath(const std::string& base, const std::string& path);
 /**
  * If path is relative, it is appended to base.
  */
-std::filesystem::path getFullPath(const std::filesystem::path& base,
-                                  const std::filesystem::path& path);
+std::filesystem::path getFullPath(const std::filesystem::path& base, const std::filesystem::path& path);
 
 bool createFileLink(const std::filesystem::path& src, const std::filesystem::path& dest, bool hard = false);
 
@@ -87,10 +98,8 @@ bool isDirectoryWritable(const std::string& directory);
  * Read the full content of a file at path.
  * If path is relative, it is appended to default_dir.
  */
-std::vector<uint8_t> loadFile(const std::filesystem::path& path,
-                              const std::filesystem::path& default_dir = {});
-std::string loadTextFile(const std::filesystem::path& path,
-                         const std::filesystem::path& default_dir = {});
+std::vector<uint8_t> loadFile(const std::filesystem::path& path, const std::filesystem::path& default_dir = {});
+std::string loadTextFile(const std::filesystem::path& path, const std::filesystem::path& default_dir = {});
 
 void saveFile(const std::filesystem::path& path, const uint8_t* data, size_t data_size, mode_t mode = 0644);
 inline void
@@ -99,24 +108,25 @@ saveFile(const std::filesystem::path& path, const std::vector<uint8_t>& data, mo
     saveFile(path, data.data(), data.size(), mode);
 }
 
-std::vector<uint8_t> loadCacheFile(const std::filesystem::path& path,
-                                   std::chrono::system_clock::duration maxAge);
+std::vector<uint8_t> loadCacheFile(const std::filesystem::path& path, std::chrono::system_clock::duration maxAge);
 std::string loadCacheTextFile(const std::filesystem::path& path, std::chrono::system_clock::duration maxAge);
 
 static constexpr auto ARCHIVE_AUTH_SCHEME_NONE = ""sv;
 static constexpr auto ARCHIVE_AUTH_SCHEME_PASSWORD = "password"sv;
 static constexpr auto ARCHIVE_AUTH_SCHEME_KEY = "key"sv;
 
-struct ArchiveStorageData {
-    std::vector<uint8_t> data;
+struct ArchiveStorageData
+{
+    std::string data;
     std::vector<uint8_t> salt;
 };
 ArchiveStorageData readArchive(const std::filesystem::path& path, std::string_view scheme, const std::string& pwd);
 
-void writeArchive(const std::string& data,
+bool writeArchive(const std::string& data,
                   const std::filesystem::path& path,
                   std::string_view scheme,
-                  const std::string& password = {}, const std::vector<uint8_t>& password_salt = {});
+                  const std::string& password = {},
+                  const std::vector<uint8_t>& password_salt = {});
 
 int64_t size(const std::filesystem::path& path);
 
