@@ -1,29 +1,19 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Pierre-Luc Beaudoin <pierre-luc.beaudoin@savoirfairelinux.com>
- *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Guillaume Carmel-Archambault <guillaume.carmel-archambault@savoirfairelinux.com>
- *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #include "def.h"
@@ -53,76 +43,85 @@ struct LIBJAMI_PUBLIC Message
     uint64_t received;
 };
 
-LIBJAMI_PUBLIC std::map<std::string, std::string> getAccountDetails(const std::string& accountID);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getVolatileAccountDetails(
-    const std::string& accountID);
-LIBJAMI_PUBLIC void setAccountDetails(const std::string& accountID,
-                                      const std::map<std::string, std::string>& details);
-LIBJAMI_PUBLIC void setAccountActive(const std::string& accountID,
-                                     bool active,
-                                     bool shutdownConnections = false);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getAccountDetails(const std::string& accountId);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getVolatileAccountDetails(const std::string& accountId);
+LIBJAMI_PUBLIC void setAccountDetails(const std::string& accountId, const std::map<std::string, std::string>& details);
+LIBJAMI_PUBLIC void setAccountActive(const std::string& accountId, bool active, bool shutdownConnections = false);
+LIBJAMI_PUBLIC void loadAccountAndConversation(const std::string& accountId, bool loadAll, const std::string& convId);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getAccountTemplate(const std::string& accountType);
 LIBJAMI_PUBLIC std::string addAccount(const std::map<std::string, std::string>& details,
-                                      const std::string& accountID = {});
+                                      const std::string& accountId = {});
 LIBJAMI_PUBLIC void monitor(bool continuous);
-LIBJAMI_PUBLIC bool exportOnRing(const std::string& accountID, const std::string& password);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getConnectionList(const std::string& accountId,
+                                                                                 const std::string& conversationId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getChannelList(const std::string& accountId,
+                                                                              const std::string& connectionId);
+
+LIBJAMI_PUBLIC bool provideAccountAuthentication(const std::string& accountId,
+                                                 const std::string& credentialsFromUser,
+                                                 const std::string& scheme);
+
+LIBJAMI_PUBLIC int32_t addDevice(const std::string& accountId, const std::string& uri);
+LIBJAMI_PUBLIC bool confirmAddDevice(const std::string& accountId, uint32_t op_id);
+LIBJAMI_PUBLIC bool cancelAddDevice(const std::string& accountId, uint32_t op_id);
+
 LIBJAMI_PUBLIC bool exportToFile(const std::string& accountID,
                                  const std::string& destinationPath,
+                                 const std::string& scheme = {},
                                  const std::string& password = {});
-LIBJAMI_PUBLIC bool revokeDevice(const std::string& accountID,
-                                 const std::string& password,
-                                 const std::string& deviceID);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getKnownRingDevices(const std::string& accountID);
-LIBJAMI_PUBLIC bool changeAccountPassword(const std::string& accountID,
+LIBJAMI_PUBLIC bool revokeDevice(const std::string& accountId,
+                                 const std::string& deviceId,
+                                 const std::string& scheme = {},
+                                 const std::string& password = {});
+LIBJAMI_PUBLIC std::map<std::string, std::string> getKnownRingDevices(const std::string& accountId);
+LIBJAMI_PUBLIC bool changeAccountPassword(const std::string& accountId,
                                           const std::string& password_old,
                                           const std::string& password_new);
-LIBJAMI_PUBLIC bool isPasswordValid(const std::string& accountID, const std::string& password);
+LIBJAMI_PUBLIC bool isPasswordValid(const std::string& accountId, const std::string& password);
+LIBJAMI_PUBLIC std::vector<uint8_t> getPasswordKey(const std::string& accountId, const std::string& password);
 
-LIBJAMI_PUBLIC bool lookupName(const std::string& account,
-                               const std::string& nameserver,
-                               const std::string& name);
-LIBJAMI_PUBLIC bool lookupAddress(const std::string& account,
-                                  const std::string& nameserver,
-                                  const std::string& address);
+LIBJAMI_PUBLIC bool lookupName(const std::string& account, const std::string& nameserver, const std::string& name);
+LIBJAMI_PUBLIC bool lookupAddress(const std::string& account, const std::string& nameserver, const std::string& address);
 LIBJAMI_PUBLIC bool registerName(const std::string& account,
-                                 const std::string& password,
-                                 const std::string& name);
+                                 const std::string& name,
+                                 const std::string& scheme = {},
+                                 const std::string& password = {});
 LIBJAMI_PUBLIC bool searchUser(const std::string& account, const std::string& query);
 
-LIBJAMI_PUBLIC void removeAccount(const std::string& accountID);
+LIBJAMI_PUBLIC void removeAccount(const std::string& accountId);
 LIBJAMI_PUBLIC std::vector<std::string> getAccountList();
-LIBJAMI_PUBLIC void sendRegister(const std::string& accountID, bool enable);
+LIBJAMI_PUBLIC void sendRegister(const std::string& accountId, bool enable);
 LIBJAMI_PUBLIC void registerAllAccounts(void);
-LIBJAMI_PUBLIC uint64_t sendAccountTextMessage(const std::string& accountID,
+LIBJAMI_PUBLIC uint64_t sendAccountTextMessage(const std::string& accountId,
                                                const std::string& to,
                                                const std::map<std::string, std::string>& payloads,
                                                int32_t flags);
-LIBJAMI_PUBLIC bool cancelMessage(const std::string& accountID, uint64_t message);
-LIBJAMI_PUBLIC std::vector<Message> getLastMessages(const std::string& accountID,
-                                                    const uint64_t& base_timestamp);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getNearbyPeers(const std::string& accountID);
+LIBJAMI_PUBLIC bool cancelMessage(const std::string& accountId, uint64_t message);
+LIBJAMI_PUBLIC std::vector<Message> getLastMessages(const std::string& accountId, const uint64_t& base_timestamp);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getNearbyPeers(const std::string& accountId);
+LIBJAMI_PUBLIC void updateProfile(const std::string& accountId,
+                                  const std::string& displayName,
+                                  const std::string& avatar,
+                                  const std::string& fileType,
+                                  int32_t flag);
 LIBJAMI_PUBLIC int getMessageStatus(uint64_t id);
-LIBJAMI_PUBLIC int getMessageStatus(const std::string& accountID, uint64_t id);
-LIBJAMI_PUBLIC void setIsComposing(const std::string& accountID,
-                                   const std::string& conversationUri,
-                                   bool isWriting);
-LIBJAMI_PUBLIC bool setMessageDisplayed(const std::string& accountID,
+LIBJAMI_PUBLIC int getMessageStatus(const std::string& accountId, uint64_t id);
+LIBJAMI_PUBLIC void setIsComposing(const std::string& accountId, const std::string& conversationUri, bool isWriting);
+LIBJAMI_PUBLIC bool setMessageDisplayed(const std::string& accountId,
                                         const std::string& conversationUri,
                                         const std::string& messageId,
                                         int status);
 
 LIBJAMI_PUBLIC std::vector<unsigned> getCodecList();
 LIBJAMI_PUBLIC std::vector<std::string> getSupportedTlsMethod();
-LIBJAMI_PUBLIC std::vector<std::string> getSupportedCiphers(const std::string& accountID);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getCodecDetails(const std::string& accountID,
-                                                                  const unsigned& codecId);
-LIBJAMI_PUBLIC bool setCodecDetails(const std::string& accountID,
+LIBJAMI_PUBLIC std::vector<std::string> getSupportedCiphers(const std::string& accountId);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getCodecDetails(const std::string& accountId, const unsigned& codecId);
+LIBJAMI_PUBLIC bool setCodecDetails(const std::string& accountId,
                                     const unsigned& codecId,
                                     const std::map<std::string, std::string>& details);
-LIBJAMI_PUBLIC std::vector<unsigned> getActiveCodecList(const std::string& accountID);
+LIBJAMI_PUBLIC std::vector<unsigned> getActiveCodecList(const std::string& accountId);
 
-LIBJAMI_PUBLIC void setActiveCodecList(const std::string& accountID,
-                                       const std::vector<unsigned>& list);
+LIBJAMI_PUBLIC void setActiveCodecList(const std::string& accountId, const std::vector<unsigned>& list);
 
 LIBJAMI_PUBLIC std::vector<std::string> getAudioPluginList();
 LIBJAMI_PUBLIC void setAudioPlugin(const std::string& audioPlugin);
@@ -138,6 +137,10 @@ LIBJAMI_PUBLIC int32_t getAudioOutputDeviceIndex(const std::string& name);
 LIBJAMI_PUBLIC std::string getCurrentAudioOutputPlugin();
 LIBJAMI_PUBLIC std::string getNoiseSuppressState();
 LIBJAMI_PUBLIC void setNoiseSuppressState(const std::string& state);
+LIBJAMI_PUBLIC std::string getEchoCancellationState();
+LIBJAMI_PUBLIC void setEchoCancellationState(const std::string& state);
+LIBJAMI_PUBLIC bool getVoiceActivityDetectionState();
+LIBJAMI_PUBLIC void setVoiceActivityDetectionState(bool state);
 
 LIBJAMI_PUBLIC bool isAgcEnabled();
 LIBJAMI_PUBLIC void setAgcState(bool enabled);
@@ -173,9 +176,8 @@ LIBJAMI_PUBLIC int32_t getRingingTimeout();
 
 LIBJAMI_PUBLIC void setAccountsOrder(const std::string& order);
 
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getCredentials(
-    const std::string& accountID);
-LIBJAMI_PUBLIC void setCredentials(const std::string& accountID,
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getCredentials(const std::string& accountId);
+LIBJAMI_PUBLIC void setCredentials(const std::string& accountId,
                                    const std::vector<std::map<std::string, std::string>>& details);
 
 LIBJAMI_PUBLIC std::string getAddrFromInterfaceName(const std::string& iface);
@@ -189,41 +191,39 @@ LIBJAMI_PUBLIC double getVolume(const std::string& device);
 /*
  * Security
  */
-LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificate(
-    const std::string& accountId, const std::string& certificate);
-LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificatePath(
-    const std::string& accountId,
-    const std::string& certificatePath,
-    const std::string& privateKey,
-    const std::string& privateKeyPassword,
-    const std::string& caList);
+LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificate(const std::string& accountId,
+                                                                      const std::string& certificate);
+LIBJAMI_PUBLIC std::map<std::string, std::string> validateCertificatePath(const std::string& accountId,
+                                                                          const std::string& certificatePath,
+                                                                          const std::string& privateKey,
+                                                                          const std::string& privateKeyPassword,
+                                                                          const std::string& caList);
 
-LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetails(
-    const std::string& certificate);
-LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetailsPath(
-    const std::string& certificatePath,
-    const std::string& privateKey,
-    const std::string& privateKeyPassword);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetails(const std::string& accountId,
+                                                                        const std::string& certificate);
+LIBJAMI_PUBLIC std::map<std::string, std::string> getCertificateDetailsPath(const std::string& accountId,
+                                                                            const std::string& certificatePath,
+                                                                            const std::string& privateKey,
+                                                                            const std::string& privateKeyPassword);
 
-LIBJAMI_PUBLIC std::vector<std::string> getPinnedCertificates();
+LIBJAMI_PUBLIC std::vector<std::string> getPinnedCertificates(const std::string& accountId);
 
-LIBJAMI_PUBLIC std::vector<std::string> pinCertificate(const std::vector<uint8_t>& certificate,
+LIBJAMI_PUBLIC std::vector<std::string> pinCertificate(const std::string& accountId,
+                                                       const std::vector<uint8_t>& certificate,
                                                        bool local);
-LIBJAMI_PUBLIC bool unpinCertificate(const std::string& certId);
+LIBJAMI_PUBLIC bool unpinCertificate(const std::string& accountId, const std::string& certId);
 
-LIBJAMI_PUBLIC void pinCertificatePath(const std::string& path);
-LIBJAMI_PUBLIC unsigned unpinCertificatePath(const std::string& path);
+LIBJAMI_PUBLIC void pinCertificatePath(const std::string& accountId, const std::string& path);
+LIBJAMI_PUBLIC unsigned unpinCertificatePath(const std::string& accountId, const std::string& path);
 
 LIBJAMI_PUBLIC bool pinRemoteCertificate(const std::string& accountId, const std::string& certId);
 LIBJAMI_PUBLIC bool setCertificateStatus(const std::string& account,
                                          const std::string& certId,
                                          const std::string& status);
-LIBJAMI_PUBLIC std::vector<std::string> getCertificatesByStatus(const std::string& account,
-                                                                const std::string& status);
+LIBJAMI_PUBLIC std::vector<std::string> getCertificatesByStatus(const std::string& account, const std::string& status);
 
 /* contact requests */
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getTrustRequests(
-    const std::string& accountId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getTrustRequests(const std::string& accountId);
 LIBJAMI_PUBLIC bool acceptTrustRequest(const std::string& accountId, const std::string& from);
 LIBJAMI_PUBLIC bool discardTrustRequest(const std::string& accountId, const std::string& from);
 LIBJAMI_PUBLIC void sendTrustRequest(const std::string& accountId,
@@ -236,8 +236,7 @@ LIBJAMI_PUBLIC void addContact(const std::string& accountId, const std::string&
 LIBJAMI_PUBLIC void removeContact(const std::string& accountId, const std::string& uri, bool ban);
 LIBJAMI_PUBLIC std::map<std::string, std::string> getContactDetails(const std::string& accountId,
                                                                     const std::string& uri);
-LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getContacts(
-    const std::string& accountId);
+LIBJAMI_PUBLIC std::vector<std::map<std::string, std::string>> getContacts(const std::string& accountId);
 
 /*
  * Network connectivity
@@ -265,8 +264,7 @@ LIBJAMI_PUBLIC void setPushNotificationConfig(const std::map<std::string, std::s
 /**
  * To be called by clients with relevant data when a push notification is received.
  */
-LIBJAMI_PUBLIC void pushNotificationReceived(const std::string& from,
-                                             const std::map<std::string, std::string>& data);
+LIBJAMI_PUBLIC void pushNotificationReceived(const std::string& from, const std::map<std::string, std::string>& data);
 
 /**
  * Returns whether or not the audio meter is enabled for ring buffer @id.
@@ -285,34 +283,37 @@ LIBJAMI_PUBLIC void setAudioMeterState(const std::string& id, bool state);
 /**
  * Add/remove default moderator for conferences
  */
-LIBJAMI_PUBLIC void setDefaultModerator(const std::string& accountID,
-                                        const std::string& peerURI,
-                                        bool state);
+LIBJAMI_PUBLIC void setDefaultModerator(const std::string& accountId, const std::string& peerURI, bool state);
 
 /**
  * Get default moderators for an account
  */
-LIBJAMI_PUBLIC std::vector<std::string> getDefaultModerators(const std::string& accountID);
+LIBJAMI_PUBLIC std::vector<std::string> getDefaultModerators(const std::string& accountId);
 
 /**
  * Enable/disable local moderators for conferences
  */
-LIBJAMI_PUBLIC void enableLocalModerators(const std::string& accountID, bool isModEnabled);
+LIBJAMI_PUBLIC void enableLocalModerators(const std::string& accountId, bool isModEnabled);
 
 /**
  * Get local moderators state
  */
-LIBJAMI_PUBLIC bool isLocalModeratorsEnabled(const std::string& accountID);
+LIBJAMI_PUBLIC bool isLocalModeratorsEnabled(const std::string& accountId);
 
 /**
  * Enable/disable all moderators for conferences
  */
-LIBJAMI_PUBLIC void setAllModerators(const std::string& accountID, bool allModerators);
+LIBJAMI_PUBLIC void setAllModerators(const std::string& accountId, bool allModerators);
 
 /**
  * Get all moderators state
  */
-LIBJAMI_PUBLIC bool isAllModerators(const std::string& accountID);
+LIBJAMI_PUBLIC bool isAllModerators(const std::string& accountId);
+
+/**
+ * Set the resource directory path
+ */
+LIBJAMI_PUBLIC void setResourceDirPath(const std::string& resourceDirPath);
 
 struct LIBJAMI_PUBLIC AudioSignal
 {
@@ -348,6 +349,23 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
         using cb_type = void(int /*alert*/);
     };
 
+    // used for client awareness of available link device jami-auth uri
+    struct LIBJAMI_PUBLIC AddDeviceStateChanged
+    {
+        constexpr static const char* name = "AddDeviceStateChanged";
+        using cb_type = void(const std::string& /*account_id*/,
+                             uint32_t /*op_id */,
+                             int /*state*/,
+                             const std::map<std::string, std::string>& /*detail*/);
+    };
+    // used for link device authentication (password, error, etc.)
+    struct LIBJAMI_PUBLIC DeviceAuthStateChanged
+    {
+        constexpr static const char* name = "DeviceAuthStateChanged";
+        using cb_type = void(const std::string& /*account_id*/,
+                             int /*state*/,
+                             const std::map<std::string, std::string>& /*detail*/);
+    };
     // TODO: move those to AccountSignal in next API breakage
     struct LIBJAMI_PUBLIC AccountDetailsChanged
     {
@@ -394,8 +412,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC NeedsHost
     {
         constexpr static const char* name = "NeedsHost";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::string& /*conversation_id*/);
+        using cb_type = void(const std::string& /*account_id*/, const std::string& /*conversation_id*/);
     };
     struct LIBJAMI_PUBLIC ActiveCallsChanged
     {
@@ -431,22 +448,18 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC ContactAdded
     {
         constexpr static const char* name = "ContactAdded";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::string& /*uri*/,
-                             bool confirmed);
+        using cb_type = void(const std::string& /*account_id*/, const std::string& /*uri*/, bool confirmed);
     };
     struct LIBJAMI_PUBLIC ContactRemoved
     {
         constexpr static const char* name = "ContactRemoved";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::string& /*uri*/,
-                             bool banned);
-    };
-    struct LIBJAMI_PUBLIC ExportOnRingEnded
-    {
-        constexpr static const char* name = "ExportOnRingEnded";
-        using cb_type = void(const std::string& /*account_id*/, int state, const std::string& pin);
+        using cb_type = void(const std::string& /*account_id*/, const std::string& /*uri*/, bool banned);
     };
+    // struct LIBJAMI_PUBLIC ExportToPeer
+    // {
+    //     constexpr static const char* name = "ExportToPeer";
+    //     using cb_type = void(const std::string& /*account_id*/, const std::string& uri);
+    // };
     struct LIBJAMI_PUBLIC NameRegistrationEnded
     {
         constexpr static const char* name = "NameRegistrationEnded";
@@ -455,13 +468,13 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC KnownDevicesChanged
     {
         constexpr static const char* name = "KnownDevicesChanged";
-        using cb_type = void(const std::string& /*account_id*/,
-                             const std::map<std::string, std::string>& devices);
+        using cb_type = void(const std::string& /*account_id*/, const std::map<std::string, std::string>& devices);
     };
     struct LIBJAMI_PUBLIC RegisteredNameFound
     {
         constexpr static const char* name = "RegisteredNameFound";
         using cb_type = void(const std::string& /*account_id*/,
+                             const std::string& /*request_name*/,
                              int state,
                              const std::string& /*address*/,
                              const std::string& /*name*/);
@@ -482,8 +495,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC CertificatePathPinned
     {
         constexpr static const char* name = "CertificatePathPinned";
-        using cb_type = void(const std::string& /*path*/,
-                             const std::vector<std::string>& /*certId*/);
+        using cb_type = void(const std::string& /*path*/, const std::vector<std::string>& /*certId*/);
     };
     struct LIBJAMI_PUBLIC CertificateExpired
     {
@@ -510,9 +522,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
     struct LIBJAMI_PUBLIC DeviceRevocationEnded
     {
         constexpr static const char* name = "DeviceRevocationEnded";
-        using cb_type = void(const std::string& /*accountId*/,
-                             const std::string& /*device*/,
-                             int /*status*/);
+        using cb_type = void(const std::string& /*accountId*/, const std::string& /*device*/, int /*status*/);
     };
     struct LIBJAMI_PUBLIC AccountProfileReceived
     {
@@ -532,7 +542,7 @@ struct LIBJAMI_PUBLIC ConfigurationSignal
         using cb_type = void(std::vector<int32_t>* /* params_ret */);
     };
 #endif
-#if defined(__ANDROID__) || defined(RING_UWP) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
+#if defined(__ANDROID__) || (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
     struct LIBJAMI_PUBLIC GetAppDataPath
     {
         constexpr static const char* name = "GetAppDataPath";
