@@ -28,6 +28,7 @@
 #include "client/ring_signal.h"
 
 #include <dhtnet/multiplexed_socket.h>
+#include <dhtnet/channel_utils.h>
 #include <opendht/dhtrunner.h>
 #include <opendht/thread_pool.h>
 
@@ -447,10 +448,10 @@ struct ArchiveAccountManager::LinkDeviceContext : public DeviceContextBase
     std::string authScheme {fileutils::ARCHIVE_AUTH_SCHEME_NONE};
     std::string credentialsFromUser {""};
 
-    LinkDeviceContext(dht::crypto::Identity id)
+    LinkDeviceContext(const std::shared_ptr<dhtnet::ConnectionManager::Config>& config)
         : DeviceContextBase(0, AuthDecodingState::HANDSHAKE)
-        , tmpId(std::move(id))
-        , tempConnMgr(tmpId)
+        , tmpId(config->id)
+        , tempConnMgr(config)
     {}
 };
 
@@ -519,11 +520,6 @@ ArchiveAccountManager::provideAccountAuthentication(const std::string& key, cons
     return true;
 }
 
-struct ArchiveAccountManager::DecodingContext
-{
-    msgpack::unpacker pac {[](msgpack::type::object_type, std::size_t, void*) { return true; }, nullptr, 512};
-};
-
 // link device: newDev: creates a new temporary account on the DHT for establishing a TLS connection
 void
 ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthContext>& ctx)
@@ -552,23 +548,31 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
             JAMI_WARNING("[LinkDevice] Failed to get the ArchiveAccountManager.");
             return;
         }
-
         // establish linkDevCtx
-        ctx->linkDevCtx = std::make_shared<LinkDeviceContext>(
-            dht::crypto::generateIdentity("Jami Temporary device", user));
+        auto config = std::make_shared<dhtnet::ConnectionManager::Config>();
+        config->id = dht::crypto::generateIdentity("Jami Temporary device", user);
+        config->ioContext = Manager::instance().ioContext();
+        config->factory = Manager::instance().getIceTransportFactory();
+        config->rng = std::make_unique<std::mt19937_64>(Manager::instance().getSeededRandomEngine());
+        config->turnEnabled = true;
+        config->turnServer = DEFAULT_TURN_SERVER;
+        config->turnServerUserName = DEFAULT_TURN_USERNAME;
+        config->turnServerPwd = DEFAULT_TURN_PWD;
+        config->turnServerRealm = DEFAULT_TURN_REALM;
+
+        ctx->linkDevCtx = std::make_shared<LinkDeviceContext>(config);
         JAMI_LOG("[LinkDevice] Established linkDevCtx. {} {} {}.",
                  fmt::ptr(this_),
                  fmt::ptr(ctx),
                  fmt::ptr(ctx->linkDevCtx));
 
         // set up auth channel code and also use it as opId
-        auto gen = Manager::instance().getSeededRandomEngine();
-        ctx->linkDevCtx->opId = std::uniform_int_distribution<uint64_t>(100000, 999999)(gen);
+        ctx->linkDevCtx->opId = std::uniform_int_distribution<uint64_t>(100000, 999999)(*config->rng);
 #if TARGET_OS_IOS
         ctx->linkDevCtx->tempConnMgr.oniOSConnected(
             [&](const std::string& connType, dht::InfoHash peer_h) { return false; });
 #endif
-        ctx->linkDevCtx->tempConnMgr.onDhtConnected(ctx->linkDevCtx->tmpId.second->getPublicKey());
+        ctx->linkDevCtx->tempConnMgr.dhtStarted();
 
         auto accountScheme = fmt::format("{}{}/{}",
                                          AUTH_URI_SCHEME,
@@ -661,7 +665,7 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
                 }
             });
 
-            socket->onShutdown([ctx, name, wthis]() {
+            socket->onShutdown([ctx, name, wthis](const std::error_code& ec) {
                 JAMI_WARNING("[LinkDevice] Temporary connection manager closing socket: {}", name);
                 if (ctx->timeout)
                     ctx->timeout->cancel();
@@ -678,30 +682,9 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
                                                                                  DeviceAuthInfo::createError(error));
             });
 
-            socket->setOnRecv([ctx, decodingCtx = std::make_shared<DecodingContext>(), wthis](const uint8_t* buf,
-                                                                                              size_t len) {
-                if (!buf) {
-                    return len;
-                }
-
-                decodingCtx->pac.reserve_buffer(len);
-                std::copy_n(buf, len, decodingCtx->pac.buffer());
-                decodingCtx->pac.buffer_consumed(len);
-                AuthMsg toRecv;
-                try {
-                    msgpack::object_handle oh;
-                    if (decodingCtx->pac.next(oh)) {
-                        JAMI_DEBUG("[LinkDevice] NEW: Unpacking message.");
-                        oh.get().convert(toRecv);
-                    } else {
-                        return len;
-                    }
-                } catch (const std::exception& e) {
-                    ctx->linkDevCtx->state = AuthDecodingState::ERR;
-                    JAMI_ERROR("[LinkDevice] Error unpacking message from source device: {}", e.what());
-                    return len;
-                }
-
+            socket->setOnRecv(dhtnet::buildMsgpackReader<AuthMsg>([ctx, wthis](AuthMsg&& toRecv) {
+                if (!ctx || !wthis.lock())
+                    return std::make_error_code(std::errc::operation_canceled);
                 JAMI_DEBUG("[LinkDevice] NEW: Successfully unpacked message from source\n{}", toRecv.formatMsg());
                 JAMI_DEBUG("[LinkDevice] NEW: State is {}:{}",
                            ctx->linkDevCtx->scheme,
@@ -711,13 +694,13 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
                 if (toRecv.schemeId != 0) {
                     JAMI_WARNING("[LinkDevice] NEW: Unsupported scheme received from source");
                     ctx->linkDevCtx->state = AuthDecodingState::ERR;
-                    return len;
+                    return std::make_error_code(std::errc::operation_canceled);
                 }
 
                 // handle the protocol logic
                 if (ctx->linkDevCtx->handleCanceledMessage(toRecv)) {
                     // import canceled. Will be handeled onShutdown
-                    return len;
+                    return std::make_error_code(std::errc::operation_canceled);
                 }
                 AuthMsg toSend;
                 bool shouldShutdown = false;
@@ -744,10 +727,9 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
 
                     // If we've reached the maximum number of retry attempts
                     if (canRetry != toRecv.payload.end() && canRetry->second == "false") {
-                        JAMI_DEBUG("[LinkDevice] Authentication failed: maximum retry attempts "
-                                   "reached");
+                        JAMI_DEBUG("[LinkDevice] Authentication failed: maximum retry attempts reached");
                         ctx->linkDevCtx->state = AuthDecodingState::AUTH_ERROR;
-                        return len;
+                        return std::make_error_code(std::errc::operation_canceled);
                     }
 
                     // If the password was incorrect but we can still retry
@@ -768,7 +750,7 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
 
                         emitSignal<libjami::ConfigurationSignal::DeviceAuthStateChanged>(
                             ctx->accountId, static_cast<uint8_t>(DeviceAuthState::AUTHENTICATING), info);
-                        return len;
+                        return std::error_code();
                     }
 
                     if (!shouldLoadArchive) {
@@ -806,12 +788,8 @@ ArchiveAccountManager::startLoadArchiveFromDevice(const std::shared_ptr<AuthCont
                     shouldShutdown = true;
                 }
 
-                if (shouldShutdown) {
-                    ctx->linkDevCtx->channel->shutdown();
-                }
-
-                return len;
-            }); // !onConnectionReady // TODO emit AuthStateChanged+"connection ready" signal
+                return shouldShutdown ? std::make_error_code(std::errc::operation_canceled) : std::error_code();
+            })); // !onConnectionReady // TODO emit AuthStateChanged+"connection ready" signal
 
             ctx->linkDevCtx->state = AuthDecodingState::HANDSHAKE;
             // send first message to establish scheme
@@ -843,69 +821,87 @@ ArchiveAccountManager::addDevice(const std::string& uriProvided,
         return static_cast<int32_t>(AccountManager::AddDeviceError::ALREADY_LINKING);
     }
     JAMI_LOG("[LinkDevice] ArchiveAccountManager::addDevice({}, {})", accountId_, uriProvided);
-    try {
-        std::string_view url(uriProvided);
-        if (!starts_with(url, AUTH_URI_SCHEME)) {
-            JAMI_ERROR("[LinkDevice] Invalid uri provided: {}", uriProvided);
-            return static_cast<int32_t>(AccountManager::AddDeviceError::INVALID_URI);
-        }
-        auto peerTempAcc = url.substr(AUTH_URI_SCHEME.length(), 40);
-        auto peerCodeS = url.substr(AUTH_URI_SCHEME.length() + peerTempAcc.length() + 1, 6);
-        JAMI_LOG("[LinkDevice] ======\n * tempAcc =  {}\n * code = {}", peerTempAcc, peerCodeS);
-
-        auto gen = Manager::instance().getSeededRandomEngine();
-        std::uniform_int_distribution<int32_t> dist(1, INT32_MAX);
-        auto token = dist(gen);
-        JAMI_WARNING("[LinkDevice] SOURCE: Creating auth context, token: {}.", token);
-        auto ctx = std::make_shared<AuthContext>();
-        ctx->accountId = accountId_;
-        ctx->token = token;
-        ctx->credentials = std::make_unique<ArchiveAccountCredentials>();
-        authCtx_ = ctx;
-
-        channelHandler->connect(
-            dht::InfoHash(peerTempAcc),
-            fmt::format("{}{}", CHANNEL_SCHEME, peerCodeS),
-            [wthis = weak(), auth_scheme, ctx, accountId = accountId_](std::shared_ptr<dhtnet::ChannelSocket> socket,
-                                                                       const dht::InfoHash& infoHash) {
-                auto this_ = wthis.lock();
-                if (!socket || !this_) {
-                    JAMI_WARNING("[LinkDevice] Invalid socket event while AccountManager connecting.");
-                    if (this_)
-                        this_->authCtx_.reset();
-                    emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(accountId,
-                                                                                    ctx->token,
-                                                                                    static_cast<uint8_t>(
-                                                                                        DeviceAuthState::DONE),
-                                                                                    DeviceAuthInfo::createError(
-                                                                                        DeviceAuthInfo::Error::NETWORK));
-                } else {
-                    if (!this_->doAddDevice(auth_scheme, ctx, socket))
-                        emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(
-                            accountId,
-                            ctx->token,
-                            static_cast<uint8_t>(DeviceAuthState::DONE),
-                            DeviceAuthInfo::createError(DeviceAuthInfo::Error::UNKNOWN));
-                }
-            });
-        runOnMainThread([token, id = accountId_] {
-            emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(id,
-                                                                            token,
-                                                                            static_cast<uint8_t>(
-                                                                                DeviceAuthState::CONNECTING),
-                                                                            DeviceAuthInfo {});
-        });
-        return token;
-    } catch (const std::exception& e) {
-        JAMI_ERROR("[LinkDevice] Parsing uri failed: {}", uriProvided);
-        return static_cast<int32_t>(AccountManager::AddDeviceError::GENERIC);
+    std::string_view url(uriProvided);
+    if (!starts_with(url, AUTH_URI_SCHEME)) {
+        JAMI_ERROR("[LinkDevice] Invalid uri provided: {}", uriProvided);
+        return static_cast<int32_t>(AccountManager::AddDeviceError::INVALID_URI);
     }
+
+    url.remove_prefix(AUTH_URI_SCHEME.length());
+    auto slashPos = url.find('/');
+    if (slashPos == std::string_view::npos || (slashPos != 40 && slashPos != 64)) {
+        JAMI_ERROR("[LinkDevice] Invalid uri provided: {}", uriProvided);
+        return static_cast<int32_t>(AccountManager::AddDeviceError::INVALID_URI);
+    }
+    auto peerTempAcc = url.substr(0, slashPos);
+    url.remove_prefix(slashPos + 1);
+    auto peerCodeS = url.substr(0, url.find('/'));
+    if (peerCodeS.size() != 6) {
+        JAMI_ERROR("[LinkDevice] Invalid uri provided: {}", uriProvided);
+        return static_cast<int32_t>(AccountManager::AddDeviceError::INVALID_URI);
+    }
+    JAMI_LOG("[LinkDevice] ======\n * tempAcc =  {}\n * code = {}", peerTempAcc, peerCodeS);
+
+    auto gen = Manager::instance().getSeededRandomEngine();
+    auto token = std::uniform_int_distribution<int32_t>(1, std::numeric_limits<int32_t>::max())(gen);
+    JAMI_WARNING("[LinkDevice] SOURCE: Creating auth context, token: {}.", token);
+    auto ctx = std::make_shared<AuthContext>();
+    ctx->accountId = accountId_;
+    ctx->token = token;
+    ctx->credentials = std::make_unique<ArchiveAccountCredentials>();
+    authCtx_ = ctx;
+
+    auto onConnect = [wthis = weak(), auth_scheme, ctx, accountId = accountId_](
+                         std::shared_ptr<dhtnet::ChannelSocket> socket) {
+        auto this_ = wthis.lock();
+        if (!socket || !this_) {
+            JAMI_WARNING("[LinkDevice] Invalid socket event while AccountManager connecting.");
+            if (this_)
+                this_->authCtx_.reset();
+            emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(accountId,
+                                                                            ctx->token,
+                                                                            static_cast<uint8_t>(DeviceAuthState::DONE),
+                                                                            DeviceAuthInfo::createError(
+                                                                                DeviceAuthInfo::Error::NETWORK));
+        } else {
+            if (!this_->doAddDevice(auth_scheme, ctx, std::move(socket)))
+                emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(accountId,
+                                                                                ctx->token,
+                                                                                static_cast<uint8_t>(
+                                                                                    DeviceAuthState::DONE),
+                                                                                DeviceAuthInfo::createError(
+                                                                                    DeviceAuthInfo::Error::UNKNOWN));
+        }
+    };
+
+    auto channelName = fmt::format("{}{}", CHANNEL_SCHEME, peerCodeS);
+    if (peerTempAcc.size() == 40) {
+        channelHandler->connect(dht::InfoHash(peerTempAcc),
+                                channelName,
+                                [onConnect](std::shared_ptr<dhtnet::ChannelSocket> socket,
+                                            const dht::InfoHash& infoHash) { onConnect(std::move(socket)); });
+    } else {
+        channelHandler->connect(dht::PkId(peerTempAcc),
+                                channelName,
+                                [onConnect](std::shared_ptr<dhtnet::ChannelSocket> socket, const dht::PkId& infoHash) {
+                                    onConnect(std::move(socket));
+                                });
+    }
+
+    runOnMainThread([token, id = accountId_] {
+        emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(id,
+                                                                        token,
+                                                                        static_cast<uint8_t>(
+                                                                            DeviceAuthState::CONNECTING),
+                                                                        DeviceAuthInfo {});
+    });
+    return token;
 }
 
 bool
 ArchiveAccountManager::doAddDevice(std::string_view scheme,
                                    const std::shared_ptr<AuthContext>& ctx,
-                                   const std::shared_ptr<dhtnet::ChannelSocket>& channel)
+                                   std::shared_ptr<dhtnet::ChannelSocket> channel)
 {
     if (ctx->canceled) {
         JAMI_WARNING("[LinkDevice] SOURCE: addDevice canceled.");
@@ -914,37 +910,38 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
     }
     JAMI_DEBUG("[LinkDevice] Setting up addDevice logic on SOURCE device.");
     JAMI_DEBUG("[LinkDevice] SOURCE: Creating addDeviceCtx.");
-    ctx->addDeviceCtx = std::make_unique<AddDeviceContext>(channel);
+    ctx->addDeviceCtx = std::make_unique<AddDeviceContext>(std::move(channel));
     ctx->addDeviceCtx->authScheme = scheme;
     ctx->addDeviceCtx->state = AuthDecodingState::HANDSHAKE;
 
     ctx->timeout = std::make_unique<asio::steady_timer>(*Manager::instance().ioContext());
     ctx->timeout->expires_after(OP_TIMEOUT);
     ctx->timeout->async_wait([wthis = weak(), wctx = std::weak_ptr(ctx)](const std::error_code& ec) {
-        if (ec) {
+        if (ec)
             return;
-        }
-        if (auto ctx = wctx.lock()) {
-            if (!ctx->addDeviceCtx->isCompleted()) {
-                if (auto this_ = wthis.lock()) {
-                    ctx->addDeviceCtx->state = AuthDecodingState::TIMEOUT;
-                    JAMI_WARNING("[LinkDevice] Timeout for addDevice.");
+        dht::ThreadPool::io().run([wthis, wctx]() {
+            if (auto ctx = wctx.lock()) {
+                if (!ctx->addDeviceCtx->isCompleted()) {
+                    if (auto this_ = wthis.lock()) {
+                        ctx->addDeviceCtx->state = AuthDecodingState::TIMEOUT;
+                        JAMI_WARNING("[LinkDevice] Timeout for addDevice.");
 
-                    // Create and send timeout message
-                    msgpack::sbuffer buffer(UINT16_MAX);
-                    msgpack::pack(buffer, AuthMsg::timeout());
-                    std::error_code ec;
-                    ctx->addDeviceCtx->channel->write(reinterpret_cast<const unsigned char*>(buffer.data()),
-                                                      buffer.size(),
-                                                      ec);
-                    ctx->addDeviceCtx->channel->shutdown();
+                        // Create and send timeout message
+                        msgpack::sbuffer buffer(UINT16_MAX);
+                        msgpack::pack(buffer, AuthMsg::timeout());
+                        std::error_code ec;
+                        ctx->addDeviceCtx->channel->write(reinterpret_cast<const unsigned char*>(buffer.data()),
+                                                          buffer.size(),
+                                                          ec);
+                        ctx->addDeviceCtx->channel->shutdown();
+                    }
                 }
             }
-        }
+        });
     });
 
     JAMI_DEBUG("[LinkDevice] SOURCE: Creating callbacks.");
-    channel->onShutdown([ctx, w = weak()]() {
+    ctx->addDeviceCtx->channel->onShutdown([ctx, w = weak()](const std::error_code& ec) {
         JAMI_DEBUG("[LinkDevice] SOURCE: Shutdown with state {}... xfer {}uccessful",
                    ctx->addDeviceCtx->formattedAuthState(),
                    ctx->addDeviceCtx->archiveTransferredWithoutFailure ? "s" : "uns");
@@ -967,53 +964,23 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
     // for now we only have one valid protocol (version is AuthMsg::scheme = 0) but can later
     // add in more schemes inside this callback function
     JAMI_DEBUG("[LinkDevice] Setting up receiving logic callback.");
-    channel->setOnRecv([ctx,
-                        wthis = weak(),
-                        decodeCtx = std::make_shared<ArchiveAccountManager::DecodingContext>()](const uint8_t* buf,
-                                                                                                size_t len) {
-        JAMI_DEBUG("[LinkDevice] Setting up receiver callback for communication logic on SOURCE "
-                   "device.");
+    ctx->addDeviceCtx->channel->setOnRecv(dhtnet::buildMsgpackReader<AuthMsg>([ctx, wthis = weak()](AuthMsg&& toRecv) {
+        JAMI_DEBUG("[LinkDevice] Setting up receiver callback for communication logic on SOURCE device.");
         // when archive is sent to newDev we will get back a success or fail response before the
         // connection closes and we need to handle this and pass it to the shutdown callback
         auto this_ = wthis.lock();
         if (!this_) {
             JAMI_ERROR("[LinkDevice] Invalid state for ArchiveAccountManager.");
-            return (size_t) 0;
-        }
-
-        if (!buf) {
-            JAMI_ERROR("[LinkDevice] Invalid buffer.");
-            return (size_t) 0;
+            return std::make_error_code(std::errc::operation_canceled);
         }
 
         if (ctx->canceled || ctx->addDeviceCtx->state == AuthDecodingState::ERR) {
             JAMI_ERROR("[LinkDevice] Error.");
-            return (size_t) 0;
+            return std::make_error_code(std::errc::operation_canceled);
         }
 
-        decodeCtx->pac.reserve_buffer(len);
-        std::copy_n(buf, len, decodeCtx->pac.buffer());
-        decodeCtx->pac.buffer_consumed(len);
-
         // handle unpacking the data from the peer
         JAMI_DEBUG("[LinkDevice] SOURCE: addDevice: setOnRecv: handling msg from NEW");
-        msgpack::object_handle oh;
-        AuthMsg toRecv;
-        try {
-            if (decodeCtx->pac.next(oh)) {
-                oh.get().convert(toRecv);
-                JAMI_DEBUG("[LinkDevice] SOURCE: Successfully unpacked message from NEW "
-                           "(NEW->SOURCE)\n{}",
-                           toRecv.formatMsg());
-            } else {
-                return len;
-            }
-        } catch (const std::exception& e) {
-            // set the generic error state in the context
-            ctx->addDeviceCtx->state = AuthDecodingState::ERR;
-            JAMI_ERROR("[LinkDevice] error unpacking message from new device: {}", e.what()); // also warn in logs
-        }
-
         JAMI_DEBUG("[LinkDevice] SOURCE: State is '{}'", ctx->addDeviceCtx->formattedAuthState());
 
         // It's possible to start handling different protocol scheme numbers here
@@ -1027,11 +994,11 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
         if (ctx->addDeviceCtx->state == AuthDecodingState::ERR
             || ctx->addDeviceCtx->state == AuthDecodingState::AUTH_ERROR) {
             JAMI_WARNING("[LinkDevice] Undefined behavior encountered during a link auth session.");
-            ctx->addDeviceCtx->channel->shutdown();
+            return std::make_error_code(std::errc::operation_canceled);
         }
         // Check for timeout message
         if (ctx->addDeviceCtx->handleTimeoutMessage(toRecv)) {
-            return len;
+            return std::make_error_code(std::errc::operation_canceled);
         }
         AuthMsg toSend;
         bool shouldSendMsg = false;
@@ -1042,8 +1009,7 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
         if (ctx->addDeviceCtx->state == AuthDecodingState::AUTH) {
             // receive the incoming password, check if the password is right, and send back the
             // archive if it is correct
-            JAMI_DEBUG("[LinkDevice] SOURCE: addDevice: setOnRecv: verifying sent "
-                       "credentials from NEW");
+            JAMI_DEBUG("[LinkDevice] SOURCE: addDevice: setOnRecv: verifying sent credentials from NEW");
             shouldSendMsg = true;
             const auto& passwordIt = toRecv.find(PayloadKey::password);
             if (passwordIt != toRecv.payload.end()) {
@@ -1064,8 +1030,7 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
                 ctx->addDeviceCtx->numTries++;
                 if (ctx->addDeviceCtx->numTries < ctx->addDeviceCtx->maxTries) {
                     // can retry auth
-                    JAMI_DEBUG("[LinkDevice] Incorrect password received. "
-                               "Attempt {} out of {}.",
+                    JAMI_DEBUG("[LinkDevice] Incorrect password received. Attempt {} out of {}.",
                                ctx->addDeviceCtx->numTries,
                                ctx->addDeviceCtx->maxTries);
                     toSend.set(PayloadKey::passwordCorrect, "false");
@@ -1101,17 +1066,13 @@ ArchiveAccountManager::doAddDevice(std::string_view scheme,
             ctx->addDeviceCtx->channel->write(reinterpret_cast<const unsigned char*>(buffer.data()), buffer.size(), ec);
         }
 
-        if (shouldShutdown) {
-            ctx->addDeviceCtx->channel->shutdown();
-        }
-
-        return len;
-    }); // !channel onRecv closure
+        return shouldShutdown ? std::make_error_code(std::errc::operation_canceled) : std::error_code();
+    })); // !channel onRecv closure
 
     if (ctx->addDeviceCtx->state == AuthDecodingState::HANDSHAKE) {
         ctx->addDeviceCtx->state = AuthDecodingState::EST;
         DeviceAuthInfo info;
-        info.set(DeviceAuthInfo::peer_address, channel->getRemoteAddress().toString(true));
+        info.set(DeviceAuthInfo::peer_address, ctx->addDeviceCtx->channel->getRemoteAddress().toString(true));
         emitSignal<libjami::ConfigurationSignal::AddDeviceStateChanged>(ctx->accountId,
                                                                         ctx->token,
                                                                         static_cast<uint8_t>(
