@@ -123,7 +123,6 @@ private:
         std::unique_ptr<asio::steady_timer> timeout;
         bool canceled {false};
     };
-    struct DecodingContext;
     struct AuthMsg;
     struct DeviceAuthInfo;
     std::shared_ptr<AuthContext> authCtx_;
@@ -150,7 +149,7 @@ private:
 
     bool doAddDevice(std::string_view scheme,
                      const std::shared_ptr<AuthContext>& ctx,
-                     const std::shared_ptr<dhtnet::ChannelSocket>& channel);
+                     std::shared_ptr<dhtnet::ChannelSocket> channel);
 
     void onArchiveLoaded(AuthContext& ctx, AccountArchive&& a, bool isLinkDevProtocol);
 
