@@ -102,6 +102,16 @@ struct ConversationCommit
 
 enum class MemberRole { ADMIN = 0, MEMBER, INVITED, BANNED, LEFT };
 
+namespace MemberPath {
+
+static const std::filesystem::path ADMINS {"admins"};
+static const std::filesystem::path MEMBERS {"members"};
+static const std::filesystem::path INVITED {"invited"};
+static const std::filesystem::path BANNED {"banned"};
+static const std::filesystem::path DEVICES {"devices"};
+
+} // namespace MemberPath
+
 struct ConversationMember
 {
     std::string uri;
@@ -160,13 +170,11 @@ public:
      * @param account           The account getting the conversation
      * @param deviceId          Remote device
      * @param conversationId    Conversation to clone
-     * @param checkCommitCb     Used if commits should be treated
      */
-    static LIBJAMI_TEST_EXPORT std::unique_ptr<ConversationRepository> cloneConversation(
-        const std::shared_ptr<JamiAccount>& account,
-        const std::string& deviceId,
-        const std::string& conversationId,
-        std::function<void(std::vector<ConversationCommit>)>&& checkCommitCb = {});
+    static LIBJAMI_TEST_EXPORT std::pair<std::unique_ptr<ConversationRepository>, std::vector<ConversationCommit>>
+    cloneConversation(const std::shared_ptr<JamiAccount>& account,
+                      const std::string& deviceId,
+                      const std::string& conversationId);
 
     /**
      * Open a conversation repository for an account and an id
@@ -332,7 +340,12 @@ public:
      * @return the validated commits and if an error occurs
      */
     std::pair<std::vector<ConversationCommit>, bool> validFetch(const std::string& remoteDevice) const;
-    bool validClone(std::function<void(std::vector<ConversationCommit>)>&& checkCommitCb) const;
+
+    /**
+     * Validate a clone
+     * @return the validated commits and false if an error occurs
+     */
+    std::pair<std::vector<ConversationCommit>, bool> validClone() const;
 
     /**
      * Verify the signature against the given commit
@@ -436,4 +449,5 @@ private:
 };
 
 } // namespace jami
-MSGPACK_ADD_ENUM(jami::MemberRole);
\ No newline at end of file
+MSGPACK_ADD_ENUM(jami::MemberRole);
+MSGPACK_ADD_ENUM(jami::ConversationMode);
