@@ -19,6 +19,7 @@
 
 #include <dhtnet/multiplexed_socket.h>
 #include <opendht/infohash.h>
+#include <opendht/thread_pool.h>
 
 #include <math.h>
 #include <stdio.h>
@@ -167,11 +168,10 @@ bool
 Bucket::shutdownNode(const NodeId& nodeId)
 {
     auto node = nodes.find(nodeId);
-
     if (node != nodes.end()) {
-        auto socket = node->second.socket;
+        auto& socket = node->second.socket;
         auto node = socket->deviceId();
-        socket->shutdown();
+        dht::ThreadPool::io().run([socket] { socket->shutdown(); });
         removeNode(node);
         return true;
     }
@@ -183,7 +183,7 @@ Bucket::shutdownAllNodes()
 {
     while (not nodes.empty()) {
         auto it = nodes.begin();
-        it->second.socket->shutdown();
+        dht::ThreadPool::io().run([socket = it->second.socket] { socket->shutdown(); });
         auto nodeId = it->first;
         removeNode(nodeId);
     }
@@ -324,10 +324,10 @@ RoutingTable::addMobileNode(const NodeId& nodeId)
     auto bucket = findBucket(nodeId);
 
     if (bucket == buckets.end())
-        return 0;
+        return false;
 
     bucket->addMobileNode(nodeId);
-    return 1;
+    return true;
 }
 
 void
@@ -509,7 +509,7 @@ RoutingTable::getAllNodes() const
         const auto& knownNodes = b.getKnownNodes();
         const auto& mobileNodes = b.getMobileNodes();
         const auto& connectingNodes = b.getConnectingNodes();
-        ret.reserve(nodes.size() + knownNodes.size() + mobileNodes.size() + connectingNodes.size());
+        ret.reserve(ret.size() + nodes.size() + knownNodes.size() + mobileNodes.size() + connectingNodes.size());
         ret.insert(ret.end(), nodes.begin(), nodes.end());
         ret.insert(ret.end(), knownNodes.begin(), knownNodes.end());
         ret.insert(ret.end(), mobileNodes.begin(), mobileNodes.end());
@@ -518,6 +518,21 @@ RoutingTable::getAllNodes() const
     return ret;
 }
 
+std::vector<NodeId>
+RoutingTable::getConnectedNodes() const
+{
+    std::vector<NodeId> ret;
+    for (const auto& b : buckets) {
+        const auto& nodes = b.getNodes();
+        const auto& mobiles = b.getMobileNodes();
+        ret.reserve(ret.size() + nodes.size() + mobiles.size());
+        for (const auto& n : nodes)
+            ret.emplace_back(n.first);
+        ret.insert(ret.end(), mobiles.begin(), mobiles.end());
+    }
+    return ret;
+}
+
 void
 RoutingTable::deleteNode(const NodeId& nodeId)
 {
