@@ -1,22 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "audio_receive_thread.h"
@@ -55,7 +51,7 @@ AudioReceiveThread::~AudioReceiveThread()
 bool
 AudioReceiveThread::setup()
 {
-    std::lock_guard<std::mutex> lk(mutex_);
+    std::lock_guard lk(mutex_);
     audioDecoder_.reset(new MediaDecoder([this](std::shared_ptr<MediaFrame>&& frame) mutable {
         notify(frame);
         ringbuffer_->put(std::static_pointer_cast<AudioFrame>(frame));
@@ -79,7 +75,7 @@ AudioReceiveThread::setup()
     audioDecoder_->setIOContext(sdpContext_.get());
     audioDecoder_->setFEC(true);
     if (audioDecoder_->openInput(args_)) {
-        JAMI_ERR("Could not open input \"%s\"", SDP_FILENAME);
+        JAMI_ERR("Unable to open input \"%s\"", SDP_FILENAME);
         return false;
     }
 
@@ -91,7 +87,6 @@ AudioReceiveThread::setup()
     }
 
     ringbuffer_ = Manager::instance().getRingBufferPool().createRingBuffer(streamId_);
-    Manager::instance().getRingBufferPool().bindHalfDuplexOut(RingBufferPool::DEFAULT_ID, streamId_);
 
     if (onSuccessfulSetup_)
         onSuccessfulSetup_(MEDIA_AUDIO, 1);
@@ -108,7 +103,7 @@ AudioReceiveThread::process()
 void
 AudioReceiveThread::cleanup()
 {
-    std::lock_guard<std::mutex> lk(mutex_);
+    std::lock_guard lk(mutex_);
     audioDecoder_.reset();
     demuxContext_.reset();
 }
@@ -138,8 +133,7 @@ AudioReceiveThread::addIOContext(SocketPair& socketPair)
 }
 
 void
-AudioReceiveThread::setRecorderCallback(
-    const std::function<void(const MediaStream& ms)>& cb)
+AudioReceiveThread::setRecorderCallback(const std::function<void(const MediaStream& ms)>& cb)
 {
     recorderCallback_ = cb;
     if (audioDecoder_)
