@@ -1,24 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *  Author: Андрей Лухнов <aol.nnov@gmail.com>
- *  Author: Adrien Beraud <adrien.beraud@gmail.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "compiler_intrinsics.h"
@@ -40,8 +34,8 @@
 
 #include <regex>
 
-// uncomment to log pulseaudio sink and sources
-//#define PA_LOG_SINK_SOURCES
+// uncomment to log PulseAudio sink and sources
+// #define PA_LOG_SINK_SOURCES
 
 namespace jami {
 
@@ -66,31 +60,28 @@ PulseLayer::PulseLayer(AudioPreference& pref)
     , mainloop_(pa_threaded_mainloop_new(), pa_threaded_mainloop_free)
     , preference_(pref)
 {
-    JAMI_INFO("[audiolayer] created pulseaudio layer");
+    JAMI_INFO("[audiolayer] Created PulseAudio layer");
     if (!mainloop_)
-        throw std::runtime_error("Couldn't create pulseaudio mainloop");
+        throw std::runtime_error("Unable to create PulseAudio mainloop");
 
     if (pa_threaded_mainloop_start(mainloop_.get()) < 0)
-        throw std::runtime_error("Failed to start pulseaudio mainloop");
+        throw std::runtime_error("Failed to start PulseAudio mainloop");
 
     setHasNativeNS(false);
 
     PulseMainLoopLock lock(mainloop_.get());
 
-    std::unique_ptr<pa_proplist, decltype(pa_proplist_free)&> pl(pa_proplist_new(),
-                                                                 pa_proplist_free);
+    std::unique_ptr<pa_proplist, decltype(pa_proplist_free)&> pl(pa_proplist_new(), pa_proplist_free);
     pa_proplist_sets(pl.get(), PA_PROP_MEDIA_ROLE, "phone");
 
-    context_ = pa_context_new_with_proplist(pa_threaded_mainloop_get_api(mainloop_.get()),
-                                            PACKAGE_NAME,
-                                            pl.get());
+    context_ = pa_context_new_with_proplist(pa_threaded_mainloop_get_api(mainloop_.get()), PACKAGE_NAME, pl.get());
     if (!context_)
-        throw std::runtime_error("Couldn't create pulseaudio context");
+        throw std::runtime_error("Unable to create PulseAudio context");
 
     pa_context_set_state_callback(context_, context_state_callback, this);
 
     if (pa_context_connect(context_, nullptr, PA_CONTEXT_NOFLAGS, nullptr) < 0)
-        throw std::runtime_error("Could not connect pulseaudio context to the server");
+        throw std::runtime_error("Unable to connect PulseAudio context to the server");
 
     // wait until context is ready
     for (;;) {
@@ -143,7 +134,7 @@ PulseLayer::contextStateChanged(pa_context* c)
     case PA_CONTEXT_CONNECTING:
     case PA_CONTEXT_AUTHORIZING:
     case PA_CONTEXT_SETTING_NAME:
-        JAMI_DBG("Waiting....");
+        JAMI_DBG("Waiting…");
         break;
 
     case PA_CONTEXT_READY:
@@ -175,7 +166,7 @@ PulseLayer::contextStateChanged(pa_context* c)
 void
 PulseLayer::updateSinkList()
 {
-    std::unique_lock<std::mutex> lk(readyMtx_);
+    std::unique_lock lk(readyMtx_);
     if (not enumeratingSinks_) {
         JAMI_DBG("Updating PulseAudio sink list");
         enumeratingSinks_ = true;
@@ -192,7 +183,7 @@ PulseLayer::updateSinkList()
 void
 PulseLayer::updateSourceList()
 {
-    std::unique_lock<std::mutex> lk(readyMtx_);
+    std::unique_lock lk(readyMtx_);
     if (not enumeratingSources_) {
         JAMI_DBG("Updating PulseAudio source list");
         enumeratingSources_ = true;
@@ -209,9 +200,9 @@ PulseLayer::updateSourceList()
 void
 PulseLayer::updateServerInfo()
 {
-    std::unique_lock<std::mutex> lk(readyMtx_);
+    std::unique_lock lk(readyMtx_);
     if (not gettingServerInfo_) {
-        JAMI_DBG("Updating PulseAudio server infos");
+        JAMI_DBG("Updating PulseAudio server info");
         gettingServerInfo_ = true;
         if (auto op = pa_context_get_server_info(context_, server_info_callback, this))
             pa_operation_unref(op);
@@ -223,18 +214,14 @@ PulseLayer::updateServerInfo()
 bool
 PulseLayer::inSinkList(const std::string& deviceName)
 {
-    return std::find_if(sinkList_.begin(),
-                        sinkList_.end(),
-                        PaDeviceInfos::NameComparator(deviceName))
+    return std::find_if(sinkList_.begin(), sinkList_.end(), PaDeviceInfos::NameComparator(deviceName))
            != sinkList_.end();
 }
 
 bool
 PulseLayer::inSourceList(const std::string& deviceName)
 {
-    return std::find_if(sourceList_.begin(),
-                        sourceList_.end(),
-                        PaDeviceInfos::NameComparator(deviceName))
+    return std::find_if(sourceList_.begin(), sourceList_.end(), PaDeviceInfos::NameComparator(deviceName))
            != sourceList_.end();
 }
 
@@ -288,14 +275,10 @@ PulseLayer::getAudioDeviceIndexByName(const std::string& name, AudioDeviceType t
     case AudioDeviceType::PLAYBACK:
     case AudioDeviceType::RINGTONE:
         return std::distance(sinkList_.begin(),
-                             std::find_if(sinkList_.begin(),
-                                          sinkList_.end(),
-                                          PaDeviceInfos::NameComparator(name)));
+                             std::find_if(sinkList_.begin(), sinkList_.end(), PaDeviceInfos::NameComparator(name)));
     case AudioDeviceType::CAPTURE:
         return std::distance(sourceList_.begin(),
-                             std::find_if(sourceList_.begin(),
-                                          sourceList_.end(),
-                                          PaDeviceInfos::NameComparator(name)));
+                             std::find_if(sourceList_.begin(), sourceList_.end(), PaDeviceInfos::NameComparator(name)));
     default:
         JAMI_ERR("Unexpected device type");
         return 0;
@@ -408,6 +391,7 @@ PulseLayer::createStream(std::unique_ptr<AudioStream>& stream,
                                  name,
                                  type,
                                  audioFormat_.sample_rate,
+                                 pulseSampleFormatFromAv(audioFormat_.sampleFormat),
                                  dev_infos,
                                  ec,
                                  std::bind(&PulseLayer::onStreamReady, this),
@@ -433,25 +417,16 @@ PulseLayer::startStream(AudioDeviceType type)
 {
     waitForDevices();
     PulseMainLoopLock lock(mainloop_.get());
-    bool ec = preference_.getEchoCanceller() == "system"
-              || preference_.getEchoCanceller() == "auto";
+    bool ec = preference_.getEchoCanceller() == "system" || preference_.getEchoCanceller() == "auto";
 
     // Create Streams
     if (type == AudioDeviceType::PLAYBACK) {
         if (auto dev_infos = getDeviceInfos(sinkList_, getPreferredPlaybackDevice())) {
-            createStream(playback_,
-                         type,
-                         *dev_infos,
-                         ec,
-                         std::bind(&PulseLayer::writeToSpeaker, this));
+            createStream(playback_, type, *dev_infos, ec, std::bind(&PulseLayer::writeToSpeaker, this));
         }
     } else if (type == AudioDeviceType::RINGTONE) {
         if (auto dev_infos = getDeviceInfos(sinkList_, getPreferredRingtoneDevice()))
-            createStream(ringtone_,
-                         type,
-                         *dev_infos,
-                         false,
-                         std::bind(&PulseLayer::ringtoneToSpeaker, this));
+            createStream(ringtone_, type, *dev_infos, false, std::bind(&PulseLayer::ringtoneToSpeaker, this));
     } else if (type == AudioDeviceType::CAPTURE) {
         if (auto dev_infos = getDeviceInfos(sourceList_, getPreferredCaptureDevice())) {
             createStream(record_, type, *dev_infos, ec, std::bind(&PulseLayer::readFromMic, this));
@@ -462,7 +437,7 @@ PulseLayer::startStream(AudioDeviceType type)
     }
     pa_threaded_mainloop_signal(mainloop_.get(), 0);
 
-    std::lock_guard<std::mutex> lk(mutex_);
+    std::lock_guard lk(mutex_);
     status_ = Status::Started;
     startedCv_.notify_all();
 }
@@ -484,7 +459,7 @@ PulseLayer::stopStream(AudioDeviceType type)
     if (type == AudioDeviceType::PLAYBACK || type == AudioDeviceType::ALL)
         playbackChanged(false);
 
-    std::lock_guard<std::mutex> lk(mutex_);
+    std::lock_guard lk(mutex_);
     if (not playback_ and not ringtone_ and not record_) {
         pendingStreams = 0;
         status_ = Status::Idle;
@@ -498,19 +473,17 @@ PulseLayer::writeToSpeaker()
     if (!playback_ or !playback_->isReady())
         return;
 
-    // available bytes to be written in pulseaudio internal buffer
-    AudioSample* data = nullptr;
+    // available bytes to be written in PulseAudio internal buffer
+    void* data = nullptr;
     size_t writableBytes = (size_t) -1;
-    int ret = pa_stream_begin_write(playback_->stream(), (void**) &data, &writableBytes);
+    int ret = pa_stream_begin_write(playback_->stream(), &data, &writableBytes);
     if (ret == 0 and data and writableBytes != 0) {
         writableBytes = std::min(pa_stream_writable_size(playback_->stream()), writableBytes);
         const auto& buff = getToPlay(playback_->format(), writableBytes / playback_->frameSize());
         if (not buff or isPlaybackMuted_)
             memset(data, 0, writableBytes);
         else
-            std::memcpy(data,
-                        buff->pointer()->data[0],
-                        buff->pointer()->nb_samples * playback_->frameSize());
+            std::memcpy(data, buff->pointer()->data[0], buff->pointer()->nb_samples * playback_->frameSize());
         pa_stream_write(playback_->stream(), data, writableBytes, nullptr, 0, PA_SEEK_RELATIVE);
     }
 }
@@ -550,18 +523,16 @@ PulseLayer::ringtoneToSpeaker()
     if (!ringtone_ or !ringtone_->isReady())
         return;
 
-    AudioSample* data = nullptr;
+    void* data = nullptr;
     size_t writableBytes = (size_t) -1;
-    int ret = pa_stream_begin_write(ringtone_->stream(), (void**) &data, &writableBytes);
+    int ret = pa_stream_begin_write(ringtone_->stream(), &data, &writableBytes);
     if (ret == 0 and data and writableBytes != 0) {
         writableBytes = std::min(pa_stream_writable_size(ringtone_->stream()), writableBytes);
         const auto& buff = getToRing(ringtone_->format(), writableBytes / ringtone_->frameSize());
         if (not buff or isRingtoneMuted_)
             memset(data, 0, writableBytes);
         else
-            std::memcpy(data,
-                        buff->pointer()->data[0],
-                        buff->pointer()->nb_samples * ringtone_->frameSize());
+            std::memcpy(data, buff->pointer()->data[0], buff->pointer()->nb_samples * ringtone_->frameSize());
         pa_stream_write(ringtone_->stream(), data, writableBytes, nullptr, 0, PA_SEEK_RELATIVE);
     }
 }
@@ -573,18 +544,13 @@ stripEchoSufix(const std::string& deviceName)
 }
 
 void
-PulseLayer::context_changed_callback(pa_context* c,
-                                     pa_subscription_event_type_t type,
-                                     uint32_t idx,
-                                     void* userdata)
+PulseLayer::context_changed_callback(pa_context* c, pa_subscription_event_type_t type, uint32_t idx, void* userdata)
 {
     static_cast<PulseLayer*>(userdata)->contextChanged(c, type, idx);
 }
 
 void
-PulseLayer::contextChanged(pa_context* c UNUSED,
-                           pa_subscription_event_type_t type,
-                           uint32_t idx UNUSED)
+PulseLayer::contextChanged(pa_context* c UNUSED, pa_subscription_event_type_t type, uint32_t idx UNUSED)
 {
     bool reset = false;
 
@@ -627,16 +593,14 @@ PulseLayer::contextChanged(pa_context* c UNUSED,
 void
 PulseLayer::waitForDevices()
 {
-    std::unique_lock<std::mutex> lk(readyMtx_);
-    readyCv_.wait(lk, [this] {
-        return !(enumeratingSinks_ or enumeratingSources_ or gettingServerInfo_);
-    });
+    std::unique_lock lk(readyMtx_);
+    readyCv_.wait(lk, [this] { return !(enumeratingSinks_ or enumeratingSources_ or gettingServerInfo_); });
 }
 
 void
 PulseLayer::waitForDeviceList()
 {
-    std::unique_lock<std::mutex> lock(readyMtx_);
+    std::unique_lock lock(readyMtx_);
     if (waitingDeviceList_.exchange(true))
         return;
     if (streamStarter_.joinable())
@@ -652,8 +616,7 @@ PulseLayer::waitForDeviceList()
         auto playbackInfo = getDeviceInfos(sinkList_, getPreferredPlaybackDevice());
         playbackDeviceChanged = playback_
                                 and (!playbackInfo->name.empty()
-                                     and playbackInfo->name
-                                             != stripEchoSufix(playback_->getDeviceName()));
+                                     and playbackInfo->name != stripEchoSufix(playback_->getDeviceName()));
 
         auto recordInfo = getDeviceInfos(sourceList_, getPreferredCaptureDevice());
         recordDeviceChanged = record_
@@ -681,13 +644,13 @@ PulseLayer::server_info_callback(pa_context*, const pa_server_info* i, void* use
     if (!i)
         return;
     char s[PA_SAMPLE_SPEC_SNPRINT_MAX], cm[PA_CHANNEL_MAP_SNPRINT_MAX];
-    JAMI_DBG("PulseAudio server info:\n"
-             "    Server name: %s\n"
-             "    Server version: %s\n"
-             "    Default Sink %s\n"
-             "    Default Source %s\n"
-             "    Default Sample Specification: %s\n"
-             "    Default Channel Map: %s\n",
+    JAMI_DBG("PulseAudio server info:"
+             "\n    Server name: %s"
+             "\n    Server version: %s"
+             "\n    Default sink: %s"
+             "\n    Default source: %s"
+             "\n    Default sample specification: %s"
+             "\n    Default channel map: %s",
              i->server_name,
              i->server_version,
              i->default_sink_name,
@@ -696,34 +659,33 @@ PulseLayer::server_info_callback(pa_context*, const pa_server_info* i, void* use
              pa_channel_map_snprint(cm, sizeof(cm), &i->channel_map));
 
     PulseLayer* context = static_cast<PulseLayer*>(userdata);
-    std::lock_guard<std::mutex> lk(context->readyMtx_);
+    std::lock_guard lk(context->readyMtx_);
     context->defaultSink_ = {};
     context->defaultSource_ = {};
-    context->defaultAudioFormat_ = {i->sample_spec.rate, i->sample_spec.channels};
+    context->defaultAudioFormat_ = {i->sample_spec.rate,
+                                    i->sample_spec.channels,
+                                    sampleFormatFromPulse(i->sample_spec.format)};
     {
-        std::lock_guard<std::mutex> lk(context->mutex_);
+        std::lock_guard lk(context->mutex_);
         context->hardwareFormatAvailable(context->defaultAudioFormat_);
     }
-    if (not context->sinkList_.empty())
+    /*if (not context->sinkList_.empty())
         context->sinkList_.front().channel_map.channels = std::min(i->sample_spec.channels,
                                                                    (uint8_t) 2);
     if (not context->sourceList_.empty())
         context->sourceList_.front().channel_map.channels = std::min(i->sample_spec.channels,
-                                                                     (uint8_t) 2);
+                                                                     (uint8_t) 2);*/
     context->gettingServerInfo_ = false;
     context->readyCv_.notify_all();
 }
 
 void
-PulseLayer::source_input_info_callback(pa_context* c UNUSED,
-                                       const pa_source_info* i,
-                                       int eol,
-                                       void* userdata)
+PulseLayer::source_input_info_callback(pa_context* c UNUSED, const pa_source_info* i, int eol, void* userdata)
 {
     PulseLayer* context = static_cast<PulseLayer*>(userdata);
 
     if (eol) {
-        std::lock_guard<std::mutex> lk(context->readyMtx_);
+        std::lock_guard lk(context->readyMtx_);
         context->enumeratingSources_ = false;
         context->readyCv_.notify_all();
         return;
@@ -761,13 +723,10 @@ PulseLayer::source_input_info_callback(pa_context* c UNUSED,
 }
 
 void
-PulseLayer::sink_input_info_callback(pa_context* c UNUSED,
-                                     const pa_sink_info* i,
-                                     int eol,
-                                     void* userdata)
+PulseLayer::sink_input_info_callback(pa_context* c UNUSED, const pa_sink_info* i, int eol, void* userdata)
 {
     PulseLayer* context = static_cast<PulseLayer*>(userdata);
-    std::lock_guard<std::mutex> lk(context->readyMtx_);
+    std::lock_guard lk(context->readyMtx_);
 
     if (eol) {
         context->enumeratingSinks_ = false;
@@ -841,15 +800,13 @@ PulseLayer::getIndexCapture() const
 int
 PulseLayer::getIndexPlayback() const
 {
-    return getAudioDeviceIndexByName(preference_.getPulseDevicePlayback(),
-                                     AudioDeviceType::PLAYBACK);
+    return getAudioDeviceIndexByName(preference_.getPulseDevicePlayback(), AudioDeviceType::PLAYBACK);
 }
 
 int
 PulseLayer::getIndexRingtone() const
 {
-    return getAudioDeviceIndexByName(preference_.getPulseDeviceRingtone(),
-                                     AudioDeviceType::RINGTONE);
+    return getAudioDeviceIndexByName(preference_.getPulseDeviceRingtone(), AudioDeviceType::RINGTONE);
 }
 
 std::string
