@@ -1,24 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Tristan Matthews <tristan.matthews@savoirfairelinux.com>
- *  Author: Luca Barbato <lu_zero@gentoo.org>
- *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "libav_deps.h" // MUST BE INCLUDED FIRST
@@ -56,6 +50,35 @@ av_frame_new_side_data_from_buf(AVFrame* frame, enum AVFrameSideDataType type, A
 namespace jami {
 namespace libav_utils {
 
+AVSampleFormat
+choose_sample_fmt(const AVCodec* codec, const AVSampleFormat* preferred_formats, int preferred_formats_count)
+{
+    if (codec->sample_fmts)
+        for (int i = 0; i < preferred_formats_count; ++i) {
+            for (auto it = codec->sample_fmts; *it != -1; ++it) {
+                if (*it == preferred_formats[i])
+                    return preferred_formats[i];
+            }
+        }
+    return AV_SAMPLE_FMT_NONE;
+}
+
+AVSampleFormat
+choose_sample_fmt_default(const AVCodec* codec, AVSampleFormat defaultFormat)
+{
+    // List of supported formats, current default first
+    const AVSampleFormat preferred_formats[] = {defaultFormat,
+                                                AV_SAMPLE_FMT_FLTP,
+                                                AV_SAMPLE_FMT_FLT,
+                                                AV_SAMPLE_FMT_S16P,
+                                                AV_SAMPLE_FMT_S16,
+                                                AV_SAMPLE_FMT_DBLP,
+                                                AV_SAMPLE_FMT_DBL,
+                                                AV_SAMPLE_FMT_S32P,
+                                                AV_SAMPLE_FMT_S32};
+    return choose_sample_fmt(codec, preferred_formats, sizeof(preferred_formats) / sizeof(preferred_formats[0]));
+}
+
 #if LIBAVCODEC_VERSION_INT < AV_VERSION_INT(58, 9, 100)
 // protect libav/ffmpeg access
 static int
@@ -97,7 +120,6 @@ static constexpr const char* AVLOGLEVEL = "AVLOGLEVEL";
 static void
 setAvLogLevel()
 {
-#ifndef RING_UWP
     char* envvar = getenv(AVLOGLEVEL);
     signed level = AV_LOG_WARNING;
 
@@ -106,9 +128,6 @@ setAvLogLevel()
         level = std::max(AV_LOG_QUIET, std::min(level, AV_LOG_DEBUG));
     }
     av_log_set_level(level);
-#else
-    av_log_set_level(0);
-#endif
 }
 
 #ifdef __ANDROID__
@@ -250,12 +269,7 @@ fillWithBlack(AVFrame* frame)
     ptrdiff_t linesizes[4];
     for (int i = 0; i < planes; ++i)
         linesizes[i] = frame->linesize[i];
-    int ret = av_image_fill_black(frame->data,
-                                  linesizes,
-                                  format,
-                                  frame->color_range,
-                                  frame->width,
-                                  frame->height);
+    int ret = av_image_fill_black(frame->data, linesizes, format, frame->color_range, frame->width, frame->height);
     if (ret < 0) {
         JAMI_ERR() << "Failed to blacken frame";
     }
