@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2021-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Mohamed Chibani <mohamed.chibani@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "media/media_attribute.h"
@@ -139,16 +136,17 @@ MediaAttribute::mediaTypeToString(MediaType type)
         return libjami::Media::MediaAttributeValue::AUDIO;
     if (type == MediaType::MEDIA_VIDEO)
         return libjami::Media::MediaAttributeValue::VIDEO;
-    return nullptr;
+    if (type == MediaType::MEDIA_NONE)
+        return libjami::Media::MediaAttributeValue::SRC_TYPE_NONE;
+    return "UNKNOWN";
 }
 
 bool
 MediaAttribute::hasMediaType(const std::vector<MediaAttribute>& mediaList, MediaType type)
 {
-    return mediaList.end()
-           != std::find_if(mediaList.begin(), mediaList.end(), [type](const MediaAttribute& media) {
-                  return media.type_ == type;
-              });
+    return mediaList.end() != std::find_if(mediaList.begin(), mediaList.end(), [type](const MediaAttribute& media) {
+               return media.type_ == type;
+           });
 }
 
 libjami::MediaMap
@@ -156,8 +154,7 @@ MediaAttribute::toMediaMap(const MediaAttribute& mediaAttr)
 {
     libjami::MediaMap mediaMap;
 
-    mediaMap.emplace(libjami::Media::MediaAttributeKey::MEDIA_TYPE,
-                     mediaTypeToString(mediaAttr.type_));
+    mediaMap.emplace(libjami::Media::MediaAttributeKey::MEDIA_TYPE, mediaTypeToString(mediaAttr.type_));
     mediaMap.emplace(libjami::Media::MediaAttributeKey::LABEL, mediaAttr.label_);
     mediaMap.emplace(libjami::Media::MediaAttributeKey::ENABLED, boolToString(mediaAttr.enabled_));
     mediaMap.emplace(libjami::Media::MediaAttributeKey::MUTED, boolToString(mediaAttr.muted_));
@@ -171,7 +168,7 @@ std::vector<libjami::MediaMap>
 MediaAttribute::mediaAttributesToMediaMaps(std::vector<MediaAttribute> mediaAttrList)
 {
     std::vector<libjami::MediaMap> mediaList;
-    mediaAttrList.reserve(mediaAttrList.size());
+    mediaList.reserve(mediaAttrList.size());
     for (auto const& media : mediaAttrList) {
         mediaList.emplace_back(toMediaMap(media));
     }
@@ -204,6 +201,6 @@ MediaAttribute::toString(bool full) const
 bool
 MediaAttribute::hasValidVideo()
 {
-    return type_ == MediaType::MEDIA_VIDEO && enabled_&& !muted_ && !onHold_;
+    return type_ == MediaType::MEDIA_VIDEO && enabled_ && !muted_ && !onHold_;
 }
 } // namespace jami
