@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 #pragma once
 
@@ -31,15 +28,17 @@
 #include "video/video_scaler.h"
 #endif // ENABLE_VIDEO
 
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
 #include "video/accel.h"
 #endif
 #include "logger.h"
 
-#include "audio/audiobuffer.h"
+#include "audio/audio_format.h"
 
 #include "media_device.h"
 #include "media_stream.h"
+#include "media_buffer.h"
+#include "media_attribute.h"
 #include "noncopyable.h"
 
 #include <map>
@@ -73,15 +72,7 @@ class Resampler;
 class MediaIOHandle;
 class MediaDecoder;
 
-enum class DecodeStatus {
-    Success,
-    FrameFinished,
-    EndOfFile,
-    ReadError,
-    DecodeError,
-    RestartRequired,
-    FallBack
-};
+enum class DecodeStatus { Success, FrameFinished, EndOfFile, ReadError, DecodeError, RestartRequired, FallBack };
 
 class MediaDemuxer
 {
@@ -89,14 +80,7 @@ public:
     MediaDemuxer();
     ~MediaDemuxer();
 
-    enum class Status {
-        Success,
-        EndOfFile,
-        ReadBufferOverflow,
-        ReadError,
-        FallBack,
-        RestartRequired
-    };
+    enum class Status { Success, EndOfFile, ReadBufferOverflow, ReadError, FallBack, RestartRequired };
 
     static const char* getStatusStr(Status status);
 
@@ -139,7 +123,7 @@ public:
     int64_t getDuration() const;
     bool seekFrame(int stream_index, int64_t timestamp);
     void setNeedFrameCb(std::function<void()> cb);
-    void emitFrame(bool isAudio);
+    bool emitFrame(bool isAudio);
 
 private:
     bool streamInfoFound_ {false};
@@ -157,7 +141,7 @@ private:
     std::function<void()> needFrameCb_;
     std::function<void(bool)> fileFinishedCb_;
     void clearFrames();
-    void pushFrameFrom(std::queue<std::unique_ptr<AVPacket, std::function<void(AVPacket*)>>>& buffer,
+    bool pushFrameFrom(std::queue<std::unique_ptr<AVPacket, std::function<void(AVPacket*)>>>& buffer,
                        bool isAudio,
                        std::mutex& mutex);
     int baseWidth_ {};
@@ -198,19 +182,16 @@ public:
 
     void updateStartTime(int64_t startTime);
 
-    void emitFrame(bool isAudio);
+    bool emitFrame(bool isAudio);
     void flushBuffers();
     void setSeekTime(int64_t time);
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     void enableAccel(bool enableAccel);
 #endif
 
     MediaStream getStream(std::string name = "") const;
 
-    void setResolutionChangedCallback(std::function<void(int, int)> cb)
-    {
-        resolutionChangedCallback_ = std::move(cb);
-    }
+    void setResolutionChangedCallback(std::function<void(int, int)> cb) { resolutionChangedCallback_ = std::move(cb); }
 
     void setFEC(bool enable) { fecEnabled_ = enable; }
 
@@ -243,7 +224,7 @@ private:
 
     bool fallback_ = false;
 
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     bool enableAccel_ = true;
     std::unique_ptr<video::HardwareAccel> accel_;
     unsigned short accelFailures_ = 0;
