@@ -1,23 +1,19 @@
 ﻿/*
- *  Copyright (C) 2020-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #include "noncopyable.h"
@@ -53,7 +49,7 @@ public:
      * @param rootPath
      * @param pluginId
      * @return string
-    */
+     */
     std::string getPluginAuthor(const std::string& rootPath, const std::string& pluginId);
 
     /**
@@ -76,14 +72,21 @@ public:
      * @brief Check the validity of a plugin certificate
      * @param cert
      * @return true if valid
-    */
+     */
     bool checkPluginCertificateValidity(dht::crypto::Certificate* cert);
 
+    /**
+     * @brief check if the if the public key of the certificate is the same as the public key in the new plugin
+     * @param oldJplPath, newJplPath
+     * return true if valid
+     */
+    bool checkPluginCertificatePublicKey(const std::string& oldJplPath, const std::string& newJplPath);
+
     /**
      * @brief check if all file are present in the signature file
      * @param jplPath
      * return true if valid
-    */
+     */
     bool checkPluginSignatureFile(const std::string& jplPath);
 
     /**
@@ -91,7 +94,7 @@ public:
      * @param jplPath
      * @param cert
      * @return true if valid
-    */
+     */
     bool checkPluginSignatureValidity(const std::string& jplPath, dht::crypto::Certificate* cert);
 
     /**
@@ -100,7 +103,7 @@ public:
      * @param
      * @return true if the plugin signature is valid
      *
-    */
+     */
     bool checkPluginSignature(const std::string& jplPath, dht::crypto::Certificate* cert);
 
     /**
@@ -108,7 +111,7 @@ public:
      * @param jplPath
      * @param force
      * @return return certificate if valid
-    */
+     */
     std::unique_ptr<dht::crypto::Certificate> checkPluginCertificate(const std::string& jplPath, bool force);
 
     /**
@@ -139,7 +142,7 @@ public:
 
     /**
      * @brief Returns True if success
-    */
+     */
     bool loadPlugins();
 
     /**
@@ -158,8 +161,8 @@ public:
      * @param rootPath
      * @param accountId
      */
-    std::vector<std::map<std::string, std::string>> getPluginPreferences(
-        const std::string& rootPath, const std::string& accountId);
+    std::vector<std::map<std::string, std::string>> getPluginPreferences(const std::string& rootPath,
+                                                                         const std::string& accountId);
 
     /**
      * @brief Returns a Map with preferences keys and values.
@@ -205,7 +208,7 @@ public:
 
     PreferenceServicesManager& getPreferenceServicesManager() { return preferencesm_; }
 
-#ifdef LIBJAMI_TESTABLE
+#ifdef LIBJAMI_TEST
     void addPluginAuthority(const dht::crypto::Certificate& cert);
 #endif
 
