@@ -1,21 +1,18 @@
 /*
- *  Copyright (C) 2021-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "pluginsutils.h"
@@ -29,33 +26,33 @@
 #include <regex>
 
 #if defined(__APPLE__)
-    #if (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
-        #define ABI "iphone"
-    #else
-        #if defined(__x86_64__)
-            #define ABI "x86_64-apple-Darwin"
-        #else
-            #define ABI "arm64-apple-Darwin"
-        #endif
-    #endif
+#if (defined(TARGET_OS_IOS) && TARGET_OS_IOS)
+#define ABI "iphone"
+#else
+#if defined(__x86_64__)
+#define ABI "x86_64-apple-Darwin"
+#else
+#define ABI "arm64-apple-Darwin"
+#endif
+#endif
 #elif defined(__arm__)
-    #if defined(__ARM_ARCH_7A__)
-        #define ABI "armeabi-v7a"
-    #else
-        #define ABI "armeabi"
-    #endif
+#if defined(__ARM_ARCH_7A__)
+#define ABI "armeabi-v7a"
+#else
+#define ABI "armeabi"
+#endif
 #elif defined(__i386__)
-    #if __ANDROID__
-        #define ABI "x86"
-    #else
-        #define ABI "x86-linux-gnu"
-    #endif
+#if __ANDROID__
+#define ABI "x86"
+#else
+#define ABI "x86-linux-gnu"
+#endif
 #elif defined(__x86_64__)
-    #if __ANDROID__
-        #define ABI "x86_64"
-    #else
-        #define ABI "x86_64-linux-gnu"
-    #endif
+#if __ANDROID__
+#define ABI "x86_64"
+#else
+#define ABI "x86_64-linux-gnu"
+#endif
 #elif defined(__aarch64__)
 #define ABI "arm64-v8a"
 #elif defined(WIN32)
@@ -82,9 +79,7 @@ manifestPath(const std::filesystem::path& rootPath)
 std::map<std::string, std::string>
 getPlatformInfo()
 {
-    return {
-        {"os", ABI}
-    };
+    return {{"os", ABI}};
 }
 
 std::filesystem::path
@@ -110,13 +105,13 @@ checkManifestJsonContentValidity(const Json::Value& root)
     std::string background = root.get("backgroundPath", "background.jpg").asString();
     if (!name.empty() || !version.empty()) {
         return {
-                {"id", id},
-                {"name", name},
-                {"description", description},
-                {"version", version},
-                {"iconPath", iconPath},
-                {"backgroundPath", background},
-                };
+            {"id", id},
+            {"name", name},
+            {"description", description},
+            {"version", version},
+            {"iconPath", iconPath},
+            {"backgroundPath", background},
+        };
     } else {
         throw std::runtime_error("plugin manifest file: bad format");
     }
@@ -229,7 +224,8 @@ readPluginCertificate(const std::string& rootPath, const std::string& pluginId)
 }
 
 std::unique_ptr<dht::crypto::Certificate>
-readPluginCertificateFromArchive(const std::string& jplPath) {
+readPluginCertificateFromArchive(const std::string& jplPath)
+{
     try {
         auto manifest = readPluginManifestFromArchive(jplPath);
         const std::string& name = manifest["id"];
@@ -238,23 +234,22 @@ readPluginCertificateFromArchive(const std::string& jplPath) {
             return {};
         }
         return std::make_unique<dht::crypto::Certificate>(archiver::readFileFromArchive(jplPath, name + ".crt"));
-    } catch(const std::exception& e) {
+    } catch (const std::exception& e) {
         JAMI_ERR() << e.what();
         return {};
     }
 }
 
 std::map<std::string, std::vector<uint8_t>>
-readPluginSignatureFromArchive(const std::string& jplPath) {
+readPluginSignatureFromArchive(const std::string& jplPath)
+{
     try {
         std::vector<uint8_t> vec = archiver::readFileFromArchive(jplPath, "signatures");
-        msgpack::object_handle oh = msgpack::unpack(
-                        reinterpret_cast<const char*>(vec.data()),
-                        vec.size() * sizeof(uint8_t)
-                    );
+        msgpack::object_handle oh = msgpack::unpack(reinterpret_cast<const char*>(vec.data()),
+                                                    vec.size() * sizeof(uint8_t));
         msgpack::object obj = oh.get();
         return obj.as<std::map<std::string, std::vector<uint8_t>>>();
-    } catch(const std::exception& e) {
+    } catch (const std::exception& e) {
         JAMI_ERR() << e.what();
         return {};
     }
@@ -287,44 +282,44 @@ std::string
 getLanguage()
 {
     std::string lang;
-        if (auto envLang = std::getenv("JAMI_LANG"))
-            lang = envLang;
-        else
-            JAMI_INFO() << "Error getting JAMI_LANG env, trying to get system language";
-        // If language preference is empty, try to get from the system.
-        if (lang.empty()) {
+    if (auto envLang = std::getenv("JAMI_LANG"))
+        lang = envLang;
+    else
+        JAMI_INFO() << "Error getting JAMI_LANG env, attempting to get system language";
+    // If language preference is empty, try to get from the system.
+    if (lang.empty()) {
 #ifdef WIN32
-            WCHAR localeBuffer[LOCALE_NAME_MAX_LENGTH];
-            if (GetUserDefaultLocaleName(localeBuffer, LOCALE_NAME_MAX_LENGTH) != 0) {
-                char utf8Buffer[LOCALE_NAME_MAX_LENGTH] {};
-                WideCharToMultiByte(CP_UTF8,
-                                    0,
-                                    localeBuffer,
-                                    LOCALE_NAME_MAX_LENGTH,
-                                    utf8Buffer,
-                                    LOCALE_NAME_MAX_LENGTH,
-                                    nullptr,
-                                    nullptr);
+        WCHAR localeBuffer[LOCALE_NAME_MAX_LENGTH];
+        if (GetUserDefaultLocaleName(localeBuffer, LOCALE_NAME_MAX_LENGTH) != 0) {
+            char utf8Buffer[LOCALE_NAME_MAX_LENGTH] {};
+            WideCharToMultiByte(CP_UTF8,
+                                0,
+                                localeBuffer,
+                                LOCALE_NAME_MAX_LENGTH,
+                                utf8Buffer,
+                                LOCALE_NAME_MAX_LENGTH,
+                                nullptr,
+                                nullptr);
 
-                lang.append(utf8Buffer);
-                string_replace(lang, "-", "_");
-            }
-            // Even though we default to the system variable in windows, technically this
-            // part of the code should not be reached because the client-qt must define that
-            // variable and we cannot run the client and the daemon in diferent processes in Windows.
+            lang.append(utf8Buffer);
+            string_replace(lang, "-", "_");
+        }
+        // Even though we default to the system variable in Windows, technically this
+        // part of the code should not be reached because the client-qt must define that
+        // variable and is unable to run the client and the daemon in diferent processes in Windows.
 #else
-            // The same way described in the comment just above, the android should not reach this
-            // part of the code given the client-android must define "JAMI_LANG" system variable.
-            // And even if this part is reached, it should not work since std::locale is not
-            // supported by the NDK.
+        // The same way described in the comment just above, Android should not reach this
+        // part of the code given the client-android must define "JAMI_LANG" system variable.
+        // And even if this part is reached, it should not work since std::locale is not
+        // supported by the NDK.
 
-            // LC_COLLATE is used to grab the locale for the case when the system user has set different
-            // values for the preferred Language and Format.
-            lang = setlocale(LC_COLLATE, "");
-            // We set the environment to avoid checking from system everytime.
-            // This is the case when running daemon and client in different processes
-            // like with dbus.
-            setenv("JAMI_LANG", lang.c_str(), 1);
+        // LC_COLLATE is used to grab the locale for the case when the system user has set different
+        // values for the preferred Language and Format.
+        lang = setlocale(LC_COLLATE, "");
+        // We set the environment to avoid checking from system everytime.
+        // This is the case when running daemon and client in different processes
+        // like with dbus.
+        setenv("JAMI_LANG", lang.c_str(), 1);
 #endif // WIN32
     }
     return lang;
@@ -354,7 +349,8 @@ getLocales(const std::string& rootPath, const std::string& lang)
 std::map<std::string, std::string>
 processLocaleFile(const std::string& preferenceLocaleFilePath)
 {
-    if (!std::filesystem::is_regular_file(preferenceLocaleFilePath)) {
+    std::error_code ec;
+    if (!std::filesystem::is_regular_file(preferenceLocaleFilePath, ec)) {
         return {};
     }
     std::ifstream file(preferenceLocaleFilePath);
