@@ -1,23 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *  Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -334,7 +329,7 @@ AudioPreference::createAudioLayer()
         try {
             return new PulseLayer(*this);
         } catch (const std::runtime_error& e) {
-            JAMI_WARN("Could not create pulseaudio layer, falling back to ALSA");
+            JAMI_WARN("Unable to create pulseaudio layer, falling back to ALSA");
         }
     }
 
@@ -355,7 +350,7 @@ AudioPreference::createAudioLayer()
     try {
         return new CoreLayer(*this);
     } catch (const std::runtime_error& e) {
-        JAMI_WARN("Could not create coreaudio layer. There will be no sound.");
+        JAMI_WARN("Unable to create coreaudio layer. There will be no sound.");
     }
     return NULL;
 #endif
@@ -365,7 +360,7 @@ AudioPreference::createAudioLayer()
     try {
         return new PortAudioLayer(*this);
     } catch (const std::runtime_error& e) {
-        JAMI_WARN("Could not create PortAudio layer. There will be no sound.");
+        JAMI_WARN("Unable to create PortAudio layer. There will be no sound.");
     }
     return nullptr;
 #endif
@@ -378,25 +373,24 @@ AudioPreference::createAudioLayer()
 std::vector<std::string>
 AudioPreference::getSupportedAudioManagers()
 {
-    return
-    {
+    return {
 #if HAVE_OPENSL
         OPENSL_API_STR,
 #endif
 #if HAVE_ALSA
-            ALSA_API_STR,
+        ALSA_API_STR,
 #endif
 #if HAVE_PULSE
-            PULSEAUDIO_API_STR,
+        PULSEAUDIO_API_STR,
 #endif
 #if HAVE_JACK
-            JACK_API_STR,
+        JACK_API_STR,
 #endif
 #if HAVE_COREAUDIO
-            COREAUDIO_API_STR,
+        COREAUDIO_API_STR,
 #endif
 #if HAVE_PORTAUDIO
-            PORTAUDIO_API_STR,
+        PORTAUDIO_API_STR,
 #endif
     };
 }
@@ -456,7 +450,7 @@ AudioPreference::setRecordPath(const std::string& r)
         recordpath_ = path;
         return true;
     } else {
-        JAMI_ERR("%s is not writable, cannot be the recording path", path.c_str());
+        JAMI_ERR("%s is not writable, unable to be the recording path", path.c_str());
         return false;
     }
 }
@@ -519,12 +513,13 @@ VideoPreferences::serialize(YAML::Emitter& out) const
     out << YAML::Key << CONFIG_LABEL << YAML::Value << YAML::BeginMap;
     out << YAML::Key << RECORD_PREVIEW_KEY << YAML::Value << recordPreview_;
     out << YAML::Key << RECORD_QUALITY_KEY << YAML::Value << recordQuality_;
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     out << YAML::Key << DECODING_ACCELERATED_KEY << YAML::Value << decodingAccelerated_;
     out << YAML::Key << ENCODING_ACCELERATED_KEY << YAML::Value << encodingAccelerated_;
 #endif
     out << YAML::Key << CONFERENCE_RESOLUTION_KEY << YAML::Value << conferenceResolution_;
-    getVideoDeviceMonitor().serialize(out);
+    if (auto dm = getVideoDeviceMonitor())
+        dm->serialize(out);
     out << YAML::EndMap;
 }
 
@@ -540,7 +535,7 @@ VideoPreferences::unserialize(const YAML::Node& in)
         recordPreview_ = true;
         recordQuality_ = 0;
     }
-#ifdef RING_ACCEL
+#ifdef ENABLE_HWACCEL
     try {
         parseValue(node, DECODING_ACCELERATED_KEY, decodingAccelerated_);
         parseValue(node, ENCODING_ACCELERATED_KEY, encodingAccelerated_);
@@ -554,7 +549,8 @@ VideoPreferences::unserialize(const YAML::Node& in)
     } catch (...) {
         conferenceResolution_ = DEFAULT_CONFERENCE_RESOLUTION;
     }
-    getVideoDeviceMonitor().unserialize(in);
+    if (auto dm = getVideoDeviceMonitor())
+        dm->unserialize(in);
 }
 #endif // ENABLE_VIDEO
 
