@@ -1,24 +1,18 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
- *  Author: Eloi Bail <eloi.bail@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "sdp.h"
@@ -41,7 +35,6 @@
 #include "compiler_intrinsics.h" // for UNUSED
 
 #include <opendht/rng.h>
-using random_device = dht::crypto::random_device;
 
 #include <algorithm>
 #include <cassert>
@@ -84,41 +77,36 @@ Sdp::~Sdp()
 #endif
 }
 
-std::shared_ptr<AccountCodecInfo>
+std::shared_ptr<SystemCodecInfo>
 Sdp::findCodecBySpec(std::string_view codec, const unsigned clockrate) const
 {
     // TODO : only manage a list?
     for (const auto& accountCodec : audio_codec_list_) {
-        auto audioCodecInfo = std::static_pointer_cast<AccountAudioCodecInfo>(accountCodec);
-        auto& sysCodecInfo = *static_cast<const SystemAudioCodecInfo*>(
-            &audioCodecInfo->systemCodecInfo);
-        if (sysCodecInfo.name == codec
+        auto audioCodecInfo = std::static_pointer_cast<SystemAudioCodecInfo>(accountCodec);
+        if (audioCodecInfo->name == codec
             and (audioCodecInfo->isPCMG722() ? (clockrate == 8000)
-                                             : (sysCodecInfo.audioformat.sample_rate == clockrate)))
+                                             : (audioCodecInfo->audioformat.sample_rate == clockrate)))
             return accountCodec;
     }
 
     for (const auto& accountCodec : video_codec_list_) {
-        auto sysCodecInfo = accountCodec->systemCodecInfo;
-        if (sysCodecInfo.name == codec)
+        if (accountCodec->name == codec)
             return accountCodec;
     }
     return nullptr;
 }
 
-std::shared_ptr<AccountCodecInfo>
+std::shared_ptr<SystemCodecInfo>
 Sdp::findCodecByPayload(const unsigned payloadType)
 {
     // TODO : only manage a list?
     for (const auto& accountCodec : audio_codec_list_) {
-        auto& sysCodecInfo = accountCodec->systemCodecInfo;
-        if (sysCodecInfo.payloadType == payloadType)
+        if (accountCodec->payloadType == payloadType)
             return accountCodec;
     }
 
     for (const auto& accountCodec : video_codec_list_) {
-        auto& sysCodecInfo = accountCodec->systemCodecInfo;
-        if (sysCodecInfo.payloadType == payloadType)
+        if (accountCodec->payloadType == payloadType)
             return accountCodec;
     }
     return nullptr;
@@ -128,7 +116,7 @@ static void
 randomFill(std::vector<uint8_t>& dest)
 {
     std::uniform_int_distribution<int> rand_byte {0, std::numeric_limits<uint8_t>::max()};
-    random_device rdev;
+    std::random_device rdev;
     std::generate(dest.begin(), dest.end(), std::bind(rand_byte, std::ref(rdev)));
 }
 
@@ -158,8 +146,7 @@ Sdp::generateSdesAttribute()
     // generate keys
     randomFill(keyAndSalt);
 
-    std::string crypto_attr = "1 "s + jami::CryptoSuites[cryptoSuite].name
-                              + " inline:" + base64::encode(keyAndSalt);
+    std::string crypto_attr = "1 "s + jami::CryptoSuites[cryptoSuite].name + " inline:" + base64::encode(keyAndSalt);
     pj_str_t val {sip_utils::CONST_PJ_STR(crypto_attr)};
     return pjmedia_sdp_attr_create(memPool_.get(), "crypto", &val);
 }
@@ -195,34 +182,22 @@ Sdp::mediaDirection(const MediaAttribute& mediaAttr)
 MediaDirection
 Sdp::getMediaDirection(pjmedia_sdp_media* media)
 {
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::SENDRECV],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::SENDRECV], nullptr)
         != nullptr) {
         return MediaDirection::SENDRECV;
     }
 
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::SENDONLY],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::SENDONLY], nullptr)
         != nullptr) {
         return MediaDirection::SENDONLY;
     }
 
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::RECVONLY],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::RECVONLY], nullptr)
         != nullptr) {
         return MediaDirection::RECVONLY;
     }
 
-    if (pjmedia_sdp_attr_find2(media->attr_count,
-                               media->attr,
-                               DIRECTION_STR[MediaDirection::INACTIVE],
-                               nullptr)
+    if (pjmedia_sdp_attr_find2(media->attr_count, media->attr, DIRECTION_STR[MediaDirection::INACTIVE], nullptr)
         != nullptr) {
         return MediaDirection::INACTIVE;
     }
@@ -283,8 +258,7 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
     med->desc.port_count = 1;
 
     // Set the transport protocol of the media
-    med->desc.transport = secure ? sip_utils::CONST_PJ_STR("RTP/SAVP")
-                                 : sip_utils::CONST_PJ_STR("RTP/AVP");
+    med->desc.transport = secure ? sip_utils::CONST_PJ_STR("RTP/SAVP") : sip_utils::CONST_PJ_STR("RTP/AVP");
 
     unsigned dynamic_payload = 96;
 
@@ -297,10 +271,9 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
         unsigned payload;
 
         if (type == MediaType::MEDIA_AUDIO) {
-            auto accountAudioCodec = std::static_pointer_cast<AccountAudioCodecInfo>(
-                audio_codec_list_[i]);
+            auto accountAudioCodec = std::static_pointer_cast<SystemAudioCodecInfo>(audio_codec_list_[i]);
             payload = accountAudioCodec->payloadType;
-            enc_name = accountAudioCodec->systemCodecInfo.name;
+            enc_name = accountAudioCodec->name;
 
             if (accountAudioCodec->audioformat.nb_channels > 1) {
                 channels = std::to_string(accountAudioCodec->audioformat.nb_channels);
@@ -316,7 +289,7 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
         } else {
             // FIXME: get this key from header
             payload = dynamic_payload++;
-            enc_name = video_codec_list_[i]->systemCodecInfo.name;
+            enc_name = video_codec_list_[i]->name;
             rtpmap.clock_rate = 90000;
         }
 
@@ -338,15 +311,12 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
         if (enc_name == "H264") {
             // FIXME: this should not be hardcoded, it will determine what profile and level
             // our peer will send us
-            const auto accountVideoCodec = std::static_pointer_cast<AccountVideoCodecInfo>(
-                video_codec_list_[i]);
+            const auto accountVideoCodec = std::static_pointer_cast<SystemVideoCodecInfo>(video_codec_list_[i]);
             const auto& profileLevelID = accountVideoCodec->parameters.empty()
                                              ? libav_utils::DEFAULT_H264_PROFILE_LEVEL_ID
                                              : accountVideoCodec->parameters;
             auto value = fmt::format("fmtp:{} {}", payload, profileLevelID);
-            med->attr[med->attr_count++] = pjmedia_sdp_attr_create(memPool_.get(),
-                                                                   value.c_str(),
-                                                                   NULL);
+            med->attr[med->attr_count++] = pjmedia_sdp_attr_create(memPool_.get(), value.c_str(), NULL);
         }
 #endif
     }
@@ -366,7 +336,7 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
 
     if (secure) {
         if (pjmedia_sdp_media_add_attr(med, generateSdesAttribute()) != PJ_SUCCESS)
-            throw SdpException("Could not add sdes attribute to media");
+            throw SdpException("Unable to add sdes attribute to media");
     }
 
     return med;
@@ -375,7 +345,7 @@ Sdp::addMediaDescription(const MediaAttribute& mediaAttr)
 void
 Sdp::addRTCPAttribute(pjmedia_sdp_media* med, uint16_t port)
 {
-    IpAddr addr {publishedIpAddr_};
+    dhtnet::IpAddr addr {publishedIpAddr_};
     addr.setPort(port);
     pjmedia_sdp_attr* attr = pjmedia_sdp_attr_create_rtcp(memPool_.get(), addr.pjPtr());
     if (attr)
@@ -395,12 +365,12 @@ Sdp::setPublishedIP(const std::string& addr, pj_uint16_t addr_type)
         localSession_->origin.addr = sip_utils::CONST_PJ_STR(publishedIpAddr_);
         localSession_->conn->addr = localSession_->origin.addr;
         if (pjmedia_sdp_validate(localSession_) != PJ_SUCCESS)
-            JAMI_ERR("Could not validate SDP");
+            JAMI_ERR("Unable to validate SDP");
     }
 }
 
 void
-Sdp::setPublishedIP(const IpAddr& ip_addr)
+Sdp::setPublishedIP(const dhtnet::IpAddr& ip_addr)
 {
     setPublishedIP(ip_addr, ip_addr.getFamily());
 }
@@ -409,9 +379,7 @@ void
 Sdp::setTelephoneEventRtpmap(pjmedia_sdp_media* med)
 {
     ++med->desc.fmt_count;
-    pj_strdup2(memPool_.get(),
-               &med->desc.fmt[med->desc.fmt_count - 1],
-               std::to_string(telephoneEventPayload_).c_str());
+    pj_strdup2(memPool_.get(), &med->desc.fmt[med->desc.fmt_count - 1], std::to_string(telephoneEventPayload_).c_str());
 
     pjmedia_sdp_attr* attr_rtpmap = static_cast<pjmedia_sdp_attr*>(
         pj_pool_zalloc(memPool_.get(), sizeof(pjmedia_sdp_attr)));
@@ -429,8 +397,7 @@ Sdp::setTelephoneEventRtpmap(pjmedia_sdp_media* med)
 }
 
 void
-Sdp::setLocalMediaCapabilities(MediaType type,
-                               const std::vector<std::shared_ptr<AccountCodecInfo>>& selectedCodecs)
+Sdp::setLocalMediaCapabilities(MediaType type, const std::vector<std::shared_ptr<SystemCodecInfo>>& selectedCodecs)
 {
     switch (type) {
     case MediaType::MEDIA_AUDIO:
@@ -444,8 +411,8 @@ Sdp::setLocalMediaCapabilities(MediaType type,
         if (not jami::Manager::instance().videoPreferences.getEncodingAccelerated()) {
             video_codec_list_.erase(std::remove_if(video_codec_list_.begin(),
                                                    video_codec_list_.end(),
-                                                   [](const std::shared_ptr<AccountCodecInfo>& i) {
-                                                       return i->systemCodecInfo.name == "H265";
+                                                   [](const std::shared_ptr<SystemCodecInfo>& i) {
+                                                       return i->name == "H265";
                                                    }),
                                     video_codec_list_.end());
         }
@@ -460,31 +427,29 @@ Sdp::setLocalMediaCapabilities(MediaType type,
     }
 }
 
-const char*
+constexpr std::string_view
 Sdp::getSdpDirectionStr(SdpDirection direction)
 {
     if (direction == SdpDirection::OFFER)
-        return "OFFER";
+        return "OFFER"sv;
     if (direction == SdpDirection::ANSWER)
-        return "ANSWER";
-    return "NONE";
+        return "ANSWER"sv;
+    return "NONE"sv;
 }
 
 void
 Sdp::printSession(const pjmedia_sdp_session* session, const char* header, SdpDirection direction)
 {
     static constexpr size_t BUF_SZ = 4095;
-    std::unique_ptr<pj_pool_t, decltype(pj_pool_release)&>
-        tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
-                                "printSdp",
-                                BUF_SZ,
-                                BUF_SZ,
-                                nullptr),
-                 pj_pool_release);
+    sip_utils::PoolPtr tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
+                                               "printSdp",
+                                               BUF_SZ,
+                                               BUF_SZ,
+                                               nullptr));
 
     auto cloned_session = pjmedia_sdp_session_clone(tmpPool_.get(), session);
     if (!cloned_session) {
-        JAMI_ERR("Could not clone SDP for printing");
+        JAMI_ERROR("Unable to clone SDP for printing");
         return;
     }
 
@@ -496,11 +461,11 @@ Sdp::printSession(const pjmedia_sdp_session* session, const char* header, SdpDir
     std::array<char, BUF_SZ + 1> buffer;
     auto size = pjmedia_sdp_print(cloned_session, buffer.data(), BUF_SZ);
     if (size < 0) {
-        JAMI_ERR("%s SDP too big for dump", header);
+        JAMI_ERROR("SDP too big for dump: {}", header);
         return;
     }
 
-    JAMI_DBG("[SDP %s] %s\n%.*s", getSdpDirectionStr(direction), header, size, buffer.data());
+    JAMI_LOG("[SDP {}] {}\n{:s}", getSdpDirectionStr(direction), header, std::string_view(buffer.data(), size));
 }
 
 void
@@ -574,8 +539,7 @@ Sdp::createOffer(const std::vector<MediaAttribute>& mediaList)
         return false;
     }
 
-    if (pjmedia_sdp_neg_create_w_local_offer(memPool_.get(), localSession_, &negotiator_)
-        != PJ_SUCCESS) {
+    if (pjmedia_sdp_neg_create_w_local_offer(memPool_.get(), localSession_, &negotiator_) != PJ_SUCCESS) {
         JAMI_ERR("Failed to create an initial SDP negotiator");
         return false;
     }
@@ -601,9 +565,7 @@ Sdp::processIncomingOffer(const std::vector<MediaAttribute>& mediaList)
     if (not remoteSession_)
         return false;
 
-    JAMI_DEBUG("Processing received offer for [{:s}] with {:d} media",
-             sessionName_,
-             mediaList.size());
+    JAMI_DEBUG("Processing received offer for [{:s}] with {:d} media", sessionName_, mediaList.size());
 
     printSession(remoteSession_, "Remote session:", SdpDirection::OFFER);
 
@@ -628,10 +590,7 @@ Sdp::processIncomingOffer(const std::vector<MediaAttribute>& mediaList)
         return false;
     }
 
-    if (pjmedia_sdp_neg_create_w_remote_offer(memPool_.get(),
-                                              localSession_,
-                                              remoteSession_,
-                                              &negotiator_)
+    if (pjmedia_sdp_neg_create_w_remote_offer(memPool_.get(), localSession_, remoteSession_, &negotiator_)
         != PJ_SUCCESS) {
         JAMI_ERR("Failed to initialize media negotiation");
         return false;
@@ -646,7 +605,7 @@ Sdp::startNegotiation()
     JAMI_DBG("Starting media negotiation for [%s]", sessionName_.c_str());
 
     if (negotiator_ == NULL) {
-        JAMI_ERR("Can't start negotiation with invalid negotiator");
+        JAMI_ERR("Unable to start negotiation with invalid negotiator");
         return false;
     }
 
@@ -664,7 +623,7 @@ Sdp::startNegotiation()
     }
 
     if (pjmedia_sdp_neg_get_active_local(negotiator_, &active_local) != PJ_SUCCESS)
-        JAMI_ERR("Could not retrieve local active session");
+        JAMI_ERR("Unable to retrieve local active session");
 
     setActiveLocalSdpSession(active_local);
 
@@ -672,9 +631,8 @@ Sdp::startNegotiation()
         printSession(active_local, "Local active session:", sdpDirection_);
     }
 
-    if (pjmedia_sdp_neg_get_active_remote(negotiator_, &active_remote) != PJ_SUCCESS
-        or active_remote == nullptr) {
-        JAMI_ERR("Could not retrieve remote active session");
+    if (pjmedia_sdp_neg_get_active_remote(negotiator_, &active_remote) != PJ_SUCCESS or active_remote == nullptr) {
+        JAMI_ERR("Unable to retrieve remote active session");
         return false;
     }
 
@@ -689,16 +647,11 @@ std::string
 Sdp::getFilteredSdp(const pjmedia_sdp_session* session, unsigned media_keep, unsigned pt_keep)
 {
     static constexpr size_t BUF_SZ = 4096;
-    std::unique_ptr<pj_pool_t, decltype(pj_pool_release)&>
-        tmpPool_(pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory,
-                                "tmpSdp",
-                                BUF_SZ,
-                                BUF_SZ,
-                                nullptr),
-                 pj_pool_release);
+    sip_utils::PoolPtr tmpPool_(
+        pj_pool_create(&Manager::instance().sipVoIPLink().getCachingPool()->factory, "tmpSdp", BUF_SZ, BUF_SZ, nullptr));
     auto cloned = pjmedia_sdp_session_clone(tmpPool_.get(), session);
     if (!cloned) {
-        JAMI_ERR("Could not clone SDP");
+        JAMI_ERR("Unable to clone SDP");
         return "";
     }
 
@@ -707,7 +660,7 @@ Sdp::getFilteredSdp(const pjmedia_sdp_session* session, unsigned media_keep, uns
     for (unsigned i = 0; i < cloned->media_count; i++)
         if (i != media_keep) {
             if (pjmedia_sdp_media_deactivate(tmpPool_.get(), cloned->media[i]) != PJ_SUCCESS)
-                JAMI_ERR("Could not deactivate media");
+                JAMI_ERR("Unable to deactivate media");
         } else {
             hasKeep = true;
         }
@@ -740,9 +693,7 @@ Sdp::getFilteredSdp(const pjmedia_sdp_session* session, unsigned media_keep, uns
             while (auto attr = pjmedia_sdp_attr_find2(media->attr_count, media->attr, "fmt", &pt))
                 pjmedia_sdp_attr_remove(&media->attr_count, media->attr, attr);
 
-            std::move(media->desc.fmt + c + 1,
-                      media->desc.fmt + media->desc.fmt_count,
-                      media->desc.fmt + c);
+            std::move(media->desc.fmt + c + 1, media->desc.fmt + media->desc.fmt_count, media->desc.fmt + c);
             media->desc.fmt_count--;
             c--;
         }
@@ -794,7 +745,7 @@ Sdp::getMediaDescriptions(const pjmedia_sdp_session* session, bool remote) const
         // get connection info
         pjmedia_sdp_conn* conn = media->conn ? media->conn : session->conn;
         if (not conn) {
-            JAMI_ERR("Could not find connection information for media");
+            JAMI_ERR("Unable to find connection information for media");
             continue;
         }
         descr.addr = std::string_view(conn->addr.ptr, conn->addr.slen);
@@ -828,20 +779,15 @@ Sdp::getMediaDescriptions(const pjmedia_sdp_session* session, bool remote) const
 
         // get codecs infos
         for (unsigned j = 0; j < media->desc.fmt_count; j++) {
-            const auto rtpMapAttribute = pjmedia_sdp_media_find_attr(media,
-                                                                     &STR_RTPMAP,
-                                                                     &media->desc.fmt[j]);
+            const auto rtpMapAttribute = pjmedia_sdp_media_find_attr(media, &STR_RTPMAP, &media->desc.fmt[j]);
             if (!rtpMapAttribute) {
-                JAMI_ERR("Could not find rtpmap attribute");
+                JAMI_ERR("Unable to find rtpmap attribute");
                 descr.enabled = false;
                 continue;
             }
             pjmedia_sdp_rtpmap rtpmap;
-            if (pjmedia_sdp_attr_get_rtpmap(rtpMapAttribute, &rtpmap) != PJ_SUCCESS
-                || rtpmap.enc_name.slen == 0) {
-                JAMI_ERR("Could not find payload type %.*s in SDP",
-                         (int) media->desc.fmt[j].slen,
-                         media->desc.fmt[j].ptr);
+            if (pjmedia_sdp_attr_get_rtpmap(rtpMapAttribute, &rtpmap) != PJ_SUCCESS || rtpmap.enc_name.slen == 0) {
+                JAMI_ERROR("Unable to find payload type {} in SDP", sip_utils::as_view(media->desc.fmt[j]));
                 descr.enabled = false;
                 continue;
             }
@@ -849,15 +795,13 @@ Sdp::getMediaDescriptions(const pjmedia_sdp_session* session, bool remote) const
             descr.rtp_clockrate = rtpmap.clock_rate;
             descr.codec = findCodecBySpec(codec_raw, rtpmap.clock_rate);
             if (not descr.codec) {
-                JAMI_ERR("Could not find codec %.*s", (int) codec_raw.size(), codec_raw.data());
+                JAMI_ERROR("Unable to find codec {}", codec_raw);
                 descr.enabled = false;
                 continue;
             }
             descr.payload_type = pj_strtoul(&rtpmap.pt);
             if (descr.type == MEDIA_VIDEO) {
-                const auto fmtpAttr = pjmedia_sdp_media_find_attr(media,
-                                                                  &STR_FMTP,
-                                                                  &media->desc.fmt[j]);
+                const auto fmtpAttr = pjmedia_sdp_media_find_attr(media, &STR_FMTP, &media->desc.fmt[j]);
                 // descr.bitrate = getOutgoingVideoField(codec, "bitrate");
                 if (fmtpAttr && fmtpAttr->value.ptr && fmtpAttr->value.slen) {
                     const auto& v = fmtpAttr->value;
@@ -901,8 +845,7 @@ void
 Sdp::addIceCandidates(unsigned media_index, const std::vector<std::string>& cands)
 {
     if (media_index >= localSession_->media_count) {
-        JAMI_ERR("addIceCandidates failed: cannot access media#%u (may be deactivated)",
-                 media_index);
+        JAMI_ERR("addIceCandidates failed: unable to access media#%u (may be deactivated)", media_index);
         return;
     }
 
@@ -913,7 +856,7 @@ Sdp::addIceCandidates(unsigned media_index, const std::vector<std::string>& cand
         pjmedia_sdp_attr* attr = pjmedia_sdp_attr_create(memPool_.get(), "candidate", &val);
 
         if (pjmedia_sdp_media_add_attr(media, attr) != PJ_SUCCESS)
-            throw SdpException("Could not add ICE candidates attribute to media");
+            throw SdpException("Unable to add ICE candidates attribute to media");
     }
 }
 
@@ -931,8 +874,7 @@ Sdp::getIceCandidates(unsigned media_index) const
         return {};
     }
     if (media_index >= remoteSession->media_count || media_index >= localSession->media_count) {
-        JAMI_ERR("getIceCandidates failed: cannot access media#%u (may be deactivated)",
-                 media_index);
+        JAMI_ERR("getIceCandidates failed: unable to access media#%u (may be deactivated)", media_index);
         return {};
     }
     auto media = remoteSession->media[media_index];
@@ -957,22 +899,22 @@ Sdp::getIceCandidates(unsigned media_index) const
 }
 
 void
-Sdp::addIceAttributes(const IceTransport::Attribute&& ice_attrs)
+Sdp::addIceAttributes(const dhtnet::IceTransport::Attribute&& ice_attrs)
 {
     pj_str_t value = sip_utils::CONST_PJ_STR(ice_attrs.ufrag);
     pjmedia_sdp_attr* attr = pjmedia_sdp_attr_create(memPool_.get(), "ice-ufrag", &value);
 
     if (pjmedia_sdp_attr_add(&localSession_->attr_count, localSession_->attr, attr) != PJ_SUCCESS)
-        throw SdpException("Could not add ICE.ufrag attribute to local SDP");
+        throw SdpException("Unable to add ICE.ufrag attribute to local SDP");
 
     value = sip_utils::CONST_PJ_STR(ice_attrs.pwd);
     attr = pjmedia_sdp_attr_create(memPool_.get(), "ice-pwd", &value);
 
     if (pjmedia_sdp_attr_add(&localSession_->attr_count, localSession_->attr, attr) != PJ_SUCCESS)
-        throw SdpException("Could not add ICE.pwd attribute to local SDP");
+        throw SdpException("Unable to add ICE.pwd attribute to local SDP");
 }
 
-IceTransport::Attribute
+dhtnet::IceTransport::Attribute
 Sdp::getIceAttributes() const
 {
     if (auto session = activeRemoteSession_ ? activeRemoteSession_ : remoteSession_)
@@ -980,17 +922,35 @@ Sdp::getIceAttributes() const
     return {};
 }
 
-IceTransport::Attribute
+dhtnet::IceTransport::Attribute
 Sdp::getIceAttributes(const pjmedia_sdp_session* session)
 {
-    IceTransport::Attribute ice_attrs;
+    dhtnet::IceTransport::Attribute ice_attrs;
+    // Per RFC8839, ice-ufrag/ice-pwd can be present either at
+    // media or session level.
+    // This seems to be the case for Asterisk servers (ICE is at media-session).
     for (unsigned i = 0; i < session->attr_count; i++) {
         pjmedia_sdp_attr* attribute = session->attr[i];
         if (pj_stricmp2(&attribute->name, "ice-ufrag") == 0)
             ice_attrs.ufrag.assign(attribute->value.ptr, attribute->value.slen);
         else if (pj_stricmp2(&attribute->name, "ice-pwd") == 0)
             ice_attrs.pwd.assign(attribute->value.ptr, attribute->value.slen);
+        if (!ice_attrs.ufrag.empty() && !ice_attrs.pwd.empty())
+            return ice_attrs;
     }
+    for (unsigned i = 0; i < session->media_count; i++) {
+        auto* media = session->media[i];
+        for (unsigned j = 0; j < media->attr_count; j++) {
+            pjmedia_sdp_attr* attribute = media->attr[j];
+            if (pj_stricmp2(&attribute->name, "ice-ufrag") == 0)
+                ice_attrs.ufrag.assign(attribute->value.ptr, attribute->value.slen);
+            else if (pj_stricmp2(&attribute->name, "ice-pwd") == 0)
+                ice_attrs.pwd.assign(attribute->value.ptr, attribute->value.slen);
+            if (!ice_attrs.ufrag.empty() && !ice_attrs.pwd.empty())
+                return ice_attrs;
+        }
+    }
+
     return ice_attrs;
 }
 
@@ -1056,13 +1016,12 @@ Sdp::getMediaAttributeListFromSdp(const pjmedia_sdp_session* sdpSession, bool ig
 
         // Get mute state.
         auto direction = getMediaDirection(media);
-        mediaAttr.muted_ = direction != MediaDirection::SENDRECV
-                           and direction != MediaDirection::SENDONLY;
+        mediaAttr.muted_ = direction != MediaDirection::SENDRECV and direction != MediaDirection::SENDONLY;
 
         // Get transport.
         auto transp = getMediaTransport(media);
         if (transp == MediaTransport::UNKNOWN) {
-            JAMI_WARN("Media#%u could not determine transport type!", idx);
+            JAMI_WARN("Media#%u is unable to determine transport type!", idx);
         }
 
         // A media is secure if the transport is of type RTP/SAVP
