@@ -1,27 +1,19 @@
 /*
- *  Copyright (C) 2004-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
- *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
- *  Author: Laurielle Lea <laurielle.lea@savoirfairelinux.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *  Author: Philippe Gorley <philippe.gorley@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
-
 #pragma once
 
 #ifdef HAVE_CONFIG_H
@@ -29,9 +21,9 @@
 #endif
 
 #include "call.h"
-#include "connectivity/ice_transport.h"
-#include "media_codec.h" // for MediaType enum
+#include <dhtnet/ice_transport.h>
 #include "connectivity/sip_utils.h"
+#include "media/media_codec.h" // for MediaType enum
 #include "sip/sdp.h"
 
 #include "media/rtp_session.h"
@@ -56,20 +48,22 @@ struct pj_ice_sess_cand;
 struct pjsip_rx_data;
 }
 
+namespace dhtnet {
+class IceSocket;
+namespace upnp {
+class Controller;
+}
+} // namespace dhtnet
+
 namespace jami {
 
 class Sdp;
 class SIPAccountBase;
 class SipTransport;
 class AudioRtpSession;
-class IceSocket;
 
 using IceCandidate = pj_ice_sess_cand;
 
-namespace upnp {
-class Controller;
-}
-
 /**
  * @file sipcall.h
  * @brief SIPCall are SIP implementation of a normal Call
@@ -90,8 +84,8 @@ public:
         std::shared_ptr<RtpSession> rtpSession_ {};
         std::shared_ptr<MediaAttribute> mediaAttribute_ {};
         std::shared_ptr<MediaAttribute> remoteMediaAttribute_;
-        std::unique_ptr<IceSocket> rtpSocket_;
-        std::unique_ptr<IceSocket> rtcpSocket_;
+        std::unique_ptr<dhtnet::IceSocket> rtpSocket_;
+        std::unique_ptr<dhtnet::IceSocket> rtcpSocket_;
     };
 
     /**
@@ -122,8 +116,7 @@ public:
     void answer(const std::vector<libjami::MediaMap>& mediaList) override;
     bool checkMediaChangeRequest(const std::vector<libjami::MediaMap>& remoteMediaList) override;
     void handleMediaChangeRequest(const std::vector<libjami::MediaMap>& remoteMediaList) override;
-    void answerMediaChangeRequest(const std::vector<libjami::MediaMap>& mediaList,
-                                  bool isRemote = false) override;
+    void answerMediaChangeRequest(const std::vector<libjami::MediaMap>& mediaList, bool isRemote = false) override;
     void hangup(int reason) override;
     void refuse() override;
     void transfer(const std::string& to) override;
@@ -135,14 +128,14 @@ public:
     void carryingDTMFdigits(char code) override;
     bool requestMediaChange(const std::vector<libjami::MediaMap>& mediaList) override;
     std::vector<libjami::MediaMap> currentMediaList() const override;
-    void sendTextMessage(const std::map<std::string, std::string>& messages,
-                         const std::string& from) override;
+    void sendTextMessage(const std::map<std::string, std::string>& messages, const std::string& from) override;
     void removeCall() override;
     void muteMedia(const std::string& mediaType, bool isMuted) override;
     std::vector<MediaAttribute> getMediaAttributeList() const override;
+    std::map<std::string, bool> getAudioStreams() const override;
     void restartMediaSender() override;
-    std::shared_ptr<AccountCodecInfo> getAudioCodec() const override;
-    std::shared_ptr<AccountCodecInfo> getVideoCodec() const override;
+    std::shared_ptr<SystemCodecInfo> getAudioCodec() const override;
+    std::shared_ptr<SystemCodecInfo> getVideoCodec() const override;
     void sendKeyframe(int streamIdx = -1) override;
     bool isIceEnabled() const override;
     std::map<std::string, std::string> getDetails() const override;
@@ -158,10 +151,7 @@ public:
 
     // TODO: cleanup this (used by conference + Call::getDetails() (and clients can use this))
     bool isCaptureDeviceMuted(const MediaType& mediaType) const override;
-    bool isSrtpEnabled() const
-    {
-        return srtpEnabled_;
-    }
+    bool isSrtpEnabled() const { return srtpEnabled_; }
     // End of override of Call class
 
     // Override of Recordable class
@@ -194,10 +184,7 @@ public:
     /**
      * Return the SDP's manager of this call
      */
-    Sdp& getSDP()
-    {
-        return *sdp_;
-    }
+    Sdp& getSDP() { return *sdp_; }
 
     // Implementation of events reported by SipVoipLink.
     /**
@@ -234,13 +221,9 @@ public:
 
     const std::string& getContactHeader() const;
 
-    void setSipTransport(const std::shared_ptr<SipTransport>& transport,
-                         const std::string& contactHdr = {});
+    void setSipTransport(const std::shared_ptr<SipTransport>& transport, const std::string& contactHdr = {});
 
-    SipTransport* getTransport()
-    {
-        return sipTransport_.get();
-    }
+    SipTransport* getTransport() { return sipTransport_.get(); }
 
     void sendSIPInfo(std::string_view body, std::string_view subtype);
 
@@ -253,14 +236,14 @@ public:
     bool remoteHasValidIceAttributes() const;
     void addLocalIceAttributes();
 
-    std::shared_ptr<IceTransport> getIceMedia() const
+    std::shared_ptr<dhtnet::IceTransport> getIceMedia() const
     {
-        std::lock_guard<std::mutex> lk(transportMtx_);
+        std::lock_guard lk(transportMtx_);
         return reinvIceMedia_ ? reinvIceMedia_ : iceMedia_;
     };
 
     // Set ICE instance. Must be called only for sub-calls
-    void setIceMedia(std::shared_ptr<IceTransport> ice, bool isReinvite = false);
+    void setIceMedia(std::shared_ptr<dhtnet::IceTransport> ice, bool isReinvite = false);
 
     // Switch to re-invite ICE media if needed
     void switchToIceReinviteIfNeeded();
@@ -285,27 +268,18 @@ public:
     void setRotation(int streamIdx, int rotation);
 #endif
     // Get the list of current RTP sessions
-    std::vector<std::shared_ptr<RtpSession>> getRtpSessionList(
-        MediaType type = MediaType::MEDIA_ALL) const;
+    std::vector<std::shared_ptr<RtpSession>> getRtpSessionList(MediaType type = MediaType::MEDIA_ALL) const;
     static size_t getActiveMediaStreamCount(const std::vector<MediaAttribute>& mediaAttrList);
     void setActiveMediaStream(const std::string& accountUri,
                               const std::string& deviceId,
                               const std::string& streamId,
                               const bool& state);
 
-    void setPeerRegisteredName(const std::string& name)
-    {
-        peerRegisteredName_ = name;
-    }
+    void setPeerRegisteredName(const std::string& name) { peerRegisteredName_ = name; }
 
-    void setPeerUri(const std::string& peerUri)
-    {
-        peerUri_ = peerUri;
-    }
+    void setPeerUri(const std::string& peerUri) { peerUri_ = peerUri; }
 
-    std::string_view peerUri() const {
-        return peerUri_;
-    }
+    std::string_view peerUri() const { return peerUri_; }
 
     // Create a new ICE media session. If we already have an instance,
     // it will be destroyed first.
@@ -314,8 +288,7 @@ public:
     // Initialize the ICE session.
     // The initialization is performed asynchronously, i.e, the instance
     // may not be ready to use when this method returns.
-    bool initIceMediaTransport(bool master,
-                               std::optional<IceTransportOptions> options = std::nullopt);
+    bool initIceMediaTransport(bool master, std::optional<dhtnet::IceTransportOptions> options = std::nullopt);
 
     std::vector<std::string> getLocalIceCandidates(unsigned compId) const;
 
@@ -323,19 +296,15 @@ public:
 
     std::unique_ptr<pjsip_inv_session, InvSessionDeleter> inviteSession_;
 
-    inline std::weak_ptr<const SIPCall> weak() const
-    {
-        return std::weak_ptr<const SIPCall>(shared());
-    }
-    inline std::weak_ptr<SIPCall> weak()
-    {
-        return std::weak_ptr<SIPCall>(shared());
-    }
+    inline std::weak_ptr<const SIPCall> weak() const { return std::weak_ptr<const SIPCall>(shared()); }
+    inline std::weak_ptr<SIPCall> weak() { return std::weak_ptr<SIPCall>(shared()); }
     /**
      * Announce to the client that medias are successfully negotiated
      */
     void reportMediaNegotiationStatus();
 
+    const std::vector<RtpStream>& getRtpStreams() const { return rtpStreams_; }
+
 private:
     void generateMediaPorts();
 
@@ -343,7 +312,7 @@ private:
 
     bool isIceRunning() const;
 
-    std::unique_ptr<IceSocket> newIceSocket(unsigned compId);
+    std::unique_ptr<dhtnet::IceSocket> newIceSocket(unsigned compId);
 
     void deinitRecorder();
 
@@ -354,7 +323,7 @@ private:
     void sendMuteState(bool state);
     void sendVoiceActivity(std::string_view streamId, bool state);
 
-    void resetTransport(std::shared_ptr<IceTransport>&& transport);
+    void resetTransport(std::shared_ptr<dhtnet::IceTransport>&& transport);
 
     /**
      * Send device orientation through SIP INFO
@@ -403,7 +372,6 @@ private:
     void setupNegotiatedMedia();
     void startAllMedia();
     void stopAllMedia();
-    void updateRemoteMedia();
 
     /**
      * Transfer method used for both type of transfer
@@ -440,21 +408,20 @@ private:
     // Find the stream index with the matching label
     int findRtpStreamIndex(const std::string& label) const;
 
-    std::vector<IceCandidate> getAllRemoteCandidates(IceTransport& transport) const;
+    std::vector<IceCandidate> getAllRemoteCandidates(dhtnet::IceTransport& transport) const;
 
     inline std::shared_ptr<const SIPCall> shared() const
     {
         return std::static_pointer_cast<const SIPCall>(shared_from_this());
     }
-    inline std::shared_ptr<SIPCall> shared()
-    {
-        return std::static_pointer_cast<SIPCall>(shared_from_this());
-    }
+    inline std::shared_ptr<SIPCall> shared() { return std::static_pointer_cast<SIPCall>(shared_from_this()); }
 
     // Peer's User-Agent.
     std::string peerUserAgent_ {};
     // Flag to indicate if the peer's Daemon version supports multi-stream.
     bool peerSupportMultiStream_ {false};
+    // Flag to indicate if the peer's Daemon version supports multi-stream.
+    bool peerSupportMultiAudioStream_ {false};
     // Flag to indicate if the peer's Daemon version can negotiate more than 2 ICE medias
     bool peerSupportMultiIce_ {false};
 
@@ -489,7 +456,7 @@ private:
 
     std::string contactHeader_ {};
 
-    std::shared_ptr<jami::upnp::Controller> upnp_;
+    std::shared_ptr<dhtnet::upnp::Controller> upnp_;
 
     /** Local audio port, as seen by me. */
     unsigned int localAudioPort_ {0};
@@ -502,9 +469,9 @@ private:
     bool rtcpMuxEnabled_ {false};
 
     // ICE media transport
-    std::shared_ptr<IceTransport> iceMedia_;
+    std::shared_ptr<dhtnet::IceTransport> iceMedia_;
     // Re-invite (temporary) ICE media transport.
-    std::shared_ptr<IceTransport> reinvIceMedia_;
+    std::shared_ptr<dhtnet::IceTransport> reinvIceMedia_;
 
     std::string peerUri_ {};
 
@@ -520,10 +487,12 @@ private:
 
     void detachAudioFromConference();
 
-    std::mutex setupSuccessMutex_;
+    std::mutex mediaStateMutex_;
 #ifdef ENABLE_VIDEO
     int rotation_ {0};
 #endif
+
+    std::string mediaPlayerId_ {};
 };
 
 // Helpers
