@@ -1,25 +1,18 @@
 /*
- *  Copyright (C) 2004-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2025 Savoir-faire Linux Inc.
  *
- *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
- *  Author: Yun Liu <yun.liu@savoirfairelinux.com>
- *  Author: Pierre-Luc Bacon <pierre-luc.bacon@savoirfairelinux.com>
- *  Author: Alexandre Savard <alexandre.savard@savoirfairelinux.com>
- *  Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>
- *
- *  This program is free software; you can redistribute it and/or modify
+ *  This program is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 3 of the License, or
+ *  the Free Software Foundation, either version 3 of the License, or
  *  (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA.
+ *  along with this program. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "sip/sipvoiplink.h"
@@ -80,17 +73,13 @@ static pjsip_module mod_ua_;
 
 static void invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* e);
 static void outgoing_request_forked_cb(pjsip_inv_session* inv, pjsip_event* e);
-static void transaction_state_changed_cb(pjsip_inv_session* inv,
-                                         pjsip_transaction* tsx,
-                                         pjsip_event* e);
+static void transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjsip_event* e);
 // Called when an SDP offer is found in answer. This will occur
 // when we send an empty invite (no SDP). In this case, we should
 // expect an offer in a the 200 OK message
 static void on_rx_offer2(pjsip_inv_session* inv, struct pjsip_inv_on_rx_offer_cb_param* param);
 // Called when a re-invite is received
-static pj_status_t reinvite_received_cb(pjsip_inv_session* inv,
-                                        const pjmedia_sdp_session* offer,
-                                        pjsip_rx_data* rdata);
+static pj_status_t reinvite_received_cb(pjsip_inv_session* inv, const pjmedia_sdp_session* offer, pjsip_rx_data* rdata);
 // Called to request an SDP offer if the peer sent an invite or
 // a re-invite with no SDP. In this, we must provide an offer in
 // the answer (200 OK) if we accept the call
@@ -242,14 +231,12 @@ transaction_request_cb(pjsip_rx_data* rdata)
         return PJ_FALSE;
     }
 
-    const auto sip_to_uri = reinterpret_cast<pjsip_sip_uri*>(
-        pjsip_uri_get_uri(rdata->msg_info.to->uri));
-    const auto sip_from_uri = reinterpret_cast<pjsip_sip_uri*>(
-        pjsip_uri_get_uri(rdata->msg_info.from->uri));
+    const auto sip_to_uri = reinterpret_cast<pjsip_sip_uri*>(pjsip_uri_get_uri(rdata->msg_info.to->uri));
+    const auto sip_from_uri = reinterpret_cast<pjsip_sip_uri*>(pjsip_uri_get_uri(rdata->msg_info.from->uri));
     const pjsip_host_port& sip_via = rdata->msg_info.via->sent_by;
 
     if (!sip_to_uri or !sip_from_uri or !sip_via.host.ptr) {
-        JAMI_ERR("NULL uri");
+        JAMI_ERR("NULL URI");
         return PJ_FALSE;
     }
 
@@ -263,23 +250,17 @@ transaction_request_cb(pjsip_rx_data* rdata)
         peerNumber = remote_user + "@" + remote_hostname;
     else {
         char tmp[PJSIP_MAX_URL_SIZE];
-        size_t length = pjsip_uri_print(PJSIP_URI_IN_FROMTO_HDR,
-                                        sip_from_uri,
-                                        tmp,
-                                        PJSIP_MAX_URL_SIZE);
+        size_t length = pjsip_uri_print(PJSIP_URI_IN_FROMTO_HDR, sip_from_uri, tmp, PJSIP_MAX_URL_SIZE);
         peerNumber = sip_utils::stripSipUriPrefix(std::string_view(tmp, length));
     }
 
-    auto transport = Manager::instance().sipVoIPLink().sipTransportBroker->addTransport(
-        rdata->tp_info.transport);
+    auto transport = Manager::instance().sipVoIPLink().sipTransportBroker->addTransport(rdata->tp_info.transport);
 
     std::shared_ptr<SIPAccountBase> account;
     // If transport account is default-constructed, guessing account is allowed
     const auto& waccount = transport ? transport->getAccount() : std::weak_ptr<SIPAccountBase> {};
     if (is_uninitialized(waccount)) {
-        account = Manager::instance().sipVoIPLink().guessAccount(toUsername,
-                                                                 viaHostname,
-                                                                 remote_hostname);
+        account = Manager::instance().sipVoIPLink().guessAccount(toUsername, viaHostname, remote_hostname);
         if (not account)
             return PJ_FALSE;
         if (not transport and account->getAccountType() == SIPAccount::ACCOUNT_TYPE) {
@@ -308,11 +289,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
                     int oldCount {0};
                     int urgentCount {0};
                     std::string sp(body_view.substr(pos));
-                    int ret = sscanf(sp.c_str(),
-                                     "Voice-Message: %d/%d (%d/",
-                                     &newCount,
-                                     &oldCount,
-                                     &urgentCount);
+                    int ret = sscanf(sp.c_str(), "Voice-Message: %d/%d (%d/", &newCount, &oldCount, &urgentCount);
 
                     // According to rfc3842
                     // urgent messages are optional
@@ -330,17 +307,16 @@ transaction_request_cb(pjsip_rx_data* rdata)
             auto payloads = im::parseSipMessage(rdata->msg_info.msg);
             if (payloads.size() > 0) {
                 constexpr pj_str_t STR_MESSAGE_ID = jami::sip_utils::CONST_PJ_STR("Message-ID");
-                auto* msgId = (pjsip_generic_string_hdr*)
-                    pjsip_msg_find_hdr_by_name(rdata->msg_info.msg, &STR_MESSAGE_ID, nullptr);
+                auto* msgId = (pjsip_generic_string_hdr*) pjsip_msg_find_hdr_by_name(rdata->msg_info.msg,
+                                                                                     &STR_MESSAGE_ID,
+                                                                                     nullptr);
                 std::string id = {};
                 if (!msgId) {
-                    // Supports imdn message format https://tools.ietf.org/html/rfc5438#section-7.1.1.3
-                    constexpr pj_str_t STR_IMDN_MESSAGE_ID = jami::sip_utils::CONST_PJ_STR(
-                        "imdn.Message-ID");
-                    msgId = (pjsip_generic_string_hdr*)
-                        pjsip_msg_find_hdr_by_name(rdata->msg_info.msg,
-                                                   &STR_IMDN_MESSAGE_ID,
-                                                   nullptr);
+                    // Supports IMDN message format https://tools.ietf.org/html/rfc5438#section-7.1.1.3
+                    constexpr pj_str_t STR_IMDN_MESSAGE_ID = jami::sip_utils::CONST_PJ_STR("imdn.Message-ID");
+                    msgId = (pjsip_generic_string_hdr*) pjsip_msg_find_hdr_by_name(rdata->msg_info.msg,
+                                                                                   &STR_IMDN_MESSAGE_ID,
+                                                                                   nullptr);
                 }
                 if (msgId)
                     id = std::string(msgId->hvalue.ptr, msgId->hvalue.slen);
@@ -348,13 +324,14 @@ transaction_request_cb(pjsip_rx_data* rdata)
                 if (not id.empty()) {
                     try {
                         // Mark message as treated
+                        auto intid = from_hex_string(id);
                         auto acc = std::dynamic_pointer_cast<JamiAccount>(account);
-                        if (acc and acc->isMessageTreated(id))
+                        if (acc and acc->isMessageTreated(intid))
                             return PJ_FALSE;
                     } catch (...) {
                     }
                 }
-                account->onTextMessage(id, peerNumber, std::string(transport->deviceId()), payloads);
+                account->onTextMessage(id, peerNumber, transport->getTlsInfos().peerCert, payloads);
             }
             return PJ_FALSE;
         }
@@ -377,8 +354,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
 
     pjmedia_sdp_session* r_sdp {nullptr};
     if (body) {
-        if (pjmedia_sdp_parse(rdata->tp_info.pool, (char*) body->data, body->len, &r_sdp)
-            != PJ_SUCCESS) {
+        if (pjmedia_sdp_parse(rdata->tp_info.pool, (char*) body->data, body->len, &r_sdp) != PJ_SUCCESS) {
             JAMI_WARN("Failed to parse the SDP in offer");
             r_sdp = nullptr;
         }
@@ -393,7 +369,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
     unsigned options = 0;
 
     if (pjsip_inv_verify_request(rdata, &options, NULL, NULL, endpt_, NULL) != PJ_SUCCESS) {
-        JAMI_ERR("Couldn't verify INVITE request in secure dialog.");
+        JAMI_ERR("Unable to verify INVITE request in secure dialog.");
         try_respond_stateless(endpt_, rdata, PJSIP_SC_METHOD_NOT_ALLOWED, NULL, NULL, NULL);
         return PJ_FALSE;
     }
@@ -419,15 +395,13 @@ transaction_request_cb(pjsip_rx_data* rdata)
     // The username can be used to join specific calls in conversations
     call->toUsername(std::string(toUsername));
 
-    // FIXME : for now, use the same address family as the SIP transport
-    auto family = pjsip_transport_type_get_af(
-        pjsip_transport_get_type_from_flag(transport->get()->flag));
+    // FIXME: for now, use the same address family as the SIP transport
+    auto family = pjsip_transport_type_get_af(pjsip_transport_get_type_from_flag(transport->get()->flag));
 
     dhtnet::IpAddr addrSdp;
     if (account->getUPnPActive()) {
         /* use UPnP addr, or published addr if its set */
-        addrSdp = account->getPublishedSameasLocal() ? account->getUPnPIpAddress()
-                                                     : account->getPublishedIpAddress();
+        addrSdp = account->getPublishedSameasLocal() ? account->getUPnPIpAddress() : account->getPublishedIpAddress();
     } else {
         addrSdp = account->isStunEnabled() or (not account->getPublishedSameasLocal())
                       ? account->getPublishedIpAddress()
@@ -461,22 +435,16 @@ transaction_request_cb(pjsip_rx_data* rdata)
     }
 
     pjsip_dialog* dialog = nullptr;
-    if (pjsip_dlg_create_uas_and_inc_lock(pjsip_ua_instance(), rdata, nullptr, &dialog)
-        != PJ_SUCCESS) {
-        JAMI_ERR("Could not create uas");
+    if (pjsip_dlg_create_uas_and_inc_lock(pjsip_ua_instance(), rdata, nullptr, &dialog) != PJ_SUCCESS) {
+        JAMI_ERR("Unable to create UAS");
         call.reset();
-        try_respond_stateless(endpt_,
-                              rdata,
-                              PJSIP_SC_INTERNAL_SERVER_ERROR,
-                              nullptr,
-                              nullptr,
-                              nullptr);
+        try_respond_stateless(endpt_, rdata, PJSIP_SC_INTERNAL_SERVER_ERROR, nullptr, nullptr, nullptr);
         return PJ_FALSE;
     }
 
     pjsip_tpselector tp_sel = SIPVoIPLink::getTransportSelector(transport->get());
     if (!dialog or pjsip_dlg_set_transport(dialog, &tp_sel) != PJ_SUCCESS) {
-        JAMI_ERR("Could not set transport for dialog");
+        JAMI_ERR("Unable to set transport for dialog");
         if (dialog)
             pjsip_dlg_dec_lock(dialog);
         return PJ_FALSE;
@@ -522,14 +490,8 @@ transaction_request_cb(pjsip_rx_data* rdata)
     // Check if call has been transferred
     pjsip_tx_data* tdata = nullptr;
 
-    if (pjsip_inv_initial_answer(call->inviteSession_.get(),
-                                 rdata,
-                                 PJSIP_SC_TRYING,
-                                 NULL,
-                                 NULL,
-                                 &tdata)
-        != PJ_SUCCESS) {
-        JAMI_ERR("Could not create answer TRYING");
+    if (pjsip_inv_initial_answer(call->inviteSession_.get(), rdata, PJSIP_SC_TRYING, NULL, NULL, &tdata) != PJ_SUCCESS) {
+        JAMI_ERR("Unable to create answer TRYING");
         return PJ_FALSE;
     }
 
@@ -537,21 +499,20 @@ transaction_request_cb(pjsip_rx_data* rdata)
     sip_utils::addUserAgentHeader(account->getUserAgentName(), tdata);
 
     if (pjsip_inv_send_msg(call->inviteSession_.get(), tdata) != PJ_SUCCESS) {
-        JAMI_ERR("Could not send msg TRYING");
+        JAMI_ERR("Unable to send msg TRYING");
         return PJ_FALSE;
     }
 
     call->setState(Call::ConnectionState::TRYING);
 
-    if (pjsip_inv_answer(call->inviteSession_.get(), PJSIP_SC_RINGING, NULL, NULL, &tdata)
-        != PJ_SUCCESS) {
-        JAMI_ERR("Could not create answer RINGING");
+    if (pjsip_inv_answer(call->inviteSession_.get(), PJSIP_SC_RINGING, NULL, NULL, &tdata) != PJ_SUCCESS) {
+        JAMI_ERR("Unable to create answer RINGING");
         return PJ_FALSE;
     }
 
     sip_utils::addContactHeader(call->getContactHeader(), tdata);
     if (pjsip_inv_send_msg(call->inviteSession_.get(), tdata) != PJ_SUCCESS) {
-        JAMI_ERR("Could not send msg RINGING");
+        JAMI_ERR("Unable to send msg RINGING");
         return PJ_FALSE;
     }
 
@@ -564,8 +525,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
         auto replaced_inv = pjsip_dlg_get_inv_session(replaced_dlg);
 
         // Disconnect the "replaced" INVITE session.
-        if (pjsip_inv_end_session(replaced_inv, PJSIP_SC_GONE, nullptr, &tdata) == PJ_SUCCESS
-            && tdata) {
+        if (pjsip_inv_end_session(replaced_inv, PJSIP_SC_GONE, nullptr, &tdata) == PJ_SUCCESS && tdata) {
             pjsip_inv_send_msg(replaced_inv, tdata);
         }
 
@@ -578,9 +538,7 @@ transaction_request_cb(pjsip_rx_data* rdata)
 }
 
 static void
-tp_state_callback(pjsip_transport* tp,
-                  pjsip_transport_state state,
-                  const pjsip_transport_state_info* info)
+tp_state_callback(pjsip_transport* tp, pjsip_transport_state state, const pjsip_transport_state_info* info)
 {
     if (auto& broker = Manager::instance().sipVoIPLink().sipTransportBroker)
         broker->transportStateChanged(tp, state, info);
@@ -615,7 +573,7 @@ SIPVoIPLink::getCachingPool() noexcept
 }
 
 SIPVoIPLink::SIPVoIPLink()
-    : pool_(nullptr, pj_pool_release)
+    : pool_(nullptr)
 {
 #define TRY(ret) \
     do { \
@@ -626,7 +584,7 @@ SIPVoIPLink::SIPVoIPLink()
     pj_caching_pool_init(&cp_, &pj_pool_factory_default_policy, 0);
     pool_.reset(pj_pool_create(&cp_.factory, PACKAGE, 64 * 1024, 4096, nullptr));
     if (!pool_)
-        throw VoipLinkException("UserAgent: Could not initialize memory pool");
+        throw VoipLinkException("UserAgent: Unable to initialize memory pool");
 
     TRY(pjsip_endpt_create(&cp_.factory, pj_gethostname()->ptr, &endpt_));
 
@@ -636,13 +594,8 @@ SIPVoIPLink::SIPVoIPLink()
         std::vector<pj_uint16_t> dns_ports(ns.size());
         for (unsigned i = 0, n = ns.size(); i < n; i++) {
             char hbuf[NI_MAXHOST];
-            if (auto ret = getnameinfo((sockaddr*) &ns[i],
-                                       ns[i].getLength(),
-                                       hbuf,
-                                       sizeof(hbuf),
-                                       nullptr,
-                                       0,
-                                       NI_NUMERICHOST)) {
+            if (auto ret
+                = getnameinfo((sockaddr*) &ns[i], ns[i].getLength(), hbuf, sizeof(hbuf), nullptr, 0, NI_NUMERICHOST)) {
                 JAMI_WARN("Error printing SIP nameserver: %s", gai_strerror(ret));
             } else {
                 JAMI_DBG("Using SIP nameserver: %s", hbuf);
@@ -661,8 +614,7 @@ SIPVoIPLink::SIPVoIPLink()
                 JAMI_WARN("Error setting SIP DNS servers: %s", sip_utils::sip_strerror(ret).c_str());
             } else {
                 if (auto ret = pjsip_endpt_set_resolver(endpt_, resv)) {
-                    JAMI_WARN("Error setting pjsip DNS resolver: %s",
-                              sip_utils::sip_strerror(ret).c_str());
+                    JAMI_WARN("Error setting PJSIP DNS resolver: %s", sip_utils::sip_strerror(ret).c_str());
                 }
             }
         }
@@ -672,7 +624,7 @@ SIPVoIPLink::SIPVoIPLink()
 
     auto status = pjsip_tpmgr_set_state_cb(pjsip_endpt_get_tpmgr(endpt_), tp_state_callback);
     if (status != PJ_SUCCESS)
-        JAMI_ERR("Can't set transport callback: %s", sip_utils::sip_strerror(status).c_str());
+        JAMI_ERR("Unable to set transport callback: %s", sip_utils::sip_strerror(status).c_str());
 
     TRY(pjsip_tsx_layer_init_module(endpt_));
     TRY(pjsip_ua_init_module(endpt_, nullptr));
@@ -715,12 +667,7 @@ SIPVoIPLink::SIPVoIPLink()
         CONST_PJ_STR(sip_utils::SIP_METHODS::PUBLISH),
     };
 
-    pjsip_endpt_add_capability(endpt_,
-                               &mod_ua_,
-                               PJSIP_H_ALLOW,
-                               nullptr,
-                               PJ_ARRAY_SIZE(allowed),
-                               allowed);
+    pjsip_endpt_add_capability(endpt_, &mod_ua_, PJSIP_H_ALLOW, nullptr, PJ_ARRAY_SIZE(allowed), allowed);
 
     static constexpr pj_str_t text_plain = CONST_PJ_STR("text/plain");
     pjsip_endpt_add_capability(endpt_, &mod_ua_, PJSIP_H_ACCEPT, nullptr, 1, &text_plain);
@@ -747,13 +694,12 @@ SIPVoIPLink::~SIPVoIPLink() {}
 void
 SIPVoIPLink::shutdown()
 {
-    JAMI_DBG("Shutdown SIPVoIPLink@%p...", this);
+    JAMI_DBG("Shutting down SIPVoIPLink@%p…", this);
     // Remaining calls should not happen as possible upper callbacks
     // may be called and another instance of SIPVoIPLink can be re-created!
 
     if (not Manager::instance().callFactory.empty(Call::LinkType::SIP))
-        JAMI_ERR("%zu SIP calls remains!",
-                 Manager::instance().callFactory.callCount(Call::LinkType::SIP));
+        JAMI_ERR("%zu SIP calls remains!", Manager::instance().callFactory.callCount(Call::LinkType::SIP));
 
     sipTransportBroker->shutdown();
     pjsip_tpmgr_set_state_cb(pjsip_endpt_get_tpmgr(endpt_), nullptr);
@@ -765,22 +711,14 @@ SIPVoIPLink::shutdown()
     pj_caching_pool_destroy(&cp_);
     sipTransportBroker.reset();
 
-    JAMI_DBG("SIPVoIPLink@%p is shutdown", this);
+    JAMI_DBG("SIPVoIPLink@%p shutdown successfully completed", this);
 }
 
 std::shared_ptr<SIPAccountBase>
-SIPVoIPLink::guessAccount(std::string_view userName,
-                          std::string_view server,
-                          std::string_view fromUri) const
+SIPVoIPLink::guessAccount(std::string_view userName, std::string_view server, std::string_view fromUri) const
 {
-    JAMI_DBG("username = %.*s, server = %.*s, from = %.*s",
-             (int) userName.size(),
-             userName.data(),
-             (int) server.size(),
-             server.data(),
-             (int) fromUri.size(),
-             fromUri.data());
-    // Try to find the account id from username and server name by full match
+    JAMI_LOG("username = {}, server = {}, from = {}", userName, server, fromUri);
+    // Attempt to find the account id from username and server name by full match
 
     std::shared_ptr<SIPAccountBase> result;
     std::shared_ptr<SIPAccountBase> IP2IPAccount;
@@ -811,14 +749,13 @@ SIPVoIPLink::handleEvents()
 {
     const pj_time_val timeout = {1, 0};
     if (auto ret = pjsip_endpt_handle_events(endpt_, &timeout))
-        JAMI_ERR("pjsip_endpt_handle_events failed with error %s",
-                 sip_utils::sip_strerror(ret).c_str());
+        JAMI_ERR("pjsip_endpt_handle_events failed with error %s", sip_utils::sip_strerror(ret).c_str());
 }
 
 void
 SIPVoIPLink::registerKeepAliveTimer(pj_timer_entry& timer, pj_time_val& delay)
 {
-    JAMI_DEBUG("Register new keep alive timer {:d} with delay {:d}", timer.id, delay.sec);
+    JAMI_DEBUG("Register new keepalive timer {:d} with delay {:d}", timer.id, delay.sec);
 
     if (timer.id == -1)
         JAMI_WARN("Timer already scheduled");
@@ -828,7 +765,7 @@ SIPVoIPLink::registerKeepAliveTimer(pj_timer_entry& timer, pj_time_val& delay)
         break;
 
     default:
-        JAMI_ERR("Could not schedule new timer in pjsip endpoint");
+        JAMI_ERR("Unable to schedule new timer in pjsip endpoint");
 
         /* fallthrough */
     case PJ_EINVAL:
@@ -863,15 +800,14 @@ static void
 invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
 {
     if (inv == nullptr or ev == nullptr) {
-        throw VoipLinkException("unexpected null pointer");
+        throw VoipLinkException("Unexpected null pointer");
     }
 
     auto call = getCallFromInvite(inv);
     if (not call)
         return;
 
-    if (ev->type != PJSIP_EVENT_TSX_STATE and ev->type != PJSIP_EVENT_TX_MSG
-        and ev->type != PJSIP_EVENT_RX_MSG) {
+    if (ev->type != PJSIP_EVENT_TSX_STATE and ev->type != PJSIP_EVENT_TX_MSG and ev->type != PJSIP_EVENT_RX_MSG) {
         JAMI_WARN("[call:%s] INVITE@%p state changed to %d (%s): unexpected event type %d",
                   call->getCallId().c_str(),
                   inv,
@@ -888,23 +824,22 @@ invite_session_state_changed_cb(pjsip_inv_session* inv, pjsip_event* ev)
         status_code = tsx ? tsx->status_code : PJSIP_SC_NOT_FOUND;
         const pj_str_t* description = pjsip_get_status_text(status_code);
 
-        JAMI_DBG("[call:%s] INVITE@%p state changed to %d (%s): cause=%d, tsx@%p status %d (%.*s)",
-                 call->getCallId().c_str(),
-                 inv,
-                 inv->state,
+        JAMI_LOG("[call:{}] INVITE@{:p} state changed to {:d} ({}): cause={:d}, tsx@{:p} status {:d} ({:s})",
+                 call->getCallId(),
+                 fmt::ptr(inv),
+                 (int) inv->state,
                  pjsip_inv_state_name(inv->state),
-                 inv->cause,
-                 tsx,
+                 (int) inv->cause,
+                 fmt::ptr(tsx),
                  status_code,
-                 (int) description->slen,
-                 description->ptr);
+                 sip_utils::as_view(*description));
     } else if (ev->type == PJSIP_EVENT_TX_MSG) {
-        JAMI_DBG("[call:%s] INVITE@%p state changed to %d (%s): cause=%d (TX_MSG)",
-                 call->getCallId().c_str(),
-                 inv,
-                 inv->state,
+        JAMI_LOG("[call:{}] INVITE@{:p} state changed to {:d} ({:s}): cause={:d} (TX_MSG)",
+                 call->getCallId(),
+                 fmt::ptr(inv),
+                 (int) inv->state,
                  pjsip_inv_state_name(inv->state),
-                 inv->cause);
+                 (int) inv->cause);
     }
     pjsip_rx_data* rdata {nullptr};
     if (ev->type == PJSIP_EVENT_RX_MSG) {
@@ -1028,7 +963,7 @@ sdp_create_offer_cb(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer)
     }
 
     auto family = pj_AF_INET();
-    // FIXME : for now, use the same address family as the SIP transport
+    // FIXME: for now, use the same address family as the SIP transport
     if (auto dlg = inv->dlg) {
         if (dlg->tp_sel.type == PJSIP_TPSELECTOR_TRANSPORT) {
             if (auto tr = dlg->tp_sel.u.transport)
@@ -1042,9 +977,8 @@ sdp_create_offer_cb(pjsip_inv_session* inv, pjmedia_sdp_session** p_offer)
 
     dhtnet::IpAddr address;
     if (account->getUPnPActive()) {
-        /* use UPnP addr, or published addr if its set */
-        address = account->getPublishedSameasLocal() ? account->getUPnPIpAddress()
-                                                     : account->getPublishedIpAddress();
+        /* use UPnP addr, or published addr if it's set */
+        address = account->getPublishedSameasLocal() ? account->getUPnPIpAddress() : account->getPublishedIpAddress();
     } else {
         address = account->getPublishedSameasLocal() ? ifaceAddr : account->getPublishedIpAddress();
     }
@@ -1120,8 +1054,7 @@ sdp_media_update_cb(pjsip_inv_session* inv, pj_status_t status)
     JAMI_DBG("[call:%s] INVITE@%p media update: status %d", call->getCallId().c_str(), inv, status);
 
     if (status != PJ_SUCCESS) {
-        const int reason = inv->state != PJSIP_INV_STATE_NULL
-                                   and inv->state != PJSIP_INV_STATE_CONFIRMED
+        const int reason = inv->state != PJSIP_INV_STATE_NULL and inv->state != PJSIP_INV_STATE_CONFIRMED
                                ? PJSIP_SC_UNSUPPORTED_MEDIA_TYPE
                                : 0;
 
@@ -1177,8 +1110,8 @@ handleMediaControl(SIPCall& call, pjsip_msg_body* body)
 
         int streamIdx = -1;
         if (body_msg.find(STREAM_ID) != std::string_view::npos) {
-            // Note: here we use the index of the RTP stream, not it's label!
-            // Indeed, both side will have different labels as they have different call ids
+            // Note: here we use the index of the RTP stream, not its label!
+            // Indeed, both sides will have different labels as they have different call IDs
             static const std::regex STREAMID_REGEX("<stream_id>([0-9]+)</stream_id>");
             std::svmatch matched_pattern;
             std::regex_search(body_msg, matched_pattern, STREAMID_REGEX);
@@ -1271,12 +1204,11 @@ static bool
 transferCall(SIPCall& call, const std::string& refer_to)
 {
     const auto& callId = call.getCallId();
-    JAMI_WARN("[call:%s] Trying to transfer to %s", callId.c_str(), refer_to.c_str());
+    JAMI_WARN("[call:%s] Attempting to transfer to %s", callId.c_str(), refer_to.c_str());
     try {
         Manager::instance().newOutgoingCall(refer_to,
                                             call.getAccountId(),
-                                            MediaAttribute::mediaAttributesToMediaMaps(
-                                                call.getMediaAttributeList()));
+                                            MediaAttribute::mediaAttributesToMediaMaps(call.getMediaAttributeList()));
         Manager::instance().hangupCall(call.getAccountId(), callId);
     } catch (const std::exception& e) {
         JAMI_ERR("[call:%s] SIP transfer failed: %s", callId.c_str(), e.what());
@@ -1290,7 +1222,7 @@ replyToRequest(pjsip_inv_session* inv, pjsip_rx_data* rdata, int status_code)
 {
     const auto ret = pjsip_dlg_respond(inv->dlg, rdata, status_code, nullptr, nullptr, nullptr);
     if (ret != PJ_SUCCESS)
-        JAMI_WARN("SIP: failed to reply %d to request", status_code);
+        JAMI_WARN("SIP: Failed to reply %d to request", status_code);
 }
 
 static void
@@ -1360,29 +1292,26 @@ transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjs
 
     const auto rdata = event->body.tsx_state.src.rdata;
     if (!rdata) {
-        JAMI_ERR("[INVITE:%p] SIP RX request without rx data", inv);
+        JAMI_ERROR("[INVITE:{:p}] SIP RX request without rx data", fmt::ptr(inv));
         return;
     }
 
     const auto msg = rdata->msg_info.msg;
     if (msg->type != PJSIP_REQUEST_MSG) {
-        JAMI_ERR("[INVITE:%p] SIP RX request without msg", inv);
+        JAMI_ERROR("[INVITE:{:p}] SIP RX request without msg", fmt::ptr(inv));
         return;
     }
 
     // Using method name to dispatch
     auto methodName = sip_utils::as_view(msg->line.req.method.name);
-    JAMI_DBG("[INVITE:%p] RX SIP method %d (%.*s)",
-             inv,
-             msg->line.req.method.id,
-             (int) methodName.size(),
-             methodName.data());
+    JAMI_LOG("[INVITE:{:p}] RX SIP method {:d} ({:s})", fmt::ptr(inv), (int) msg->line.req.method.id, methodName);
 
 #ifdef DEBUG_SIP_REQUEST_MSG
     char msgbuf[1000];
-    pjsip_msg_print(msg, msgbuf, sizeof msgbuf);
-    JAMI_DBG("%s", msgbuf);
-#endif // DEBUG_SIP_MESSAGE
+    auto msgsize = pjsip_msg_print(msg, msgbuf, sizeof msgbuf);
+    if (msgsize > 0)
+        JAMI_LOG("{:s}", std::string_view(msgbuf, msgsize));
+#endif // DEBUG_SIP_REQUEST_MSG
 
     if (methodName == sip_utils::SIP_METHODS::REFER)
         onRequestRefer(inv, rdata, msg, *call);
@@ -1394,9 +1323,7 @@ transaction_state_changed_cb(pjsip_inv_session* inv, pjsip_transaction* tsx, pjs
         handleIncomingOptions(rdata);
     else if (methodName == sip_utils::SIP_METHODS::MESSAGE) {
         if (msg->body)
-            runOnMainThread([call, m = im::parseSipMessage(msg)]() mutable {
-                call->onTextMessage(std::move(m));
-            });
+            runOnMainThread([call, m = im::parseSipMessage(msg)]() mutable { call->onTextMessage(std::move(m)); });
     }
 }
 
@@ -1425,11 +1352,11 @@ processInviteResponseHelper(pjsip_inv_session* inv, pjsip_event* event)
         return;
     }
 
-    JAMI_INFO("[INVITE:%p] SIP RX response: reason %.*s, status code %i",
-              inv,
-              (int) msg->line.status.reason.slen,
-              msg->line.status.reason.ptr,
-              msg->line.status.code);
+    JAMI_LOG("[INVITE:{:p}] SIP RX response: reason {:s}, status code {:d} {:s}",
+             fmt::ptr(inv),
+             sip_utils::as_view(msg->line.status.reason),
+             msg->line.status.code,
+             sip_utils::as_view(*pjsip_get_status_text(msg->line.status.code)));
 
     sip_utils::logMessageHeaders(&msg->hdr);
 }
@@ -1445,7 +1372,7 @@ void
 SIPVoIPLink::createSDPOffer(pjsip_inv_session* inv)
 {
     if (inv == nullptr) {
-        throw VoipLinkException("Invite session can not be null");
+        throw VoipLinkException("Invite session is unable to be null");
     }
     sdp_create_offer_cb(inv, nullptr);
 }
@@ -1491,9 +1418,7 @@ resolver_callback(pj_status_t status, void* token, const struct pjsip_server_add
 }
 
 void
-SIPVoIPLink::resolveSrvName(const std::string& name,
-                            pjsip_transport_type_e type,
-                            SrvResolveCallback&& cb)
+SIPVoIPLink::resolveSrvName(const std::string& name, pjsip_transport_type_e type, SrvResolveCallback&& cb)
 {
     // PJSIP limits hostname to be longer than PJ_MAX_HOSTNAME.
     // But, resolver prefix the given name by a string like "_sip._udp."
@@ -1518,7 +1443,7 @@ SIPVoIPLink::resolveSrvName(const std::string& name,
         port = 0;
         name_size = name.size();
     }
-    JAMI_DBG("try to resolve '%s' (port: %u)", name.c_str(), port);
+    JAMI_DBG("Attempt to resolve '%s' (port: %u)", name.c_str(), port);
 
     pjsip_host_info host_info {
         /*.flag = */ 0,
@@ -1527,11 +1452,11 @@ SIPVoIPLink::resolveSrvName(const std::string& name,
     };
 
     const auto token = std::hash<std::string>()(name + std::to_string(type));
-    getResolveCallbackMap().registerCallback(
-        token, [=, cb = std::move(cb)](pj_status_t s, const pjsip_server_addresses* r) {
+    getResolveCallbackMap()
+        .registerCallback(token, [=, cb = std::move(cb)](pj_status_t s, const pjsip_server_addresses* r) {
             try {
                 if (s != PJ_SUCCESS || !r) {
-                    JAMI_WARN("Can't resolve \"%s\" using pjsip_endpt_resolve, trying getaddrinfo.",
+                    JAMI_WARN("Unable to resolve \"%s\" using pjsip_endpt_resolve, attempting getaddrinfo.",
                               name.c_str());
                     dht::ThreadPool::io().run([=, cb = std::move(cb)]() {
                         auto ips = dhtnet::ip_utils::getAddrList(name.c_str());
@@ -1572,17 +1497,14 @@ SIPVoIPLink::findLocalAddressFromTransport(pjsip_transport* transport,
                                            std::string& addr,
                                            pj_uint16_t& port) const
 {
-    // Initialize the sip port with the default SIP port
+    // Initialize the SIP port with the default SIP port
     port = pjsip_transport_get_default_port_for_type(transportType);
 
-    // Initialize the sip address with the hostname
+    // Initialize the SIP address with the hostname
     addr = sip_utils::as_view(*pj_gethostname());
 
     // Update address and port with active transport
-    RETURN_IF_NULL(transport,
-                   "Transport is NULL in findLocalAddress, using local address %s :%d",
-                   addr.c_str(),
-                   port);
+    RETURN_IF_NULL(transport, "Transport is NULL in findLocalAddress, using local address %s :%d", addr.c_str(), port);
 
     // get the transport manager associated with the SIP enpoint
     auto tpmgr = pjsip_endpt_get_tpmgr(endpt_);
@@ -1594,12 +1516,9 @@ SIPVoIPLink::findLocalAddressFromTransport(pjsip_transport* transport,
     const pj_str_t pjstring(CONST_PJ_STR(host));
 
     auto tp_sel = getTransportSelector(transport);
-    pjsip_tpmgr_fla2_param param
-        = {transportType, &tp_sel, pjstring, PJ_FALSE, {nullptr, 0}, 0, nullptr};
+    pjsip_tpmgr_fla2_param param = {transportType, &tp_sel, pjstring, PJ_FALSE, {nullptr, 0}, 0, nullptr};
     if (pjsip_tpmgr_find_local_addr2(tpmgr, pool_.get(), &param) != PJ_SUCCESS) {
-        JAMI_WARN("Could not retrieve local address and port from transport, using %s :%d",
-                  addr.c_str(),
-                  port);
+        JAMI_WARN("Unable to retrieve local address and port from transport, using %s :%d", addr.c_str(), port);
         return;
     }
 
@@ -1611,11 +1530,8 @@ SIPVoIPLink::findLocalAddressFromTransport(pjsip_transport* transport,
 }
 
 bool
-SIPVoIPLink::findLocalAddressFromSTUN(pjsip_transport* transport,
-                                      pj_str_t* stunServerName,
-                                      int stunPort,
-                                      std::string& addr,
-                                      pj_uint16_t& port) const
+SIPVoIPLink::findLocalAddressFromSTUN(
+    pjsip_transport* transport, pj_str_t* stunServerName, int stunPort, std::string& addr, pj_uint16_t& port) const
 {
     // WARN: this code use pjstun_get_mapped_addr2 that works
     // in IPv4 only.
@@ -1643,18 +1559,12 @@ SIPVoIPLink::findLocalAddressFromSTUN(pjsip_transport* transport,
 
     pj_sockaddr_in mapped_addr;
     pj_sock_t sipSocket = pjsip_udp_transport_get_socket(transport);
-    const pjstun_setting stunOpt
-        = {PJ_TRUE, localIp.getFamily(), *stunServerName, stunPort, *stunServerName, stunPort};
-    pj_status_t stunStatus = pjstun_get_mapped_addr2(&cp_.factory,
-                                                           &stunOpt,
-                                                           1,
-                                                           &sipSocket,
-                                                           &mapped_addr);
+    const pjstun_setting stunOpt = {PJ_TRUE, localIp.getFamily(), *stunServerName, stunPort, *stunServerName, stunPort};
+    pj_status_t stunStatus = pjstun_get_mapped_addr2(&cp_.factory, &stunOpt, 1, &sipSocket, &mapped_addr);
 
     switch (stunStatus) {
     case PJLIB_UTIL_ESTUNNOTRESPOND:
-        JAMI_ERROR("No response from STUN server {:s}",
-                 sip_utils::as_view(*stunServerName));
+        JAMI_ERROR("No response from STUN server {:s}", sip_utils::as_view(*stunServerName));
         return false;
 
     case PJLIB_UTIL_ESTUNSYMMETRIC:
@@ -1668,8 +1578,7 @@ SIPVoIPLink::findLocalAddressFromSTUN(pjsip_transport* transport,
         return true;
 
     default: // use given address, silent any not handled error
-        JAMI_WARNING("Error from STUN server {:s}, using source address",
-                  sip_utils::as_view(*stunServerName));
+        JAMI_WARNING("Error from STUN server {:s}, using source address", sip_utils::as_view(*stunServerName));
         return false;
     }
 }
