@@ -54,8 +54,7 @@ public:
     AccountArchiveTest()
     {
         // Init daemon
-        libjami::init(
-            libjami::InitFlag(libjami::LIBJAMI_FLAG_DEBUG | libjami::LIBJAMI_FLAG_CONSOLE_LOG));
+        libjami::init(libjami::InitFlag(libjami::LIBJAMI_FLAG_DEBUG | libjami::LIBJAMI_FLAG_CONSOLE_LOG));
         if (not Manager::instance().initialized)
             CPPUNIT_ASSERT(libjami::start("dring-sample.yml"));
     }
@@ -105,23 +104,19 @@ AccountArchiveTest::setUp()
     aliceId = actors["alice"];
     bobId = actors["bob"];
 
-    confHandlers.insert(
-        libjami::exportable_callback<libjami::ConfigurationSignal::VolatileDetailsChanged>(
-            [&](const std::string& accountId, const std::map<std::string, std::string>& details) {
-                if (accountId != aliceId) {
-                    return;
-                }
-                try {
-                    aliceReady |= accountId == aliceId
-                                  && details.at(jami::Conf::CONFIG_ACCOUNT_REGISTRATION_STATUS)
-                                         == "REGISTERED"
-                                  && details.at(
-                                         libjami::Account::VolatileProperties::DEVICE_ANNOUNCED)
-                                         == "true";
-                } catch (const std::out_of_range&) {
-                }
-                cv.notify_one();
-            }));
+    confHandlers.insert(libjami::exportable_callback<libjami::ConfigurationSignal::VolatileDetailsChanged>(
+        [&](const std::string& accountId, const std::map<std::string, std::string>& details) {
+            if (accountId != aliceId) {
+                return;
+            }
+            try {
+                aliceReady |= accountId == aliceId
+                              && details.at(jami::Conf::CONFIG_ACCOUNT_REGISTRATION_STATUS) == "REGISTERED"
+                              && details.at(libjami::Account::VolatileProperties::DEVICE_ANNOUNCED) == "true";
+            } catch (const std::out_of_range&) {
+            }
+            cv.notify_one();
+        }));
     libjami::registerSignalHandlers(confHandlers);
 }
 
