@@ -114,10 +114,10 @@ private:
                                   const std::string& callId,
                                   const std::string& state,
                                   CallData& callData);
-    static void onIncomingCallWithMedia(const std::string& accountId,
-                                        const std::string& callId,
-                                        const std::vector<libjami::MediaMap> mediaList,
-                                        CallData& callData);
+    static void onIncomingCall(const std::string& accountId,
+                               const std::string& callId,
+                               const std::vector<libjami::MediaMap> mediaList,
+                               CallData& callData);
     static void onMediaNegotiationStatus(const std::string& callId, const std::string& event, CallData& callData);
 
     // Helpers
@@ -250,15 +250,15 @@ SipBasicCallTest::getUserAlias(const std::string& accountId)
 }
 
 void
-SipBasicCallTest::onIncomingCallWithMedia(const std::string& accountId,
-                                          const std::string& callId,
-                                          const std::vector<libjami::MediaMap> mediaList,
-                                          CallData& callData)
+SipBasicCallTest::onIncomingCall(const std::string& accountId,
+                                 const std::string& callId,
+                                 const std::vector<libjami::MediaMap> mediaList,
+                                 CallData& callData)
 {
     CPPUNIT_ASSERT_EQUAL(callData.accountId_, accountId);
 
     JAMI_INFO("Signal [%s] - user [%s] - call [%s] - media count [%lu]",
-              libjami::CallSignal::IncomingCallWithMedia::name,
+              libjami::CallSignal::IncomingCall::name,
               callData.alias_.c_str(),
               callId.c_str(),
               mediaList.size());
@@ -271,7 +271,7 @@ SipBasicCallTest::onIncomingCallWithMedia(const std::string& accountId,
 
     std::unique_lock lock {callData.mtx_};
     callData.callId_ = callId;
-    callData.signals_.emplace_back(CallData::Signal(libjami::CallSignal::IncomingCallWithMedia::name));
+    callData.signals_.emplace_back(CallData::Signal(libjami::CallSignal::IncomingCall::name));
 
     callData.cv_.notify_one();
 }
@@ -400,14 +400,14 @@ SipBasicCallTest::configureTest()
     std::map<std::string, std::shared_ptr<libjami::CallbackWrapperBase>> signalHandlers;
 
     // Insert needed signal handlers.
-    signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::IncomingCallWithMedia>(
+    signalHandlers.insert(libjami::exportable_callback<libjami::CallSignal::IncomingCall>(
         [&](const std::string& accountId,
             const std::string& callId,
             const std::string&,
             const std::vector<libjami::MediaMap> mediaList) {
             auto alias = getUserAlias(accountId);
             if (not alias.empty()) {
-                onIncomingCallWithMedia(accountId, callId, mediaList, callDataMap_[alias]);
+                onIncomingCall(accountId, callId, mediaList, callDataMap_[alias]);
             }
         }));
 
@@ -460,7 +460,7 @@ SipBasicCallTest::audio_video_call(std::vector<MediaAttribute> offer,
     CPPUNIT_ASSERT(waitForSignal(callDataMap_["ALICE"], libjami::CallSignal::StateChange::name, StateEvent::RINGING));
 
     // Wait for incoming call signal.
-    CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::IncomingCallWithMedia::name));
+    CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::IncomingCall::name));
 
     // Answer the call.
     libjami::acceptWithMedia(callDataMap_["BOB"].accountId_,
@@ -695,7 +695,7 @@ SipBasicCallTest::hold_resume_test()
             waitForSignal(callDataMap_["ALICE"], libjami::CallSignal::StateChange::name, StateEvent::RINGING));
 
         // Wait for incoming call signal.
-        CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::IncomingCallWithMedia::name));
+        CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::IncomingCall::name));
 
         // Answer the call.
         libjami::acceptWithMedia(callDataMap_["BOB"].accountId_,
@@ -918,7 +918,7 @@ SipBasicCallTest::blind_transfer_test()
     CPPUNIT_ASSERT(waitForSignal(callDataMap_["ALICE"], libjami::CallSignal::StateChange::name, StateEvent::RINGING));
 
     // Wait for incoming call signal.
-    CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::IncomingCallWithMedia::name));
+    CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::IncomingCall::name));
 
     // Answer the call.
     libjami::acceptWithMedia(callDataMap_["BOB"].accountId_,
@@ -957,7 +957,7 @@ SipBasicCallTest::blind_transfer_test()
     CPPUNIT_ASSERT(waitForSignal(callDataMap_["BOB"], libjami::CallSignal::StateChange::name, StateEvent::RINGING));
 
     // Wait for incoming call signal.
-    CPPUNIT_ASSERT(waitForSignal(callDataMap_["CARLA"], libjami::CallSignal::IncomingCallWithMedia::name));
+    CPPUNIT_ASSERT(waitForSignal(callDataMap_["CARLA"], libjami::CallSignal::IncomingCall::name));
 
     // Let it ring
     std::this_thread::sleep_for(std::chrono::seconds(2));
