@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #include "appversionmanager.h"
 
 #include "lrcinstance.h"
-#include "version.h"
+#include "version_info.h"
 
 #include <QProcess>
 #include <QTimer>
@@ -58,10 +58,7 @@ struct AppVersionManager::Impl : public QObject
         parent_.disconnect();
         // Fail without UI if this is a programmatic check.
         if (!quiet)
-            connect(&parent_,
-                    &NetworkManager::errorOccurred,
-                    &parent_,
-                    &AppVersionManager::networkErrorOccurred);
+            connect(&parent_, &NetworkManager::errorOccurred, &parent_, &AppVersionManager::networkErrorOccurred);
 
         cleanUpdateFiles();
         const QUrl versionUrl {isBeta ? QUrl::fromUserInput(baseUrlString_ + betaVersionSubUrl)
@@ -73,14 +70,14 @@ struct AppVersionManager::Impl : public QObject
                     Q_EMIT parent_.updateCheckReplyReceived(false);
                 return;
             }
-            auto currentVersion = QString(VERSION_STRING).toULongLong();
+            auto currentVersion = BUILD_VERSION_STRING.toULongLong();
             auto latestVersion = latestVersionString.toULongLong();
             const QString channelStr = isBeta ? "beta" : "stable";
             const auto newVersionFound = latestVersion > currentVersion;
-            qInfo().noquote() << "--------- Version info ------------"
-                              << QString("\n - Current: %1 (%2)").arg(currentVersion).arg(channelStr);
+            qInfo().noquote() << "--------- Version info ------------";
+            qInfo().noquote() << QString("\tCurrent: \t%1 (%2)").arg(currentVersion).arg(channelStr);
             if (newVersionFound) {
-                qDebug() << " - Latest: " << latestVersion;
+                qInfo().noquote() << QString("\tLatest: \t%1").arg(latestVersion);
                 Q_EMIT parent_.updateCheckReplyReceived(true, true);
             } else if (!quiet) {
                 Q_EMIT parent_.updateCheckReplyReceived(true, false);
@@ -91,14 +88,10 @@ struct AppVersionManager::Impl : public QObject
     void applyUpdates(bool beta = false)
     {
         parent_.disconnect();
-        connect(&parent_,
-                &NetworkManager::errorOccurred,
-                &parent_,
-                &AppVersionManager::networkErrorOccurred);
+        connect(&parent_, &NetworkManager::errorOccurred, &parent_, &AppVersionManager::networkErrorOccurred);
 
-        const QUrl downloadUrl {(beta || isBeta)
-                                    ? QUrl::fromUserInput(baseUrlString_ + betaMsiSubUrl)
-                                    : QUrl::fromUserInput(baseUrlString_ + msiSubUrl)};
+        const QUrl downloadUrl {(beta || isBeta) ? QUrl::fromUserInput(baseUrlString_ + betaMsiSubUrl)
+                                                 : QUrl::fromUserInput(baseUrlString_ + msiSubUrl)};
 
         const auto lastDownloadReplyId = parent_.replyId_;
         parent_.replyId_ = parent_.downloadFile(
@@ -112,10 +105,8 @@ struct AppVersionManager::Impl : public QObject
                 auto msiPath = QDir::toNativeSeparators(basePath + downloadUrl.fileName());
                 auto logPath = QDir::toNativeSeparators(basePath + "jami_x64_install.log");
                 process.startDetached("msiexec",
-                                      QStringList() << "/i" << msiPath << "/passive"
-                                                    << "/norestart"
-                                                    << "WIXNONUILAUNCH=1"
-                                                    << "/L*V" << logPath);
+                                      QStringList() << "/i" << msiPath << "/passive" << "/norestart"
+                                                    << "WIXNONUILAUNCH=1" << "/L*V" << logPath);
             },
             QDir::tempPath());
     };
@@ -160,10 +151,7 @@ struct AppVersionManager::Impl : public QObject
     QTimer* updateTimer_;
 };
 
-AppVersionManager::AppVersionManager(const QString& url,
-                                     ConnectivityMonitor* cm,
-                                     LRCInstance* instance,
-                                     QObject* parent)
+AppVersionManager::AppVersionManager(const QString& url, ConnectivityMonitor* cm, LRCInstance* instance, QObject* parent)
     : NetworkManager(cm, parent)
     , replyId_(0)
     , pimpl_(std::make_unique<Impl>(url, instance, *this))
