@@ -64,7 +64,7 @@ CallAdapter::CallAdapter(AppSettingsManager* settingsManager,
             &SystemTray::acceptCallActivated,
             this,
             [this](const QString& accountId, const QString& convUid) {
-                acceptACall(accountId, convUid);
+                acceptCall(accountId, convUid);
                 Q_EMIT lrcInstance_->notificationClicked();
                 lrcInstance_->selectConversation(convUid, accountId);
                 updateCall(convUid, accountId);
@@ -73,7 +73,7 @@ CallAdapter::CallAdapter(AppSettingsManager* settingsManager,
     connect(systemTray_,
             &SystemTray::declineCallActivated,
             this,
-            [this](const QString& accountId, const QString& convUid) { hangUpACall(accountId, convUid); });
+            [this](const QString& accountId, const QString& convUid) { endCall(accountId, convUid); });
 #endif
 
     connect(&lrcInstance_->behaviorController(),
@@ -338,29 +338,29 @@ CallAdapter::onCallAddedToConference(const QString& callId, const QString& conve
 }
 
 void
-CallAdapter::placeAudioOnlyCall()
+CallAdapter::startAudioOnlyCall()
 {
     const auto convUid = lrcInstance_->get_selectedConvUid();
     if (!convUid.isEmpty()) {
-        lrcInstance_->getCurrentConversationModel()->placeAudioOnlyCall(convUid);
+        lrcInstance_->getCurrentConversationModel()->startAudioOnlyCall(convUid);
     }
 }
 
 void
-CallAdapter::placeCall()
+CallAdapter::startCall()
 {
     const auto convUid = lrcInstance_->get_selectedConvUid();
     if (!convUid.isEmpty()) {
-        lrcInstance_->getCurrentConversationModel()->placeCall(convUid);
+        lrcInstance_->getCurrentConversationModel()->startCall(convUid);
     }
 }
 
 void
-CallAdapter::hangUpACall(const QString& accountId, const QString& convUid)
+CallAdapter::endCall(const QString& accountId, const QString& convUid)
 {
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(convUid, accountId);
     if (!convInfo.uid.isEmpty()) {
-        lrcInstance_->getAccountInfo(accountId).callModel->hangUp(convInfo.callId);
+        lrcInstance_->getAccountInfo(accountId).callModel->end(convInfo.callId);
     }
 }
 
@@ -375,7 +375,7 @@ CallAdapter::setCallMedia(const QString& accountId, const QString& convUid, bool
 }
 
 void
-CallAdapter::acceptACall(const QString& accountId, const QString& convUid)
+CallAdapter::acceptCall(const QString& accountId, const QString& convUid)
 {
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(convUid, accountId);
     if (convInfo.uid.isEmpty())
@@ -463,7 +463,23 @@ CallAdapter::onShowIncomingCallView(const QString& accountId, const QString& con
 void
 CallAdapter::onShowCallView(const QString& accountId, const QString& convUid)
 {
-    Q_EMIT lrcInstance_->conversationUpdated(convUid, accountId); // This will show the call
+    if (accountId.isEmpty() || convUid.isEmpty()) {
+        qWarning() << "Invalid parameters: (" << accountId << "," << convUid << ")";
+        return;
+    }
+
+    // check if we're already on the correct conversation
+    // selectConversation will emit conversationUpdated if already selected
+    bool alreadySelected = (lrcInstance_->get_selectedConvUid() == convUid
+                            && lrcInstance_->get_currentAccountId() == accountId);
+
+    lrcInstance_->selectConversation(convUid, accountId);
+
+    // if it wasn't selected, selectConversation changed the selection but didn't emit conversationUpdated
+    // we emit it here to make sure the UI reacts to the "Show Call" request specifically
+    if (!alreadySelected) {
+        Q_EMIT lrcInstance_->conversationUpdated(convUid, accountId);
+    }
 }
 
 void
@@ -578,9 +594,9 @@ CallAdapter::saveConferenceSubcalls()
 }
 
 void
-CallAdapter::hangUpCall(const QString& callId)
+CallAdapter::endCall(const QString& callId)
 {
-    lrcInstance_->getCurrentCallModel()->hangUp(callId);
+    lrcInstance_->getCurrentCallModel()->end(callId);
 }
 
 void
@@ -670,15 +686,15 @@ CallAdapter::showGridConferenceLayout()
 }
 
 void
-CallAdapter::hangUpThisCall()
+CallAdapter::endCall()
 {
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid(), accountId_);
     if (!convInfo.uid.isEmpty()) {
         auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
         if (!convInfo.confId.isEmpty() && callModel->hasCall(convInfo.confId)) {
-            callModel->hangUp(convInfo.confId);
+            callModel->end(convInfo.confId);
         } else if (callModel->hasCall(convInfo.callId)) {
-            callModel->hangUp(convInfo.callId);
+            callModel->end(convInfo.callId);
         }
     }
 }
@@ -825,7 +841,7 @@ CallAdapter::getMuteState(const QString& uri) const
 }
 
 void
-CallAdapter::hangupParticipant(const QString& uri, const QString& deviceId)
+CallAdapter::disconnectParticipant(const QString& uri, const QString& deviceId)
 {
     auto* callModel = lrcInstance_->getAccountInfo(accountId_).callModel.get();
     const auto& convInfo = lrcInstance_->getConversationFromConvUid(lrcInstance_->get_selectedConvUid());
@@ -835,7 +851,7 @@ CallAdapter::hangupParticipant(const QString& uri, const QString& deviceId)
         confId = convInfo.callId;
     try {
         const auto call = callModel->getCall(confId);
-        callModel->hangupParticipant(confId, uri, deviceId);
+        callModel->disconnectParticipant(confId, uri, deviceId);
     } catch (...) {
     }
 }
