@@ -1,7 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,9 +17,12 @@
 
 #include "calloverlaymodel.h"
 
+#include "global.h"
+
 #include <QEvent>
 #include <QMouseEvent>
 #include <QQuickWindow>
+#include <QKeyEvent>
 
 IndexRangeFilterProxyModel::IndexRangeFilterProxyModel(QAbstractListModel* parent)
     : QSortFilterProxyModel(parent)
@@ -55,9 +56,7 @@ PendingConferenceesListModel::PendingConferenceesListModel(LRCInstance* instance
     , lrcInstance_(instance)
 {
     connectSignals();
-    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, [this]() {
-        connectSignals();
-    });
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, [this]() { connectSignals(); });
 }
 
 int
@@ -74,10 +73,10 @@ PendingConferenceesListModel::data(const QModelIndex& index, int role) const
     using namespace PendingConferences;
 
     // WARNING: not swarm ready
+    lrc::api::call::Status callStatus;
     QString pendingConferenceeCallId;
     QString pendingConferenceeContactUri;
     ContactModel* contactModel {nullptr};
-    lrc::api::call::Status callStatus;
     try {
         auto callModel = lrcInstance_->getCurrentCallModel();
         auto currentPendingConferenceeInfo = callModel->getPendingConferencees().at(index.row());
@@ -134,19 +133,15 @@ PendingConferenceesListModel::connectSignals()
     callsStatusChanged_ = connect(currentCallModel,
                                   &CallModel::callStatusChanged,
                                   this,
-                                  [this](const QString&, int) {
-                                      Q_EMIT dataChanged(index(0, 0),
-                                                         index(rowCount() - 1),
-                                                         {Role::CallStatus});
+                                  [this](const QString&, const QString&, int) {
+                                      Q_EMIT dataChanged(index(0, 0), index(rowCount() - 1), {Role::CallStatus});
                                   });
 
     beginInsertPendingConferencesRows_ = connect(
         currentCallModel,
         &CallModel::beginInsertPendingConferenceesRows,
         this,
-        [this](int position, int rows) {
-            beginInsertRows(QModelIndex(), position, position + (rows - 1));
-        },
+        [this](int position, int rows) { beginInsertRows(QModelIndex(), position, position + (rows - 1)); },
         Qt::DirectConnection);
 
     endInsertPendingConferencesRows_ = connect(
@@ -160,9 +155,7 @@ PendingConferenceesListModel::connectSignals()
         currentCallModel,
         &CallModel::beginRemovePendingConferenceesRows,
         this,
-        [this](int position, int rows) {
-            beginRemoveRows(QModelIndex(), position, position + (rows - 1));
-        },
+        [this](int position, int rows) { beginRemoveRows(QModelIndex(), position, position + (rows - 1)); },
         Qt::DirectConnection);
 
     endRemovePendingConferencesRows_ = connect(
@@ -223,9 +216,7 @@ void
 CallControlListModel::setUrgentCount(QVariant item, int count)
 {
     const auto* obj = item.value<QObject*>();
-    auto it = std::find_if(data_.cbegin(), data_.cend(), [obj](const auto& item) {
-        return item.itemAction == obj;
-    });
+    auto it = std::find_if(data_.cbegin(), data_.cend(), [obj](const auto& item) { return item.itemAction == obj; });
     if (it != data_.cend()) {
         auto row = std::distance(data_.cbegin(), it);
         if (row >= rowCount())
@@ -240,9 +231,7 @@ void
 CallControlListModel::setEnabled(QObject* obj, bool enabled)
 {
     beginResetModel();
-    auto it = std::find_if(data_.cbegin(), data_.cend(), [obj](const auto& item) {
-        return item.itemAction == obj;
-    });
+    auto it = std::find_if(data_.cbegin(), data_.cend(), [obj](const auto& item) { return item.itemAction == obj; });
     if (it != data_.cend()) {
         auto row = std::distance(data_.cbegin(), it);
         if (row >= rowCount())
@@ -268,7 +257,7 @@ CallControlListModel::clearData()
     data_.clear();
 }
 
-CallOverlayModel::CallOverlayModel(LRCInstance* instance, QObject* parent)
+CallOverlayModel::CallOverlayModel(LRCInstance* instance, PTTListener* listener, QObject* parent)
     : QObject(parent)
     , lrcInstance_(instance)
     , primaryModel_(new CallControlListModel(this))
@@ -278,11 +267,12 @@ CallOverlayModel::CallOverlayModel(LRCInstance* instance, QObject* parent)
     , overflowHiddenModel_(new IndexRangeFilterProxyModel(secondaryModel_))
     , pendingConferenceesModel_(new PendingConferenceesListModel(instance, this))
 {
-    connect(this,
-            &CallOverlayModel::overflowIndexChanged,
-            this,
-            &CallOverlayModel::setControlRanges);
+    connect(this, &CallOverlayModel::overflowIndexChanged, this, &CallOverlayModel::setControlRanges);
     overflowVisibleModel_->setFilterRole(CallControl::Role::UrgentCount);
+
+#ifndef HAVE_GLOBAL_PTT
+    listener_ = listener;
+#endif
 }
 
 void
@@ -355,23 +345,33 @@ CallOverlayModel::clearControls()
 }
 
 void
-CallOverlayModel::registerFilter(QQuickWindow* object, QQuickItem* item)
+CallOverlayModel::setEventFilterActive(QObject* object, QQuickItem* item, bool isActive)
 {
-    if (!object || !item || watchedItems_.contains(item))
+    QQuickWindow* window = qobject_cast<QQuickWindow*>(object);
+    if (!window || !item) {
+        C_WARN << "Attempting to" << (isActive ? "register" : "unregister") << "an invalid object or item" << window
+               << item;
         return;
-    watchedItems_.push_back(item);
-    if (watchedItems_.size() == 1)
-        object->installEventFilter(this);
-}
-
-void
-CallOverlayModel::unregisterFilter(QQuickWindow* object, QQuickItem* item)
-{
-    if (!object || !item || !watchedItems_.contains(item))
-        return;
-    watchedItems_.removeOne(item);
-    if (watchedItems_.size() == 0)
-        object->removeEventFilter(this);
+    }
+    if (isActive) {
+        if (watchedItems_.contains(item)) {
+            C_DBG << "Item already registered" << item;
+        } else {
+            watchedItems_.push_back(item);
+            if (watchedItems_.size() == 1) {
+                window->installEventFilter(this);
+            }
+        }
+    } else {
+        if (!watchedItems_.contains(item)) {
+            C_DBG << "Item not registered" << item;
+        } else {
+            watchedItems_.removeOne(item);
+            if (watchedItems_.size() == 0) {
+                window->removeEventFilter(this);
+            }
+        }
+    }
 }
 
 bool
@@ -386,6 +386,29 @@ CallOverlayModel::eventFilter(QObject* object, QEvent* event)
             }
         }
     }
+    // Tab or BackTab key events should trigger a signal that we can use to
+    // prevent the overlay from fading and to allow the user to navigate
+    // through the controls.
+    if (event->type() == QEvent::KeyPress && (static_cast<QKeyEvent*>(event)->key() == Qt::Key_Tab)
+        || (static_cast<QKeyEvent*>(event)->key() == Qt::Key_Backtab)) {
+        Q_EMIT focusKeyPressed();
+        // Don't absorb the event so that the focus can be changed
+        // to the next or previous control.
+        return false;
+    }
+#ifndef HAVE_GLOBAL_PTT
+    else if (event->type() == QEvent::KeyPress && listener_->getPttState()) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+        if (keyEvent->key() == listener_->getCurrentKey() && !keyEvent->isAutoRepeat()) {
+            Q_EMIT pttKeyPressed();
+        }
+    } else if (event->type() == QEvent::KeyRelease && listener_->getPttState()) {
+        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(event);
+        if (keyEvent->key() == listener_->getCurrentKey() && !keyEvent->isAutoRepeat()) {
+            Q_EMIT pttKeyReleased();
+        }
+    }
+#endif
     return QObject::eventFilter(object, event);
 }
 
