@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2022-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,27 +17,34 @@
 
 #include "currentcall.h"
 
+#include "callparticipantsmodel.h"
+#include "global.h"
+
 #include <api/callparticipantsmodel.h>
+#include <api/devicemodel.h>
 
 CurrentCall::CurrentCall(LRCInstance* lrcInstance, QObject* parent)
     : QObject(parent)
     , lrcInstance_(lrcInstance)
 {
-    connect(lrcInstance_,
-            &LRCInstance::currentAccountIdChanged,
-            this,
-            &CurrentCall::onCurrentAccountIdChanged);
+    participantsModel_ = qApp->property("CallParticipantsModel").value<CallParticipantsModel*>();
 
-    connect(lrcInstance_,
-            &LRCInstance::selectedConvUidChanged,
-            this,
-            &CurrentCall::onCurrentConvIdChanged);
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, &CurrentCall::onCurrentAccountIdChanged);
+
+    connect(lrcInstance_, &LRCInstance::selectedConvUidChanged, this, &CurrentCall::onCurrentConvIdChanged);
 
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::showIncomingCallView,
             this,
             &CurrentCall::onShowIncomingCallView);
 
+    try {
+        auto& accInfo = lrcInstance_->getCurrentAccountInfo();
+        set_isSIP(accInfo.profileInfo.type == profile::Type::SIP);
+    } catch (const std::exception& e) {
+        qWarning() << "Can't update current call type" << e.what();
+    }
+
     connectModel();
 }
 
@@ -65,14 +72,23 @@ CurrentCall::updateId(QString callId)
         // Only setCurrentCall if call is actually answered
         try {
             auto callInfo = accInfo.callModel->getCall(callId);
-            if (callInfo.status == call::Status::IN_PROGRESS
-                || callInfo.status == call::Status::PAUSED)
+            if (callInfo.status == call::Status::IN_PROGRESS || callInfo.status == call::Status::PAUSED)
                 accInfo.callModel->setCurrentCall(callId);
         } catch (...) {
         }
     }
     // Set the current id_ if there is a call.
-    set_id((accInfo.callModel->hasCall(callId) ? callId : QString()));
+    auto hasCall = accInfo.callModel->hasCall(callId);
+    set_id((hasCall ? callId : QString()));
+
+    if (hasCall) {
+        try {
+            auto callInfo = accInfo.callModel->getCall(callId);
+            participantsModel_->setParticipants(id_, getConferencesInfos());
+            participantsModel_->setConferenceLayout(static_cast<int>(callInfo.layout), id_);
+        } catch (...) {
+        }
+    }
 }
 
 void
@@ -105,6 +121,88 @@ CurrentCall::updateParticipants()
     set_isConference(uris.size());
 }
 
+void
+CurrentCall::onParticipantAdded(const QString& callId, int index)
+{
+    if (callId != id_)
+        return;
+    auto infos = getConferencesInfos();
+    if (index < infos.size())
+        participantsModel_->addParticipant(index, infos[index]);
+}
+
+void
+CurrentCall::onParticipantRemoved(const QString& callId, int index)
+{
+    if (callId != id_)
+        return;
+    participantsModel_->removeParticipant(index);
+}
+
+void
+CurrentCall::onParticipantUpdated(const QString& callId, int index)
+{
+    if (callId != id_)
+        return;
+    auto infos = getConferencesInfos();
+    if (index < infos.size())
+        participantsModel_->updateParticipant(index, infos[index]);
+}
+
+void
+CurrentCall::fillParticipantData(QJsonObject& participant) const
+{
+    // TODO: getCurrentDeviceId should be part of CurrentAccount, and Current<thing>
+    //       should be read accessible through LRCInstance ??
+    auto getCurrentDeviceId = [](const account::Info& accInfo) -> QString {
+        const auto& deviceList = accInfo.deviceModel->getAllDevices();
+        auto devIt = std::find_if(std::cbegin(deviceList), std::cend(deviceList), [](const Device& dev) {
+            return dev.isCurrent;
+        });
+        return devIt != deviceList.cend() ? devIt->id : QString();
+    };
+
+    auto& accInfo = lrcInstance_->getCurrentAccountInfo();
+    using namespace lrc::api::ParticipantsInfosStrings;
+
+    // If both the URI and the device Id match, we set the "is local" flag
+    // used to filter out the participant.
+    // TODO:
+    //  - This filter should always be applied, and any local streams should render
+    //    using local sinks. Local non-preview participants should have proxy participant
+    //    items replaced into this model using their local sink Ids.
+    //  - The app setting should remain and be used to control whether or not the preview
+    //    sink partipcant is rendered.
+    auto uri = participant[URI].toString();
+    participant[ISLOCAL] = false;
+    if (uri == accInfo.profileInfo.uri && participant[DEVICE] == getCurrentDeviceId(accInfo)) {
+        participant[BESTNAME] = tr("Me");
+        participant[ISLOCAL] = true;
+    } else {
+        try {
+            participant[BESTNAME] = accInfo.contactModel->bestNameForContact(uri);
+        } catch (...) {
+        }
+    }
+}
+
+QVariantList
+CurrentCall::getConferencesInfos() const
+{
+    QVariantList map;
+    try {
+        auto callModel = lrcInstance_->getCurrentCallModel();
+        auto& participantsModel = callModel->getParticipantsInfos(id_);
+        for (int index = 0; index < participantsModel.getParticipants().size(); index++) {
+            auto participant = participantsModel.toQJsonObject(index);
+            fillParticipantData(participant);
+            map.push_back(QVariant(participant));
+        }
+    } catch (...) {
+    }
+    return map;
+}
+
 void
 CurrentCall::updateCallInfo()
 {
@@ -119,49 +217,21 @@ CurrentCall::updateCallInfo()
     set_isGrid(callInfo.layout == call::Layout::GRID);
     set_isAudioOnly(callInfo.isAudioOnly);
 
-    bool isAudioMuted {};
-    bool isVideoMuted {};
-    bool isSharing {};
-    QString sharingSource {};
-    bool isCapturing {};
-    QString previewId {};
-    using namespace libjami::Media;
-    if (callInfo.status != lrc::api::call::Status::ENDED) {
-        for (const auto& media : callInfo.mediaList) {
-            if (media[MediaAttributeKey::MEDIA_TYPE] == Details::MEDIA_TYPE_VIDEO) {
-                if (media[MediaAttributeKey::SOURCE].startsWith(VideoProtocolPrefix::DISPLAY)
-                    || media[MediaAttributeKey::SOURCE].startsWith(VideoProtocolPrefix::FILE)) {
-                    isSharing = true;
-                    sharingSource = media[MediaAttributeKey::SOURCE];
-                }
-                if (media[MediaAttributeKey::ENABLED] == TRUE_STR
-                    && media[MediaAttributeKey::MUTED] == FALSE_STR && previewId.isEmpty()) {
-                    previewId = media[libjami::Media::MediaAttributeKey::SOURCE];
-                }
-                if (media[libjami::Media::MediaAttributeKey::SOURCE].startsWith(
-                        libjami::Media::VideoProtocolPrefix::CAMERA)) {
-                    isVideoMuted |= media[MediaAttributeKey::MUTED] == TRUE_STR;
-                    isCapturing = media[MediaAttributeKey::MUTED] == FALSE_STR;
-                }
-            } else if (media[MediaAttributeKey::MEDIA_TYPE] == Details::MEDIA_TYPE_AUDIO) {
-                if (media[MediaAttributeKey::LABEL] == "audio_0") {
-                    isAudioMuted |= media[libjami::Media::MediaAttributeKey::MUTED] == TRUE_STR;
-                }
-            }
-        }
-    }
-    set_previewId(previewId);
-    set_isAudioMuted(isAudioMuted);
-    set_isVideoMuted(isVideoMuted);
-    set_isSharing(isSharing);
-    set_sharingSource(sharingSource);
-    set_isCapturing(isCapturing);
+    auto callInfoEx = callInfo.getCallInfoEx();
+    set_previewId(callInfoEx["preview_id"].toString());
+    set_isAudioMuted(callInfoEx["is_audio_muted"].toBool());
+    set_isVideoMuted(callInfoEx["is_video_muted"].toBool());
+    set_isSharing(callInfoEx["is_sharing"].toBool());
+    set_sharingSource(isSharing_ ? callInfoEx["preview_id"].toString() : QString());
+    set_isCapturing(callInfoEx["is_capturing"].toBool());
+
     set_isHandRaised(callModel->isHandRaised(id_));
     set_isModerator(callModel->isModerator(id_));
 
     QStringList recorders {};
     if (callModel->hasCall(id_)) {
         auto callInfo = callModel->getCall(id_);
+        participantsModel_->setConferenceLayout(static_cast<int>(callInfo.layout), id_);
         recorders = callInfo.recordingPeers;
     }
     updateRecordingState(callModel->isRecording(id_));
@@ -200,26 +270,10 @@ CurrentCall::connectModel()
         return;
     }
 
-    connect(callModel,
-            &CallModel::callStatusChanged,
-            this,
-            &CurrentCall::onCallStatusChanged,
-            Qt::UniqueConnection);
-    connect(callModel,
-            &CallModel::callInfosChanged,
-            this,
-            &CurrentCall::onCallInfosChanged,
-            Qt::UniqueConnection);
-    connect(callModel,
-            &CallModel::currentCallChanged,
-            this,
-            &CurrentCall::onCurrentCallChanged,
-            Qt::UniqueConnection);
-    connect(callModel,
-            &CallModel::participantsChanged,
-            this,
-            &CurrentCall::onParticipantsChanged,
-            Qt::UniqueConnection);
+    connect(callModel, &CallModel::callStatusChanged, this, &CurrentCall::onCallStatusChanged, Qt::UniqueConnection);
+    connect(callModel, &CallModel::callInfosChanged, this, &CurrentCall::onCallInfosChanged, Qt::UniqueConnection);
+    connect(callModel, &CallModel::currentCallChanged, this, &CurrentCall::onCurrentCallChanged, Qt::UniqueConnection);
+    connect(callModel, &CallModel::participantsChanged, this, &CurrentCall::onParticipantsChanged, Qt::UniqueConnection);
     connect(callModel,
             &CallModel::remoteRecordersChanged,
             this,
@@ -230,6 +284,9 @@ CurrentCall::connectModel()
             this,
             &CurrentCall::onRecordingStateChanged,
             Qt::UniqueConnection);
+    connect(callModel, &CallModel::participantAdded, this, &CurrentCall::onParticipantAdded, Qt::UniqueConnection);
+    connect(callModel, &CallModel::participantRemoved, this, &CurrentCall::onParticipantRemoved, Qt::UniqueConnection);
+    connect(callModel, &CallModel::participantUpdated, this, &CurrentCall::onParticipantUpdated, Qt::UniqueConnection);
 }
 
 void
@@ -257,14 +314,14 @@ CurrentCall::onCurrentAccountIdChanged()
         auto& accInfo = lrcInstance_->getCurrentAccountInfo();
         set_isSIP(accInfo.profileInfo.type == profile::Type::SIP);
     } catch (const std::exception& e) {
-        qWarning() << "Can't update current call type" << e.what();
+        C_DBG << "Can't update current call type" << e.what();
     }
 
     connectModel();
 }
 
 void
-CurrentCall::onCallStatusChanged(const QString& callId, int code)
+CurrentCall::onCallStatusChanged(const QString& accountId, const QString& callId, int code)
 {
     Q_UNUSED(code)
 
@@ -335,8 +392,7 @@ CurrentCall::onRecordingStateChanged(const QString& callId, bool state)
 void
 CurrentCall::onShowIncomingCallView(const QString& accountId, const QString& convUid)
 {
-    if (accountId != lrcInstance_->get_currentAccountId()
-        || convUid != lrcInstance_->get_selectedConvUid()) {
+    if (accountId != lrcInstance_->get_currentAccountId() || convUid != lrcInstance_->get_selectedConvUid()) {
         return;
     }
 
