@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Savoir-faire Linux Inc.
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
+ * Copyright (C) 2021-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,26 +17,25 @@
 
 #include "currentconversation.h"
 
+#include "global.h"
+
 #include <api/conversationmodel.h>
+#include <api/contact.h>
 
 CurrentConversation::CurrentConversation(LRCInstance* lrcInstance, QObject* parent)
     : QObject(parent)
     , lrcInstance_(lrcInstance)
 {
-    uris_ = new CurrentConversationMembers(lrcInstance, this);
+    membersModel_ = new CurrentConversationMembers(lrcInstance, this);
+    set_members(QVariant::fromValue(membersModel_));
+
     // whenever the account changes, reconnect the new conversation model
     // for updates to the conversation and call state/id
-    connect(lrcInstance_,
-            &LRCInstance::currentAccountIdChanged,
-            this,
-            &CurrentConversation::connectModel);
+    connect(lrcInstance_, &LRCInstance::currentAccountIdChanged, this, &CurrentConversation::connectModel);
     connectModel();
 
     // update when the conversation itself changes
-    connect(lrcInstance_,
-            &LRCInstance::selectedConvUidChanged,
-            this,
-            &CurrentConversation::updateData);
+    connect(lrcInstance_, &LRCInstance::selectedConvUidChanged, this, &CurrentConversation::updateData);
 
     connect(&lrcInstance_->behaviorController(),
             &BehaviorController::showIncomingCallView,
@@ -55,7 +53,7 @@ CurrentConversation::updateData()
     // If the conversation is empty, clear the id and return.
     if (convId.isEmpty()) {
         set_id();
-        uris_->setMembers({}, {}, {});
+        membersModel_->setMembers({}, {}, {});
         return;
     }
 
@@ -95,7 +93,7 @@ CurrentConversation::updateData()
             for (const auto& banned : bannedUris)
                 uris.push_back(banned);
         }
-        uris_->setMembers(accountId, convId, uris);
+        membersModel_->setMembers(accountId, convId, uris);
         set_isSwarm(convInfo.isSwarm());
         set_isLegacy(convInfo.isLegacy());
         set_isCoreDialog(convInfo.isCoreDialog());
@@ -147,7 +145,7 @@ CurrentConversation::updateData()
         updateProfile(convId);
         updateActiveCalls(accountId, convId);
     } catch (...) {
-        qWarning() << "Can't update current conversation data for" << convId;
+        qWarning() << "Error while updating current conversation data for" << convId;
     }
 }
 
@@ -202,12 +200,6 @@ CurrentConversation::setInfo(const QString& key, const QString& value)
     accInfo.conversationModel->updateConversationInfos(convId, infos);
 }
 
-CurrentConversationMembers*
-CurrentConversation::uris() const
-{
-    return uris_;
-}
-
 void
 CurrentConversation::onConversationUpdated(const QString& convId)
 {
@@ -228,7 +220,7 @@ CurrentConversation::updateProfile(const QString& convId)
     try {
         if (auto optConv = convModel->getConversationForUid(convId)) {
             auto& convInfo = optConv->get();
-            // Now, update call informations (rdvAccount/device)
+            // Now, update call information (rdvAccount/device)
             if (convInfo.infos.contains("rdvAccount")) {
                 set_rdvAccount(convInfo.infos["rdvAccount"]);
             } else {
@@ -258,55 +250,44 @@ CurrentConversation::updateConversationPreferences(const QString& convId)
             color = convInfo.preferences["color"];
         }
         set_color(color);
-        if (convInfo.preferences.contains("ignoreNotifications")) {
-            set_ignoreNotifications(convInfo.preferences["ignoreNotifications"] == "true");
-        }
+        set_ignoreNotifications(convInfo.preferences.contains("ignoreNotifications")
+                                && convInfo.preferences["ignoreNotifications"] == "true");
     }
 }
 
 void
 CurrentConversation::connectModel()
 {
-    uris_->setMembers({}, {}, {});
-    auto convModel = lrcInstance_->getCurrentConversationModel();
-    if (!convModel)
-        return;
+    membersModel_->setMembers({}, {}, {});
 
-    connect(lrcInstance_->getCurrentConversationModel(),
-            &ConversationModel::conversationUpdated,
-            this,
-            &CurrentConversation::onConversationUpdated,
-            Qt::UniqueConnection);
-    connect(lrcInstance_->getCurrentConversationModel(),
-            &ConversationModel::profileUpdated,
-            this,
-            &CurrentConversation::updateProfile,
-            Qt::UniqueConnection);
-    connect(lrcInstance_->getCurrentConversationModel(),
-            &ConversationModel::onConversationErrorsUpdated,
-            this,
-            &CurrentConversation::updateErrors,
-            Qt::UniqueConnection);
-    connect(lrcInstance_->getCurrentConversationModel(),
-            &ConversationModel::activeCallsChanged,
-            this,
-            &CurrentConversation::updateActiveCalls,
-            Qt::UniqueConnection);
-    connect(lrcInstance_->getCurrentConversationModel(),
-            &ConversationModel::conversationPreferencesUpdated,
-            this,
-            &CurrentConversation::updateConversationPreferences,
-            Qt::UniqueConnection);
-    connect(lrcInstance_->getCurrentConversationModel(),
-            &ConversationModel::needsHost,
-            this,
-            &CurrentConversation::onNeedsHost,
-            Qt::UniqueConnection);
-    connect(lrcInstance_->getCurrentCallModel(),
-            &CallModel::callStatusChanged,
-            this,
-            &CurrentConversation::onCallStatusChanged,
-            Qt::UniqueConnection);
+    auto currentConversationModel = lrcInstance_->getCurrentConversationModel();
+    auto currentCallModel = lrcInstance_->getCurrentCallModel();
+    if (!currentConversationModel || !currentCallModel) {
+        C_DBG << "CurrentConversation: unable to connect to unavailable models";
+        return;
+    }
+
+    auto connectObjectSignal = [this](auto obj, auto signal, auto slot) {
+        connect(obj, signal, this, slot, Qt::UniqueConnection);
+    };
+
+    connectObjectSignal(currentConversationModel,
+                        &ConversationModel::conversationUpdated,
+                        &CurrentConversation::onConversationUpdated);
+    connectObjectSignal(currentConversationModel,
+                        &ConversationModel::profileUpdated,
+                        &CurrentConversation::updateProfile);
+    connectObjectSignal(currentConversationModel,
+                        &ConversationModel::conversationErrorsUpdated,
+                        &CurrentConversation::updateErrors);
+    connectObjectSignal(currentConversationModel,
+                        &ConversationModel::activeCallsChanged,
+                        &CurrentConversation::updateActiveCalls);
+    connectObjectSignal(currentConversationModel,
+                        &ConversationModel::conversationPreferencesUpdated,
+                        &CurrentConversation::updateConversationPreferences);
+    connectObjectSignal(currentConversationModel, &ConversationModel::needsHost, &CurrentConversation::onNeedsHost);
+    connectObjectSignal(currentCallModel, &CallModel::callStatusChanged, &CurrentConversation::onCallStatusChanged);
 }
 
 void
@@ -322,15 +303,15 @@ CurrentConversation::updateErrors(const QString& convId)
             auto& convInfo = optConv->get();
             for (const auto& [code, error] : convInfo.errors) {
                 if (code == 1) {
-                    newErrors.append(tr("An error occurred while fetching this repository"));
+                    newErrors.append(tr("An error occurred while fetching this repository."));
                 } else if (code == 2) {
-                    newErrors.append(tr("Unrecognized conversation mode"));
+                    newErrors.append(tr("Unrecognized conversation mode."));
                 } else if (code == 3) {
-                    newErrors.append(tr("An invalid message was detected"));
+                    newErrors.append(tr("An invalid message was detected."));
                 } else if (code == 4) {
-                    newErrors.append(tr("Not authorized to update conversation information"));
+                    newErrors.append(tr("Insufficient permission to update conversation information."));
                 } else if (code == 5) {
-                    newErrors.append(tr("An error occurred while committing a new message"));
+                    newErrors.append(tr("An error occurred while committing a new message."));
                 } else {
                     continue;
                 }
@@ -380,7 +361,7 @@ CurrentConversation::updateActiveCalls(const QString&, const QString& convId)
 }
 
 void
-CurrentConversation::onCallStatusChanged(const QString& callId, int)
+CurrentConversation::onCallStatusChanged(const QString& accountId, const QString& callId, int)
 {
     if (callId != callId_) {
         return;
