@@ -1,6 +1,5 @@
 /*!
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,17 +28,16 @@ void
 DBusErrorHandler::errorCallback()
 {
     qDebug() << "Dring has possibly crashed, "
-                "or has been killed... will wait 2.5 seconds and try to reconnect";
+                "or has been killed… will wait 2.5 seconds before attempting to reconnect.";
 
     Q_EMIT showDaemonReconnectPopup(true);
 
     QTimer::singleShot(2500, this, [this]() {
         if ((!lrc::api::Lrc::isConnected()) || (!lrc::api::Lrc::dbusIsValid())) {
-            qDebug() << "Could not reconnect to the daemon";
+            qDebug() << "An error occurred while attempting to reconnect to the daemon.";
             Q_EMIT daemonReconnectFailed();
         } else {
-            static_cast<DBusErrorHandler&>(GlobalInstances::dBusErrorHandler())
-                .finishedHandlingError();
+            static_cast<DBusErrorHandler&>(GlobalInstances::dBusErrorHandler()).finishedHandlingError();
         }
     });
 }
