@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023 Savoir-faire Linux Inc.
+ * Copyright (C) 2024-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@ public:
 
     bool parseHtmlString(const QString& html)
     {
-        return tidyParseString(doc_, html.toLocal8Bit().data()) >= 0;
+        return tidyParseString(doc_, html.toUtf8().data()) >= 0;
     }
 
     using TagNodeList = QMap<TidyTagId, QList<TidyNode>>;
@@ -63,10 +63,7 @@ public:
     {
         TagNodeList result;
         traverseNode(
-            tidyGetRoot(doc_),
-            tags,
-            [&result](TidyNode node, TidyTagId tag) { result[tag].append(node); },
-            maxDepth);
+            tidyGetRoot(doc_), tags, [&result](TidyNode node, TidyTagId tag) { result[tag].append(node); }, maxDepth);
 
         return result;
     }
@@ -75,22 +72,21 @@ public:
     TidyNode getFirstTagNode(TidyTagId tag, int maxDepth = -1)
     {
         TidyNode result = nullptr;
-        traverseNode(
-            tidyGetRoot(doc_),
-            {tag},
-            [&result](TidyNode node, TidyTagId) { result = node; },
-            maxDepth);
+        traverseNode(tidyGetRoot(doc_), {tag}, [&result](TidyNode node, TidyTagId) { result = node; }, maxDepth);
         return result;
     }
 
     // Extract the text value from a node.
     QString getNodeText(TidyNode node)
     {
-        TidyBuffer nodeValue = {};
+        TidyBuffer nodeValue = {0};
         if (!node || tidyNodeGetText(doc_, node, &nodeValue) != yes) {
             return QString();
         }
-        QString result = QString::fromUtf8((char*) nodeValue.bp, nodeValue.size);
+        QString result;
+        if (nodeValue.bp && nodeValue.size > 0) {
+            result = QString::fromUtf8(reinterpret_cast<char*>(nodeValue.bp), nodeValue.size);
+        }
         tidyBufFree(&nodeValue);
         return result;
     }
