@@ -416,7 +416,7 @@ MessagesAdapter::acceptInvitation(const QString& convId)
 }
 
 void
-MessagesAdapter::refuseInvitation(const QString& convUid)
+MessagesAdapter::declineInvitation(const QString& convUid)
 {
     const auto currentConvUid = convUid.isEmpty() ? lrcInstance_->get_selectedConvUid() : convUid;
     lrcInstance_->getCurrentConversationModel()->removeConversation(currentConvUid, false);
@@ -563,13 +563,13 @@ MessagesAdapter::isLocalImage(const QString& mimename)
 {
     if (mimename.startsWith("image/")) {
         QString fileFormat = mimename;
-        fileFormat.replace("image/", "");
+
         QImageReader reader;
-        QList<QByteArray> supportedFormats = reader.supportedImageFormats();
+        QList<QByteArray> supportedFormats = reader.supportedMimeTypes();
         auto iterator = std::find_if(supportedFormats.begin(),
                                      supportedFormats.end(),
                                      [fileFormat](const QByteArray& format) { return format == fileFormat; });
-        if (iterator != supportedFormats.end() && *iterator == "gif") {
+        if (iterator != supportedFormats.end() && *iterator == "image/gif") {
             return {{"isAnimatedImage", true}};
         }
         return {{"isImage", iterator != supportedFormats.end()}};
