@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2024 Savoir-faire Linux Inc.
+ * Copyright (C) 2019-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,8 +50,7 @@ public:
     void sendGetRequest(const QUrl& url,
                         const QMap<QString, QByteArray>& header,
                         std::function<void(const QByteArray&)>&& onDoneCallback);
-    void sendGetRequest(const QNetworkRequest& request,
-                        std::function<void(const QByteArray&)>&& onDoneCallback);
+    void sendGetRequest(const QNetworkRequest& request, std::function<void(const QByteArray&)>&& onDoneCallback);
     int downloadFile(const QUrl& url,
                      int replyId,
                      std::function<void(bool, const QString&)>&& onDoneCallback,
