@@ -1,6 +1,5 @@
 /**
- * Copyright (C) 2019-2023 Savoir-faire Linux Inc.
- * Author: Aline Gondim Santos   <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2019-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -171,9 +170,8 @@ PluginListModel::filterPlugins(VectorString& list) const
     list.erase(std::remove_if(list.begin(), // clazy:exclude=strict-iterators
                               list.end(),
                               [&](const QString& pluginName) -> bool {
-                                  const auto prefs = lrcInstance_->pluginModel()
-                                                         .getPluginPreferences(pluginName,
-                                                                               accountId);
+                                  const auto prefs = lrcInstance_->pluginModel().getPluginPreferences(pluginName,
+                                                                                                      accountId);
                                   return prefs.empty();
                               }),
                list.cend());
