@@ -1,6 +1,5 @@
 /**
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author: Aline Gondim Santos   <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,8 +24,8 @@
 class PluginListPreferenceModel : public AbstractListModelBase
 {
     Q_OBJECT
-    Q_PROPERTY(QString preferenceNewValue READ preferenceNewValue WRITE setPreferenceNewValue NOTIFY
-                   preferenceNewValueChanged)
+    Q_PROPERTY(
+        QString preferenceNewValue READ preferenceNewValue WRITE setPreferenceNewValue NOTIFY preferenceNewValueChanged)
     Q_PROPERTY(QString pluginId READ pluginId WRITE setPluginId NOTIFY pluginIdChanged)
     QML_PROPERTY(QString, preferenceKey)
     QML_PROPERTY(int, idx)
@@ -70,8 +69,7 @@ public:
 
     QString preferenceCurrentValue()
     {
-        return lrcInstance_->pluginModel().getPluginPreferencesValues(pluginId_,
-                                                                      accountId_)[preferenceKey_];
+        return lrcInstance_->pluginModel().getPluginPreferencesValues(pluginId_, accountId_)[preferenceKey_];
     }
 
     QString preferenceNewValue()
