@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2023 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -62,16 +60,13 @@ public:
                  const BehaviorController& behaviorController);
     ~ContactModel();
 
+    void initContacts();
+
     /**
      * Ask the daemon to add a contact.
      * @param contactInfo
      */
     void addContact(contact::Info contactInfo);
-    /**
-     * Add a pending item into the contact list
-     * @param contactUri
-     */
-    void addToContacts(const QString& contactUri);
     /**
      * Ask the daemon to remove a contact.
      * @param contactUri
@@ -82,7 +77,7 @@ public:
      * get contact information.
      * @param  contactUri
      * @return the contact::Info structure for a contact
-     * @throws out_of_range exception if can't find the contact
+     * @throws out_of_range exception if it is unable to find the contact
      */
     const contact::Info getContact(const QString& contactUri) const;
     ContactInfoMap getSearchResults() const;
@@ -110,10 +105,7 @@ public:
      * @param body
      * @return id from daemon
      */
-    uint64_t sendDhtMessage(const QString& uri,
-                            const QString& body,
-                            const QString& mimeType = {},
-                            int flag = 0) const;
+    uint64_t sendDhtMessage(const QString& uri, const QString& body, const QString& mimeType = {}, int flag = 0) const;
     /**
      * Get best id for contact
      * @param contactUri
@@ -131,11 +123,17 @@ public:
      */
     QString avatar(const QString& contactUri) const;
 
+    /**
+     * Get display name from storage
+     * @param contactUri
+     */
+    QString displayName(const QString& contactUri) const;
+
 Q_SIGNALS:
     /**
-     * Connect this signal to know when this model was updated.
+     * Connect this signal to know when a contact was updated.
      */
-    void modelUpdated(const QString& uri) const;
+    void contactUpdated(const QString& uri) const;
     /**
      * Connect this signal to know when a contact was added.
      * @param contactUri
@@ -154,9 +152,11 @@ Q_SIGNALS:
     /**
      * Connect this signal to know when a call is incoming.
      * @param fromId peer profile uri
-     * @param callId incoming call id
+     * @param callId call id
+     * @param isOutgoing
+     * @param toUri
      */
-    void incomingCall(const QString& from, const QString& callId) const;
+    void newCall(const QString& from, const QString& callId, bool isOutgoing, const QString& toUri) const;
     /**
      * Connect this signal to know when a text message arrives for this account
      * @param accountId
