@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2023 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -244,9 +242,15 @@ CallbacksHandler::CallbacksHandler(const Lrc& parent)
             Qt::QueuedConnection);
 
     connect(&ConfigurationManager::instance(),
-            &ConfigurationManagerInterface::exportOnRingEnded,
+            &ConfigurationManagerInterface::deviceAuthStateChanged,
             this,
-            &CallbacksHandler::slotExportOnRingEnded,
+            &CallbacksHandler::slotDeviceAuthStateChanged,
+            Qt::QueuedConnection);
+
+    connect(&ConfigurationManager::instance(),
+            &ConfigurationManagerInterface::addDeviceStateChanged,
+            this,
+            &CallbacksHandler::slotAddDeviceStateChanged,
             Qt::QueuedConnection);
 
     connect(&ConfigurationManager::instance(),
@@ -301,9 +305,9 @@ CallbacksHandler::CallbacksHandler(const Lrc& parent)
             &CallbacksHandler::slotAudioMeterReceived,
             Qt::QueuedConnection);
     connect(&ConfigurationManager::instance(),
-            &ConfigurationManagerInterface::conversationLoaded,
+            &ConfigurationManagerInterface::swarmLoaded,
             this,
-            &CallbacksHandler::slotConversationLoaded,
+            &CallbacksHandler::slotSwarmLoaded,
             Qt::QueuedConnection);
     connect(&ConfigurationManager::instance(),
             &ConfigurationManagerInterface::messagesFound,
@@ -311,10 +315,25 @@ CallbacksHandler::CallbacksHandler(const Lrc& parent)
             &CallbacksHandler::slotMessagesFound,
             Qt::QueuedConnection);
     connect(&ConfigurationManager::instance(),
-            &ConfigurationManagerInterface::messageReceived,
+            &ConfigurationManagerInterface::swarmMessageReceived,
             this,
             &CallbacksHandler::slotMessageReceived,
             Qt::QueuedConnection);
+    connect(&ConfigurationManager::instance(),
+            &ConfigurationManagerInterface::swarmMessageUpdated,
+            this,
+            &CallbacksHandler::slotMessageUpdated,
+            Qt::QueuedConnection);
+    connect(&ConfigurationManager::instance(),
+            &ConfigurationManagerInterface::reactionAdded,
+            this,
+            &CallbacksHandler::slotReactionAdded,
+            Qt::QueuedConnection);
+    connect(&ConfigurationManager::instance(),
+            &ConfigurationManagerInterface::reactionRemoved,
+            this,
+            &CallbacksHandler::slotReactionRemoved,
+            Qt::QueuedConnection);
     connect(&ConfigurationManager::instance(),
             &ConfigurationManagerInterface::conversationProfileUpdated,
             this,
@@ -393,10 +412,9 @@ CallbacksHandler::slotNewAccountMessage(const QString& accountId,
 void
 CallbacksHandler::slotNewBuddySubscription(const QString& accountId,
                                            const QString& uri,
-                                           bool status,
+                                           int status,
                                            const QString& message)
 {
-    Q_UNUSED(status)
     Q_UNUSED(message)
     Q_EMIT newBuddySubscription(accountId, uri, status);
 }
@@ -411,10 +429,7 @@ CallbacksHandler::slotNearbyPeerSubscription(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotVoiceMailNotify(const QString& accountId,
-                                      int newCount,
-                                      int oldCount,
-                                      int urgentCount)
+CallbacksHandler::slotVoiceMailNotify(const QString& accountId, int newCount, int oldCount, int urgentCount)
 {
     Q_EMIT voiceMailNotify(accountId, newCount, oldCount, urgentCount);
 }
@@ -426,17 +441,13 @@ CallbacksHandler::slotRecordPlaybackStopped(const QString& filePath)
 }
 
 void
-CallbacksHandler::slotContactAdded(const QString& accountId,
-                                   const QString& contactUri,
-                                   bool confirmed)
+CallbacksHandler::slotContactAdded(const QString& accountId, const QString& contactUri, bool confirmed)
 {
     Q_EMIT contactAdded(accountId, contactUri, confirmed);
 }
 
 void
-CallbacksHandler::slotContactRemoved(const QString& accountId,
-                                     const QString& contactUri,
-                                     bool banned)
+CallbacksHandler::slotContactRemoved(const QString& accountId, const QString& contactUri, bool banned)
 {
     Q_EMIT contactRemoved(accountId, contactUri, banned);
 }
@@ -450,10 +461,7 @@ CallbacksHandler::slotMediaChangeRequested(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotCallStateChanged(const QString& accountId,
-                                       const QString& callId,
-                                       const QString& state,
-                                       int code)
+CallbacksHandler::slotCallStateChanged(const QString& accountId, const QString& callId, const QString& state, int code)
 {
     Q_EMIT callStateChanged(accountId, callId, state, code);
 }
@@ -473,8 +481,7 @@ CallbacksHandler::slotAccountDetailsChanged(const QString& accountId, const MapS
 }
 
 void
-CallbacksHandler::slotVolatileAccountDetailsChanged(const QString& accountId,
-                                                    const MapStringString& details)
+CallbacksHandler::slotVolatileAccountDetailsChanged(const QString& accountId, const MapStringString& details)
 {
     Q_EMIT volatileAccountDetailsChanged(accountId, details);
 }
@@ -514,8 +521,7 @@ CallbacksHandler::slotIncomingMessage(const QString& accountId,
     for (auto& e : interaction.toStdMap()) {
         if (e.first.contains("x-ring/ring.profile.vcard")) {
             auto decodedHead = QUrl::fromPercentEncoding(e.first.toLatin1());
-            QRegularExpression re(
-                "x-ring/ring.profile.vcard;id=([A-z0-9]+),part=([0-9]+),of=([0-9]+)");
+            QRegularExpression re("x-ring/ring.profile.vcard;id=([A-z0-9]+),part=([0-9]+),of=([0-9]+)");
             auto match = re.match(decodedHead);
 
             if (!match.hasMatch())
@@ -534,9 +540,9 @@ CallbacksHandler::slotIncomingMessage(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotConferenceCreated(const QString& accountId, const QString& callId)
+CallbacksHandler::slotConferenceCreated(const QString& accountId, const QString& convId, const QString& callId)
 {
-    Q_EMIT conferenceCreated(accountId, callId);
+    Q_EMIT conferenceCreated(accountId, convId, callId);
 }
 
 void
@@ -546,20 +552,15 @@ CallbacksHandler::slotConferenceRemoved(const QString& accountId, const QString&
 }
 
 void
-CallbacksHandler::slotConferenceChanged(const QString& accountId,
-                                        const QString& callId,
-                                        const QString& state)
+CallbacksHandler::slotConferenceChanged(const QString& accountId, const QString& callId, const QString& state)
 {
     Q_EMIT conferenceChanged(accountId, callId, state);
     slotCallStateChanged(accountId, callId, state, 0);
 }
 
 void
-CallbacksHandler::slotAccountMessageStatusChanged(const QString& accountId,
-                                                  const QString& conversationId,
-                                                  const QString& peer,
-                                                  const QString& messageId,
-                                                  int status)
+CallbacksHandler::slotAccountMessageStatusChanged(
+    const QString& accountId, const QString& conversationId, const QString& peer, const QString& messageId, int status)
 {
     Q_EMIT accountMessageStatusChanged(accountId, conversationId, peer, messageId, status);
 }
@@ -571,11 +572,8 @@ CallbacksHandler::slotNeedsHost(const QString& accountId, const QString& convers
 }
 
 void
-CallbacksHandler::slotDataTransferEvent(const QString& accountId,
-                                        const QString& conversationId,
-                                        const QString&,
-                                        const QString& fileId,
-                                        uint codeStatus)
+CallbacksHandler::slotDataTransferEvent(
+    const QString& accountId, const QString& conversationId, const QString&, const QString& fileId, uint codeStatus)
 {
     auto event = libjami::DataTransferEventCode(codeStatus);
 
@@ -590,8 +588,12 @@ CallbacksHandler::slotDataTransferEvent(const QString& accountId,
         qlonglong totalSize, progress;
         QString path;
         try {
-            parent.getAccountModel().getAccountInfo(accountId).dataTransferModel->fileTransferInfo(
-                accountId, conversationId, fileId, path, totalSize, progress);
+            parent.getAccountModel().getAccountInfo(accountId).dataTransferModel->fileTransferInfo(accountId,
+                                                                                                   conversationId,
+                                                                                                   fileId,
+                                                                                                   path,
+                                                                                                   totalSize,
+                                                                                                   progress);
         } catch (...) {
             return;
         }
@@ -649,14 +651,6 @@ CallbacksHandler::slotKnownDevicesChanged(const QString& accountId, const MapStr
     Q_EMIT knownDevicesChanged(accountId, devices);
 }
 
-void
-CallbacksHandler::slotDeviceRevokationEnded(const QString& accountId,
-                                            const QString& deviceId,
-                                            const int status)
-{
-    Q_EMIT deviceRevocationEnded(accountId, deviceId, status);
-}
-
 void
 CallbacksHandler::slotAccountProfileReceived(const QString& accountId,
                                              const QString& displayName,
@@ -666,26 +660,40 @@ CallbacksHandler::slotAccountProfileReceived(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotExportOnRingEnded(const QString& accountId, int status, const QString& pin)
+CallbacksHandler::slotDeviceRevokationEnded(const QString& accountId, const QString& deviceId, const int status)
 {
-    Q_EMIT exportOnRingEnded(accountId, status, pin);
+    Q_EMIT deviceRevocationEnded(accountId, deviceId, status);
 }
 
 void
-CallbacksHandler::slotNameRegistrationEnded(const QString& accountId,
-                                            int status,
-                                            const QString& name)
+CallbacksHandler::slotDeviceAuthStateChanged(const QString& accountId, int state, const MapStringString& details)
+{
+    Q_EMIT deviceAuthStateChanged(accountId, state, details);
+}
+
+void
+CallbacksHandler::slotAddDeviceStateChanged(const QString& accountId,
+                                            uint32_t operationId,
+                                            int state,
+                                            const MapStringString& details)
+{
+    Q_EMIT addDeviceStateChanged(accountId, operationId, state, details);
+}
+
+void
+CallbacksHandler::slotNameRegistrationEnded(const QString& accountId, int status, const QString& name)
 {
     Q_EMIT nameRegistrationEnded(accountId, status, name);
 }
 
 void
 CallbacksHandler::slotRegisteredNameFound(const QString& accountId,
+                                          const QString& requestedName,
                                           int status,
                                           const QString& address,
-                                          const QString& name)
+                                          const QString& registeredName)
 {
-    Q_EMIT registeredNameFound(accountId, status, address, name);
+    Q_EMIT registeredNameFound(accountId, requestedName, status, address, registeredName);
 }
 
 void
@@ -713,21 +721,20 @@ CallbacksHandler::slotAudioMeterReceived(const QString& id, float level)
 }
 
 void
-CallbacksHandler::slotRemoteRecordingChanged(const QString& callId,
-                                             const QString& peerNumber,
-                                             bool state)
+CallbacksHandler::slotRemoteRecordingChanged(const QString& callId, const QString& peerNumber, bool state)
 {
     Q_EMIT remoteRecordingChanged(callId, peerNumber, state);
 }
 
 void
-CallbacksHandler::slotConversationLoaded(uint32_t requestId,
-                                         const QString& accountId,
-                                         const QString& conversationId,
-                                         const VectorMapStringString& messages)
+CallbacksHandler::slotSwarmLoaded(uint32_t requestId,
+                                  const QString& accountId,
+                                  const QString& conversationId,
+                                  const VectorSwarmMessage& messages)
 {
-    Q_EMIT conversationLoaded(requestId, accountId, conversationId, messages);
+    Q_EMIT swarmLoaded(requestId, accountId, conversationId, messages);
 }
+
 void
 CallbacksHandler::slotMessagesFound(uint32_t requestId,
                                     const QString& accountId,
@@ -740,11 +747,37 @@ CallbacksHandler::slotMessagesFound(uint32_t requestId,
 void
 CallbacksHandler::slotMessageReceived(const QString& accountId,
                                       const QString& conversationId,
-                                      const MapStringString& message)
+                                      const SwarmMessage& message)
 {
     Q_EMIT messageReceived(accountId, conversationId, message);
 }
 
+void
+CallbacksHandler::slotMessageUpdated(const QString& accountId,
+                                     const QString& conversationId,
+                                     const SwarmMessage& message)
+{
+    Q_EMIT messageUpdated(accountId, conversationId, message);
+}
+
+void
+CallbacksHandler::slotReactionAdded(const QString& accountId,
+                                    const QString& conversationId,
+                                    const QString& messageId,
+                                    const MapStringString& reaction)
+{
+    Q_EMIT reactionAdded(accountId, conversationId, messageId, reaction);
+}
+
+void
+CallbacksHandler::slotReactionRemoved(const QString& accountId,
+                                      const QString& conversationId,
+                                      const QString& messageId,
+                                      const QString& reactionId)
+{
+    Q_EMIT reactionRemoved(accountId, conversationId, messageId, reactionId);
+}
+
 void
 CallbacksHandler::slotConversationProfileUpdated(const QString& accountId,
                                                  const QString& conversationId,
@@ -762,8 +795,7 @@ CallbacksHandler::slotConversationRequestReceived(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotConversationRequestDeclined(const QString& accountId,
-                                                  const QString& conversationId)
+CallbacksHandler::slotConversationRequestDeclined(const QString& accountId, const QString& conversationId)
 {
     Q_EMIT conversationRequestDeclined(accountId, conversationId);
 }
