@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -66,18 +64,15 @@ Q_SIGNALS:
      * Connect this signal to get information when a peer is online.
      * @param accountId  related account.
      * @param contactUri the peer.
-     * @param present if the peer is online.
+     * @param presence if the peer is online.
      */
-    void newBuddySubscription(const QString& accountId, const QString& contactUri, bool present);
+    void newBuddySubscription(const QString& accountId, const QString& contactUri, int presence);
     /**
      * Connect this signal to get information when peer discovery changes.
      * @param contactUri the peer.
      * @param state is 0 if the peer is added.
      */
-    void newPeerSubscription(const QString& accountId,
-                             const QString& contactUri,
-                             int state,
-                             const QString& displayname);
+    void newPeerSubscription(const QString& accountId, const QString& contactUri, int state, const QString& displayname);
     /**
      * Connect this signal to know when a contact is removed by the daemon.
      * @param accountId the one who lost a contact.
@@ -98,9 +93,7 @@ Q_SIGNALS:
      * @param callId the call id
      * @param mediaList new media received
      */
-    void mediaChangeRequested(const QString& accountId,
-                              const QString& callId,
-                              const VectorMapStringString& mediaList);
+    void mediaChangeRequested(const QString& accountId, const QString& callId, const VectorMapStringString& mediaList);
     /**
      * Connect this signal to know when a call is updated
      * @param accountId
@@ -108,19 +101,14 @@ Q_SIGNALS:
      * @param state the new state
      * @param code
      */
-    void callStateChanged(const QString& accountId,
-                          const QString& callId,
-                          const QString& state,
-                          int code);
+    void callStateChanged(const QString& accountId, const QString& callId, const QString& state, int code);
     /**
      * Connect this signal to know when a call medias are available
      * @param callId the call id
      * @param event
      * @param mediaList new mediaList for the call
      */
-    void mediaNegotiationStatus(const QString& callId,
-                                const QString& event,
-                                const VectorMapStringString& mediaList);
+    void mediaNegotiationStatus(const QString& callId, const QString& event, const VectorMapStringString& mediaList);
     /**
      * Connect this signal to know when the account details have changed
      * @param accountId the one who changes
@@ -173,7 +161,7 @@ Q_SIGNALS:
      * Connect this signal to know when a new conference is created
      * @param callId of the conference
      */
-    void conferenceCreated(const QString& accountId, const QString& callId);
+    void conferenceCreated(const QString& accountId, const QString& conversationId, const QString& callId);
     void conferenceChanged(const QString& accountId, const QString& confId, const QString& state);
     /**
      * Connect this signal to know when a conference is removed
@@ -232,17 +220,28 @@ Q_SIGNALS:
      * @param displayName
      * @param userPhoto
      */
-    void accountProfileReceived(const QString& accountId,
-                                const QString& displayName,
-                                const QString& userPhoto);
+    void accountProfileReceived(const QString& accountId, const QString& displayName, const QString& userPhoto);
 
     /**
-     * Emit exportOnRingEnded
+     * Device authentication state has changed
      * @param accountId
-     * @param status SUCCESS = 0, WRONG_PASSWORD = 1, NETWORK_ERROR = 2
-     * @param pin
+     * @param state
+     * @param details map
      */
-    void exportOnRingEnded(const QString& accountId, int status, const QString& pin);
+    void deviceAuthStateChanged(const QString& accountId, int state, const MapStringString& details);
+
+    /**
+     * Add device state has changed
+     * @param accountId
+     * @param operationId
+     * @param state
+     * @param details map
+     */
+
+    void addDeviceStateChanged(const QString& accountId,
+                               uint32_t operationId,
+                               int state,
+                               const MapStringString& details);
 
     /**
      * Name registration has ended
@@ -255,13 +254,16 @@ Q_SIGNALS:
     /**
      * Name registration has been found
      * @param accountId
+     * @param requestedName the name requested
      * @param status
-     * @param name
+     * @param address
+     * @param registeredName the name found, have same normalized form as requestedName
      */
     void registeredNameFound(const QString& accountId,
+                             const QString& requestedName,
                              int status,
                              const QString& address,
-                             const QString& name);
+                             const QString& registeredName);
 
     /**
      * Migration ended
@@ -345,12 +347,8 @@ Q_SIGNALS:
                        const QString& accountId,
                        const QString& conversationId,
                        const VectorMapStringString& messages);
-    void messageReceived(const QString& accountId,
-                         const QString& conversationId,
-                         const SwarmMessage& message);
-    void messageUpdated(const QString& accountId,
-                        const QString& conversationId,
-                        const SwarmMessage& message);
+    void messageReceived(const QString& accountId, const QString& conversationId, const SwarmMessage& message);
+    void messageUpdated(const QString& accountId, const QString& conversationId, const SwarmMessage& message);
     void reactionAdded(const QString& accountId,
                        const QString& conversationId,
                        const QString& messageId,
@@ -372,10 +370,7 @@ Q_SIGNALS:
                                  const QString& conversationId,
                                  const QString& memberId,
                                  int event);
-    void conversationError(const QString& accountId,
-                           const QString& conversationId,
-                           int code,
-                           const QString& what);
+    void conversationError(const QString& accountId, const QString& conversationId, int code, const QString& what);
     void activeCallsChanged(const QString& accountId,
                             const QString& conversationId,
                             const VectorMapStringString& activeCalls);
@@ -407,12 +402,12 @@ private Q_SLOTS:
      * Emit newBuddySubscription
      * @param accountId
      * @param contactUri
-     * @param status if the contact is present
+     * @param status if the contact is present (1=dht presence, 0=offline, 2=connected)
      * @param message unused for now
      */
     void slotNewBuddySubscription(const QString& accountId,
                                   const QString& contactUri,
-                                  bool status,
+                                  int status,
                                   const QString& message);
     /**
      * Emit contactAdded
@@ -472,19 +467,14 @@ private Q_SLOTS:
      * @param state the new state
      * @param code unused for now
      */
-    void slotCallStateChanged(const QString& accountId,
-                              const QString& callId,
-                              const QString& state,
-                              int code);
+    void slotCallStateChanged(const QString& accountId, const QString& callId, const QString& state, int code);
     /**
      * Emit mediaNegotiationStatus
      * @param callId the call which changes.
      * @param eventstate the new state
      * @param mediaList new mediaList for the call
      */
-    void slotMediaNegotiationStatus(const QString& callId,
-                                    const QString& event,
-                                    const VectorMapStringString& mediaList);
+    void slotMediaNegotiationStatus(const QString& callId, const QString& event, const VectorMapStringString& mediaList);
     /**
      * Parse a call message and emit incomingVCardChunk if it's a VCard chunk
      * else incomingCallMessage if it's a text message
@@ -500,9 +490,10 @@ private Q_SLOTS:
     /**
      * Emit conferenceCreated
      * @param accountId
-     * @param callId of the conference
+     * @param callId         of the conference
+     * @param conversationId of the conference
      */
-    void slotConferenceCreated(const QString& accountId, const QString& callId);
+    void slotConferenceCreated(const QString& accountId, const QString& conversationId, const QString& callId);
     /**
      * Emit conferenceRemove
      * @param accountId
@@ -515,9 +506,7 @@ private Q_SLOTS:
      * @param callId of the conference
      * @param state, new state
      */
-    void slotConferenceChanged(const QString& accountId,
-                               const QString& callId,
-                               const QString& state);
+    void slotConferenceChanged(const QString& accountId, const QString& callId, const QString& state);
     /**
      * Emit accountMessageStatusChanged
      * @param accountId, account linked
@@ -557,9 +546,7 @@ private Q_SLOTS:
      * @param deviceId
      * @param status SUCCESS = 0, WRONG_PASSWORD = 1, UNKNOWN_DEVICE = 2
      */
-    void slotDeviceRevokationEnded(const QString& accountId,
-                                   const QString& deviceId,
-                                   const int status);
+    void slotDeviceRevokationEnded(const QString& accountId, const QString& deviceId, const int status);
 
     /**
      * Emit account avatar has been received
@@ -567,17 +554,27 @@ private Q_SLOTS:
      * @param displayName
      * @param userPhoto
      */
-    void slotAccountProfileReceived(const QString& accountId,
-                                    const QString& displayName,
-                                    const QString& userPhoto);
+    void slotAccountProfileReceived(const QString& accountId, const QString& displayName, const QString& userPhoto);
 
     /**
-     * Emit exportOnRingEnded
+     * Device authentication state has changed
      * @param accountId
-     * @param status SUCCESS = 0, WRONG_PASSWORD = 1, NETWORK_ERROR = 2
-     * @param pin
+     * @param state
+     * @param details map
      */
-    void slotExportOnRingEnded(const QString& accountId, int status, const QString& pin);
+    void slotDeviceAuthStateChanged(const QString& accountId, int state, const MapStringString& details);
+
+    /**
+     * Add device state has changed
+     * @param accountId
+     * @param operationId
+     * @param state
+     * @param details map
+     */
+    void slotAddDeviceStateChanged(const QString& accountId,
+                                   uint32_t operationId,
+                                   int state,
+                                   const MapStringString& details);
 
     /**
      * Emit nameRegistrationEnded
@@ -590,13 +587,16 @@ private Q_SLOTS:
     /**
      * Emit registeredNameFound
      * @param accountId
+     * @param requestedName requested name
      * @param status
-     * @param name
+     * @param address
+     * @param registeredName found name, have same normalized form as requestedName
      */
     void slotRegisteredNameFound(const QString& accountId,
+                                 const QString& requestedName,
                                  int status,
                                  const QString& address,
-                                 const QString& name);
+                                 const QString& registeredName);
 
     /**
      * emit migrationEnded
@@ -664,12 +664,8 @@ private Q_SLOTS:
                            const QString& accountId,
                            const QString& conversationId,
                            const VectorMapStringString& messages);
-    void slotMessageReceived(const QString& accountId,
-                             const QString& conversationId,
-                             const SwarmMessage& message);
-    void slotMessageUpdated(const QString& accountId,
-                            const QString& conversationId,
-                            const SwarmMessage& message);
+    void slotMessageReceived(const QString& accountId, const QString& conversationId, const SwarmMessage& message);
+    void slotMessageUpdated(const QString& accountId, const QString& conversationId, const SwarmMessage& message);
     void slotReactionAdded(const QString& accountId,
                            const QString& conversationId,
                            const QString& messageId,
@@ -694,10 +690,7 @@ private Q_SLOTS:
                                      const QString& conversationId,
                                      const QString& memberId,
                                      int event);
-    void slotOnConversationError(const QString& accountId,
-                                 const QString& conversationId,
-                                 int code,
-                                 const QString& what);
+    void slotOnConversationError(const QString& accountId, const QString& conversationId, int code, const QString& what);
     void slotActiveCallsChanged(const QString& accountId,
                                 const QString& conversationId,
                                 const VectorMapStringString& activeCalls);
