@@ -1,19 +1,19 @@
-/****************************************************************************
- *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
- *                                                                          *
- *   This library is free software; you can redistribute it and/or          *
- *   modify it under the terms of the GNU Lesser General Public             *
- *   License as published by the Free Software Foundation; either           *
- *   version 2.1 of the License, or (at your option) any later version.     *
- *                                                                          *
- *   This library is distributed in the hope that it will be useful,        *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
- *   Lesser General Public License for more details.                        *
- *                                                                          *
- *   You should have received a copy of the GNU General Public License      *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
- ***************************************************************************/
+/*
+ * Copyright (C) 2017-2025 Savoir-faire Linux Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
 
 #include "api/callmodel.h"
 
@@ -47,6 +47,8 @@
 #include <QString>
 #include <QUrl>
 #include <QSize>
+#include <qlogging.h>
+#include <qtcoreexports.h>
 
 // std
 #include <chrono>
@@ -120,7 +122,7 @@ static const std::map<short, QString>
                               {513, QObject::tr("Message Too Large")},
                               {580, QObject::tr("Precondition Failure")},
                               {600, QObject::tr("Busy Everywhere")},
-                              {603, QObject::tr("Call Refused")},
+                              {603, QObject::tr("Call Declined")},
                               {604, QObject::tr("Does Not Exist Anywhere")},
                               {606, QObject::tr("Not Acceptable Anywhere")}};
 
@@ -141,6 +143,15 @@ public:
     QVariantList callAdvancedInformation();
     MapStringString advancedInformationForCallId(QString callId);
 
+    /**
+     * Get a suitable fallback conversation for when the client should select a new one.
+     * For example if the peer whose conversation was used to host the conference leaves the conference,
+     * we need to pick another conversation to display the conference call.
+     * @param confId the conference id
+     * @return the conversation to use as fallback, nullopt if client does not need to change conversation or if none found
+     */
+    OptRef<conversation::Info> getFallbackConversationForConference(const QString& confId);
+
     QStringList getCallIds();
 
     CallModel::CallInfoMap calls;
@@ -226,6 +237,7 @@ public Q_SLOTS:
      */
     void slotConferenceCreated(const QString& accountId, const QString& conversationId, const QString& callId);
     void slotConferenceChanged(const QString& accountId, const QString& callId, const QString& state);
+    void slotConferenceRemoved(const QString& accountId, const QString& confId);
     /**
      * Listen from CallbacksHandler when a voice mail notice is incoming
      * @param accountId
@@ -683,23 +695,23 @@ CallModel::accept(const QString& callId) const
 }
 
 void
-CallModel::hangUp(const QString& callId) const
+CallModel::end(const QString& callId) const
 {
     if (!hasCall(callId))
         return;
     auto& call = pimpl_->calls[callId];
 
     if (call->status == call::Status::INCOMING_RINGING) {
-        CallManager::instance().refuse(owner.id, callId);
+        CallManager::instance().decline(owner.id, callId);
         return;
     }
 
     switch (call->type) {
     case call::Type::DIALOG:
-        CallManager::instance().hangUp(owner.id, callId);
+        CallManager::instance().end(owner.id, callId);
         break;
     case call::Type::CONFERENCE:
-        CallManager::instance().hangUpConference(owner.id, callId);
+        CallManager::instance().endConference(owner.id, callId);
         break;
     case call::Type::INVALID:
     default:
@@ -708,11 +720,11 @@ CallModel::hangUp(const QString& callId) const
 }
 
 void
-CallModel::refuse(const QString& callId) const
+CallModel::decline(const QString& callId) const
 {
     if (!hasCall(callId))
         return;
-    CallManager::instance().refuse(owner.id, callId);
+    CallManager::instance().decline(owner.id, callId);
 }
 
 void
@@ -741,9 +753,9 @@ CallModel::togglePause(const QString& callId) const
 
     if (call->status == call::Status::PAUSED) {
         if (call->type == call::Type::DIALOG) {
-            CallManager::instance().unhold(owner.id, callId);
+            CallManager::instance().resume(owner.id, callId);
         } else {
-            CallManager::instance().unholdConference(owner.id, callId);
+            CallManager::instance().resumeConference(owner.id, callId);
         }
     } else if (call->status == call::Status::IN_PROGRESS) {
         if (call->type == call::Type::DIALOG)
@@ -824,7 +836,7 @@ CallModel::joinCalls(const QString& callIdA, const QString& callIdB) const
         auto call = call1.type == call::Type::CONFERENCE ? callIdB : callIdA;
         auto conf = call1.type == call::Type::CONFERENCE ? callIdA : callIdB;
         // Unpause conference if conference was not active
-        CallManager::instance().unholdConference(owner.id, conf);
+        CallManager::instance().resumeConference(owner.id, conf);
         auto accountCall = call1.type == call::Type::CONFERENCE ? accountIdCall2 : accountIdCall1;
 
         bool joined = CallManager::instance().addParticipant(accountCall, call, accountCall, conf);
@@ -1007,6 +1019,7 @@ CallModelPimpl::CallModelPimpl(const CallModel& linked,
     connect(&callbacksHandler, &CallbacksHandler::incomingVCardChunk, this, &CallModelPimpl::slotincomingVCardChunk);
     connect(&callbacksHandler, &CallbacksHandler::conferenceCreated, this, &CallModelPimpl::slotConferenceCreated);
     connect(&callbacksHandler, &CallbacksHandler::conferenceChanged, this, &CallModelPimpl::slotConferenceChanged);
+    connect(&callbacksHandler, &CallbacksHandler::conferenceRemoved, this, &CallModelPimpl::slotConferenceRemoved);
     connect(&callbacksHandler, &CallbacksHandler::voiceMailNotify, this, &CallModelPimpl::slotVoiceMailNotify);
     connect(&CallManager::instance(),
             &CallManagerInterface::onConferenceInfosUpdated,
@@ -1056,6 +1069,56 @@ CallModelPimpl::advancedInformationForCallId(QString callId)
     return infoMap;
 }
 
+OptRef<conversation::Info>
+CallModelPimpl::getFallbackConversationForConference(const QString& confId)
+{
+    if (confId.isEmpty()) {
+        qWarning() << "Empty conference ID provided.";
+        return std::nullopt;
+    }
+
+    auto currentConversation = linked.owner.conversationModel->getConversationForCallId(confId);
+    if (!currentConversation) {
+        qWarning() << "No conversation found for conference ID:" << confId;
+        return std::nullopt;
+    }
+
+    const auto participantsIt = participantsModel.find(confId);
+    if (participantsIt == participantsModel.end()) {
+        qWarning() << "No participants model found for conference ID:" << confId;
+        return std::nullopt;
+    }
+
+    // There should always be at least 2 participants in a SIP call/conference
+    const auto participants = participantsIt->second->getParticipants();
+    if (participants.size() <= 1) {
+        qWarning() << participants.size() << "participants found in conference" << confId
+                   << ", no fallback conversation available.";
+        return std::nullopt;
+    }
+
+    // Check if any participant matches the current conversation
+    // If yes, then no need to switch conversation, so return nullopt
+    for (const auto& participant : participants) {
+        const auto conv = linked.owner.conversationModel->getConversationForPeerUri(participant.uri);
+        if (conv && currentConversation->get().uid == conv->get().uid) {
+            qDebug() << "Current conversation matches a participant. No fallback needed.";
+            return std::nullopt;
+        }
+    }
+
+    OptRef<conversation::Info> fallbackConversation = std::nullopt;
+    for (const auto& participant : participants) {
+        if (participant.uri != linked.owner.profileInfo.uri) {
+            fallbackConversation = linked.owner.conversationModel->getConversationForPeerUri(participant.uri);
+            qDebug() << "Fallback conversation found with URI:" << participant.uri;
+            break;
+        }
+    }
+
+    return fallbackConversation;
+}
+
 QStringList
 CallModelPimpl::getCallIds()
 {
@@ -1154,14 +1217,14 @@ CallModel::setCurrentCall(const QString& callId) const
         return;
     pimpl_->currentCall_ = callId;
 
-    // Unhold call
+    // Resume call
     auto& call = pimpl_->calls[callId];
     if (call->status == call::Status::PAUSED) {
         auto& call = pimpl_->calls[callId];
         if (call->type == call::Type::DIALOG) {
-            CallManager::instance().unhold(owner.id, callId);
+            CallManager::instance().resume(owner.id, callId);
         } else {
-            CallManager::instance().unholdConference(owner.id, callId);
+            CallManager::instance().resumeConference(owner.id, callId);
         }
     }
 
@@ -1309,9 +1372,9 @@ CallModel::muteStream(const QString& confId,
 }
 
 void
-CallModel::hangupParticipant(const QString& confId, const QString& accountUri, const QString& deviceId)
+CallModel::disconnectParticipant(const QString& confId, const QString& accountUri, const QString& deviceId)
 {
-    CallManager::instance().hangupParticipant(owner.id, confId, accountUri, deviceId);
+    CallManager::instance().disconnectParticipant(owner.id, confId, accountUri, deviceId);
 }
 
 void
@@ -1397,7 +1460,7 @@ CallModelPimpl::slotCallStateChanged(const QString& accountId, const QString& ca
 
         if (!(details["CALL_TYPE"] == "1") && !linked.owner.confProperties.allowIncoming
             && linked.owner.profileInfo.type == profile::Type::JAMI) {
-            linked.refuse(callId);
+            linked.decline(callId);
             return;
         }
 
@@ -1578,6 +1641,7 @@ CallModelPimpl::slotOnConferenceInfosUpdated(const QString& confId, const Vector
     // For now, the rendez-vous account can see ongoing calls
     // And must be notified when a new
     QStringList callList = CallManager::instance().getParticipantList(linked.owner.id, confId);
+    qDebug() << "[conf:" << confId << "] Conference infos updated. Calls remaining:" << callList.size();
     Q_FOREACH (const auto& call, callList) {
         Q_EMIT linked.callAddedToConference(call, "", confId);
         if (calls.find(call) == calls.end()) {
@@ -1597,6 +1661,21 @@ CallModelPimpl::slotOnConferenceInfosUpdated(const QString& confId, const Vector
         participantIt->second->update(infos);
     it->second->layout = participantIt->second->getLayout();
 
+    // Check if we need to switch conversation
+    auto currentConversation = linked.owner.conversationModel->getConversationForCallId(confId);
+    if (currentConversation && callList.size() >= 2) {
+        auto fallbackConversation = getFallbackConversationForConference(confId);
+        // If a fallback conversation was returned, switch to it
+        if (fallbackConversation) {
+            currentConversation->get().confId.clear();
+            fallbackConversation->get().confId = confId;
+            fallbackConversation->get().callId = confId;
+            qWarning() << "[conf:" << confId
+                       << "] Switching to fallback conversation:" << fallbackConversation->get().uid;
+            linked.owner.conversationModel->selectConversation(fallbackConversation->get().uid);
+        }
+    }
+
     // if Jami, remove @ring.dht
     for (auto& i : participantIt->second->getParticipants()) {
         i.uri.replace("@ring.dht", "");
@@ -1691,6 +1770,80 @@ CallModelPimpl::slotConferenceChanged(const QString& accountId, const QString& c
     Q_EMIT linked.currentCallChanged(currentCall_);
 }
 
+void
+CallModelPimpl::slotConferenceRemoved(const QString& accountId, const QString& confId)
+{
+    if (accountId != linked.owner.id || !linked.owner.conversationModel) {
+        return;
+    }
+    auto confIt = calls.find(confId);
+    if (confIt == calls.end() || !confIt->second) {
+        return;
+    }
+
+    qWarning() << "[conf:" << confId
+               << "] Conference removed, determining remaining participant to switch conversation.";
+
+    QString remainingPeerUri;
+    QString remainingCallId;
+
+    auto participantsIt = participantsModel.find(confId);
+    if (participantsIt != participantsModel.end()) {
+        const auto participants = participantsIt->second->getParticipants();
+        // Assuming the participants model is up to date, it should contain all remaining participants in the conference
+        // Which should be 2: the host and the remaining remote peer
+        // Therefore, we look for the participant which is not ourselves
+        for (const auto& participant : participants) {
+            if (participant.uri != linked.owner.profileInfo.uri) {
+                remainingPeerUri = participant.uri;
+                try {
+                    remainingCallId = linked.getCallFromURI(remainingPeerUri, true).id;
+                } catch (const std::exception& e) {
+                    qWarning() << "[conf:" << confId << "] Could not find call for peerUri:" << remainingPeerUri << ":"
+                               << e.what();
+                }
+                break;
+            }
+        }
+    } else {
+        qWarning() << "[conf:" << confId << "] Participants model not found for conference";
+    }
+
+    auto currentConversation = linked.owner.conversationModel->getConversationForCallId(confId);
+    auto fallbackConversation = getFallbackConversationForConference(confId);
+    // If we have a fallback conversation, that means the client should switch to it
+    if (fallbackConversation) {
+        if (currentConversation) {
+            currentConversation->get().confId.clear();
+        }
+        auto& targetConv = fallbackConversation->get();
+        targetConv.confId.clear();
+        if (!remainingCallId.isEmpty()) {
+            targetConv.callId = remainingCallId;
+        }
+        qWarning() << "[conf:" << confId << "] Switching to conversation:" << targetConv.uid;
+        linked.owner.conversationModel->selectConversation(targetConv.uid);
+    } else if (currentConversation) {
+        auto& targetConv = currentConversation->get();
+        targetConv.confId.clear();
+        if (!remainingCallId.isEmpty()) {
+            targetConv.callId = remainingCallId;
+        }
+        qWarning() << "[conf:" << confId << "] Staying in current conversation:" << targetConv.uid;
+    } else {
+        qWarning() << "[conf:" << confId << "] No conversation available to update after conference removal";
+    }
+
+    // Now remove the conference from our models and list of calls then update currentCall_
+    participantsModel.erase(confId);
+    calls.erase(confIt);
+
+    currentCall_ = remainingCallId;
+    Q_EMIT linked.currentCallChanged(currentCall_);
+
+    qDebug() << "[conf:" << confId << "] Conference removed, transitioned to call" << currentCall_;
+}
+
 void
 CallModelPimpl::onRemoteRecordingChanged(const QString& callId, const QString& peerUri, bool state)
 {
