@@ -1,19 +1,20 @@
-/******************************************************************************
- *   Copyright (C) 2014-2025 Savoir-faire Linux Inc.                          *
- *                                                                            *
- *   This library is free software; you can redistribute it and/or            *
- *   modify it under the terms of the GNU Lesser General Public               *
- *   License as published by the Free Software Foundation; either             *
- *   version 2.1 of the License, or (at your option) any later version.       *
- *                                                                            *
- *   This library is distributed in the hope that it will be useful,          *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of           *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU        *
- *   Lesser General Public License for more details.                          *
- *                                                                            *
- *   You should have received a copy of the Lesser GNU General Public License *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>.    *
- *****************************************************************************/
+/*
+ * Copyright (C) 2014-2025 Savoir-faire Linux Inc.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the Lesser GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #pragma once
 
 #include <QtCore/QObject>
@@ -97,7 +98,10 @@ public:
                                        convertMap(message));
             }),
             exportable_callback<CallSignal::IncomingCall>(
-                [this](const std::string& accountId, const std::string& callId, const std::string& from) {
+                [this](const std::string& accountId,
+                       const std::string& callId,
+                       const std::string& from,
+                       const std::vector<std::map<std::string, std::string>>& mediaList) {
                     LOG_LIBJAMI_SIGNAL3("incomingCall",
                                         QString(accountId.c_str()),
                                         QString(callId.c_str()),
@@ -290,12 +294,12 @@ public Q_SLOTS: // METHODS
         return temp;
     }
 
-    bool hangUp(const QString& accountId, const QString& callId)
+    bool end(const QString& accountId, const QString& callId)
     {
         return libjami::hangUp(accountId.toStdString(), callId.toStdString());
     }
 
-    bool hangUpConference(const QString& accountId, const QString& confId)
+    bool endConference(const QString& accountId, const QString& confId)
     {
         return libjami::hangUpConference(accountId.toStdString(), confId.toStdString());
     }
@@ -383,7 +387,7 @@ public Q_SLOTS: // METHODS
         libjami::recordPlaybackSeek(value);
     }
 
-    bool refuse(const QString& accountId, const QString& callId)
+    bool decline(const QString& accountId, const QString& callId)
     {
         return libjami::refuse(accountId.toStdString(), callId.toStdString());
     }
@@ -426,12 +430,12 @@ public Q_SLOTS: // METHODS
         return libjami::transfer(accountId.toStdString(), callId.toStdString(), to.toStdString());
     }
 
-    bool unhold(const QString& accountId, const QString& callId)
+    bool resume(const QString& accountId, const QString& callId)
     {
         return libjami::unhold(accountId.toStdString(), callId.toStdString());
     }
 
-    bool unholdConference(const QString& accountId, const QString& confId)
+    bool resumeConference(const QString& accountId, const QString& confId)
     {
         return libjami::unholdConference(accountId.toStdString(), confId.toStdString());
     }
@@ -508,10 +512,10 @@ public Q_SLOTS: // METHODS
                             state);
     }
 
-    void hangupParticipant(const QString& accountId,
-                           const QString& confId,
-                           const QString& accountUri,
-                           const QString& deviceId)
+    void disconnectParticipant(const QString& accountId,
+                               const QString& confId,
+                               const QString& accountUri,
+                               const QString& deviceId)
     {
         libjami::hangupParticipant(accountId.toStdString(),
                                    confId.toStdString(),
