@@ -1,7 +1,5 @@
 /******************************************************************************
- *    Copyright (C) 2014-2023 Savoir-faire Linux Inc.                         *
- *   Author : Philippe Groarke <philippe.groarke@savoirfairelinux.com>        *
- *   Author : Alexandre Lision <alexandre.lision@savoirfairelinux.com>        *
+ *   Copyright (C) 2014-2025 Savoir-faire Linux Inc.                          *
  *                                                                            *
  *   This library is free software; you can redistribute it and/or            *
  *   modify it under the terms of the GNU Lesser General Public               *
@@ -130,10 +128,10 @@ public Q_SLOTS: // METHODS
 #endif
     }
 
-    void closeVideoInput(const QString& resource)
+    bool closeVideoInput(const QString& resource)
     {
 #ifdef ENABLE_VIDEO
-        libjami::closeVideoInput(resource.toLatin1().toStdString());
+        return libjami::closeVideoInput(resource.toLatin1().toStdString());
 #endif
     }
 
@@ -185,8 +183,7 @@ public Q_SLOTS: // METHODS
 
     QString startLocalMediaRecorder(const QString& videoInputId, const QString& path)
     {
-        return QString::fromStdString(
-            libjami::startLocalMediaRecorder(videoInputId.toStdString(), path.toStdString()));
+        return QString::fromStdString(libjami::startLocalMediaRecorder(videoInputId.toStdString(), path.toStdString()));
     }
 
     MapStringString getRenderer(const QString& id)
@@ -236,8 +233,7 @@ public Q_SLOTS: // METHODS
 
 Q_SIGNALS: // SIGNALS
     void deviceEvent();
-    void decodingStarted(
-        const QString& id, const QString& shmPath, int width, int height, bool isMixer);
+    void decodingStarted(const QString& id, const QString& shmPath, int width, int height, bool isMixer);
     void decodingStopped(const QString& id, const QString& shmPath, bool isMixer);
     void fileOpened(const QString& path, const MapStringString& info);
 };
