@@ -33,10 +33,10 @@ using namespace std::chrono_literals;
 
 const std::string DhtProtocolException::GET_NO_INFOHASH {"Get_values with no info_hash"};
 const std::string DhtProtocolException::LISTEN_NO_INFOHASH {"Listen with no info_hash"};
-const std::string DhtProtocolException::LISTEN_WRONG_TOKEN {"Listen with wrong token"};
+const std::string DhtProtocolException::LISTEN_WRONG_TOKEN {"Listen with incorrect token"};
 const std::string DhtProtocolException::PUT_NO_INFOHASH {"Put with no info_hash"};
-const std::string DhtProtocolException::PUT_WRONG_TOKEN {"Put with wrong token"};
-const std::string DhtProtocolException::PUT_INVALID_ID {"Put with invalid id"};
+const std::string DhtProtocolException::PUT_WRONG_TOKEN {"Put with incorrect token"};
+const std::string DhtProtocolException::PUT_INVALID_ID {"Put with invalid ID"};
 const std::string DhtProtocolException::STORAGE_NOT_FOUND {"Access operation for unknown storage"};
 
 constexpr std::chrono::seconds NetworkEngine::UDP_REPLY_TIME;
@@ -133,7 +133,7 @@ NetworkEngine::tellListener(const Sp<Node>& node, Tid socket_id, const InfoHash&
         }
     } catch (const std::overflow_error& e) {
         if (logger_)
-            logger_->e("Can't send value: buffer not large enough !");
+            logger_->e("Unable to send value: buffer not large enough.");
     }
 }
 
@@ -288,13 +288,14 @@ NetworkEngine::requestStep(Sp<Request> sreq)
     auto& node = *req.node;
     if (req.isExpired(now)) {
         // if (logger_)
-        //     logger_->d(node.id, "[node %s] expired !", node.toString().c_str());
+        //     logger_->d(node.id, "[node %s] expired.", node.toString().c_str());
         node.setExpired();
         if (not node.id)
             requests.erase(req.tid);
         return;
     } else if (req.attempt_count == 1) {
-        req.on_expired(req, false);
+        if (req.on_expired)
+            req.on_expired(req, false);
     }
 
     auto err = send(node.getAddr(), (char*)req.msg.data(), req.msg.size(), node.getReplyTime() < now - UDP_REPLY_TIME);
@@ -429,7 +430,7 @@ NetworkEngine::processMessage(const uint8_t *buf, size_t buflen, SockAddr f)
         msg->msgpack_unpack(msg_res.get());
     } catch (const std::exception& e) {
         if (logger_)
-            logger_->w("Can't parse message of size %lu: %s", buflen, e.what());
+            logger_->w("Unable to parse message of size %lu: %s", buflen, e.what());
         // if (logger_)
         //     logger_->DBG.logPrintable(buf, buflen);
         return;
@@ -449,7 +450,7 @@ NetworkEngine::processMessage(const uint8_t *buf, size_t buflen, SockAddr f)
         if (pmsg_it == partial_messages.end()) {
             if (logIncoming_)
                 if (logger_)
-                    logger_->d("Can't find partial message");
+                    logger_->d("Unable to find partial message");
             rateLimit(from);
             return;
         }
@@ -523,7 +524,7 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
     if (msg->type == MessageType::ValueUpdate) {
         auto rsocket = node->getSocket(msg->tid);
         if (not rsocket)
-            throw DhtProtocolException {DhtProtocolException::UNKNOWN_TID, "Can't find socket", msg->id};
+            throw DhtProtocolException {DhtProtocolException::UNKNOWN_TID, "Unable to find socket", msg->id};
         node->received(now, {});
         onNewNode(node, 2);
         try {
@@ -531,7 +532,7 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
             rsocket->on_receive(node, std::move(*msg));
         } catch (const DhtProtocolException& e) {
             if (logger_)
-                logger_->w("Can't deserialize nodes %s", e.what());
+                logger_->w("Unable to deserialize nodes %s", e.what());
         }
     }
     else if (msg->type == MessageType::Error or msg->type == MessageType::Reply) {
@@ -550,7 +551,7 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
                 if (not node->isClient())
                     onNewNode(node, 1);
                 if (logger_)
-                    logger_->d(node->id, "[node %s] can't find transaction with id %u", node->toString().c_str(), msg->tid);
+                    logger_->d(node->id, "[node %s] Unable to find transaction with id %u", node->toString().c_str(), msg->tid);
                 return;
             }
         }
@@ -600,7 +601,7 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
                     r.setDone(std::move(*msg));
                 } catch (const DhtProtocolException& e) {
                     if (logger_)
-                        logger_->w("Can't deserialize nodes %s", e.what());
+                        logger_->w("Unable to deserialize nodes %s", e.what());
                 }
                 break;
             } else { /* request socket data */
@@ -609,7 +610,7 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
                     rsocket->on_receive(node, std::move(*msg));
                 } catch (const DhtProtocolException& e) {
                     if (logger_)
-                        logger_->w("Can't deserialize nodes %s", e.what());
+                        logger_->w("Unable to deserialize nodes %s", e.what());
                 }
             }
             break;
@@ -694,7 +695,7 @@ NetworkEngine::process(std::unique_ptr<ParsedMessage>&& msg, const SockAddr& fro
             }
         } catch (const std::overflow_error& e) {
             if (logger_)
-                logger_->e("Can't send value: buffer not large enough !");
+                logger_->e("Unable to send value: buffer not large enough.");
         } catch (const DhtProtocolException& e) {
             sendError(from, msg->tid, e.getCode(), e.getMsg().c_str(), true);
         }
@@ -744,16 +745,12 @@ NetworkEngine::sendPing(const Sp<Node>& node, RequestCb&& on_done, RequestExpire
         Blob(buffer.data(), buffer.data() + buffer.size()),
         [=](const Request& req_status, ParsedMessage&&) {
             if (logger_)
-                logger_->d(req_status.node->id, "[node %s] got pong !", req_status.node->toString().c_str());
+                logger_->d(req_status.node->id, "[node %s] got pong.", req_status.node->toString().c_str());
             if (on_done) {
                 on_done(req_status, {});
             }
         },
-        [=](const Request& req_status, bool done) { /* on expired */
-            if (on_expired) {
-                on_expired(req_status, done);
-            }
-        }
+        std::move(on_expired)
     );
     sendRequest(req);
     ++out_stats.ping;
@@ -819,11 +816,7 @@ NetworkEngine::sendFindNode(const Sp<Node>& n, const InfoHash& target, want_t wa
                 on_done(req_status, {std::forward<ParsedMessage>(msg)});
             }
         },
-        [=](const Request& req_status, bool done) { /* on expired */
-            if (on_expired) {
-                on_expired(req_status, done);
-            }
-        }
+        std::move(on_expired)
     );
     sendRequest(req);
     ++out_stats.find;
@@ -875,11 +868,7 @@ NetworkEngine::sendGetValues(const Sp<Node>& n, const InfoHash& info_hash, const
                 on_done(req_status, {std::forward<ParsedMessage>(msg)});
             }
         },
-        [=](const Request& req_status, bool done) { /* on expired */
-            if (on_expired) {
-                on_expired(req_status, done);
-            }
-        }
+        std::move(on_expired)
     );
     sendRequest(req);
     ++out_stats.get;
@@ -1157,10 +1146,7 @@ NetworkEngine::sendListen(const Sp<Node>& n,
             if (on_done)
                 on_done(req_status, {std::forward<ParsedMessage>(msg)});
         },
-        [=](const Request& req_status, bool done) { /* on expired */
-            if (on_expired)
-                on_expired(req_status, done);
-        }
+        std::move(on_expired)
     );
     sendRequest(req);
     ++out_stats.listen;
@@ -1240,11 +1226,7 @@ NetworkEngine::sendAnnounceValue(const Sp<Node>& n,
                 }
             }
         },
-        [=](const Request& req_status, bool done) { /* on expired */
-            if (on_expired) {
-                on_expired(req_status, done);
-            }
-        }
+        std::move(on_expired)
     );
     req->parts = std::move(v);
     sendRequest(req);
@@ -1372,12 +1354,8 @@ NetworkEngine::sendRefreshValue(const Sp<Node>& n,
                 }
             }
         },
-        on_error,
-        [=](const Request& req_status, bool done) { /* on expired */
-            if (on_expired) {
-                on_expired(req_status, done);
-            }
-        }
+        std::move(on_error),
+        std::move(on_expired)
     );
     sendRequest(req);
     ++out_stats.refresh;
