@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2014-2023 Savoir-faire Linux Inc.
+ *  Copyright (C) 2014-2025 Savoir-faire Linux Inc.
  *
  *  Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
  *
@@ -26,7 +26,7 @@
 
 namespace test {
 
-class OPENDHT_PUBLIC PeerDiscoveryTester : public CppUnit::TestFixture {
+class PeerDiscoveryTester : public CppUnit::TestFixture {
 
     CPPUNIT_TEST_SUITE(PeerDiscoveryTester);
     CPPUNIT_TEST(testMulticastToTwoNodes);
